﻿/*
 * Code contained in this file (Shuffle.cs) is copyright free
 * It was originally developped by "grenade". For more information about the 
 * author, please see:
 * http://stackoverflow.com/questions/273313/randomize-a-listt-in-c 
 * http://stackoverflow.com/users/68115/grenade
 * */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using System.Security.Cryptography;

namespace MetaNull.Collections
{
	/// <summary>
	/// Shuffles a collection
	/// </summary>
	public static class ShuffleCollections
	{
		/// <summary>
		/// Shuffles a collection
		/// </summary>
		/// <remarks>
		/// http://stackoverflow.com/questions/273313/randomize-a-listt-in-c
		/// Usage:
		/// List&lt;Product&gt; products = GetProducts(); 
		/// products.Shuffle(); 
		/// </remarks>
		/// <typeparam name="T"></typeparam>
		/// <param name="list"></param>
		public static void Shuffle<T>(this IList<T> list)
		{
			Random rng = new Random();
			int n = list.Count;
			while (n > 1)
			{
				n--;
				int k = rng.Next(n + 1);
				T value = list[k];
				list[k] = list[n];
				list[n] = value;
			}
		}

		/// <summary>
		/// Shuffles a collection
		/// </summary>
		/// <remarks>
		/// http://stackoverflow.com/questions/273313/randomize-a-listt-in-c
		/// Usage:
		/// List&lt;Product&gt; products = GetProducts(); 
		/// products.Shuffle(); 
		/// </remarks>
		/// <typeparam name="T"></typeparam>
		/// <param name="list"></param>
		public static void ShuffleBetter<T>(this IList<T> list)
		{
			RNGCryptoServiceProvider provider = new RNGCryptoServiceProvider();
			int n = list.Count;
			while (n > 1)
			{
				byte[] box = new byte[1];
				do provider.GetBytes(box);
				while (!(box[0] < n * (Byte.MaxValue / n)));
				int k = (box[0] % n);
				n--;
				T value = list[k];
				list[k] = list[n];
				list[n] = value;
			}
		} 
	}
}
