﻿/*
 * mTools - © EUROPEAN COMMISSION, 2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous
 * la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou 
 * implicites.
 * Consultez la Licence pour les autorisations et les restrictions 
 * linguistiques spécifiques relevant de la Licence.
 *
 * Auteur de l'oeuvre: Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using System.Net;
using System.Net.Sockets;
using System.IO;

using System.Runtime.Serialization;

namespace MetaNull.Net
{
	/// <summary>
	/// Holds settings for a WEB request
	/// </summary>
	[Serializable()]
	public class WebDocumentRequestSettings
	{
		/// <summary>
		/// Default constructor
		/// </summary>
		public WebDocumentRequestSettings()
		{
			init(null, true, 3, 100000);
		}
		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="allowAutoRedirect">Allow HTTP redirects</param>
		/// <param name="maxRedirects">Max number of redirects</param>
		public WebDocumentRequestSettings(bool allowAutoRedirect, int maxRedirects)
		{
			init(null, allowAutoRedirect, maxRedirects, 100000);
		}
		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="allowAutoRedirect">Allow HTTP redirects</param>
		/// <param name="maxRedirects">Max number of redirects</param>
		/// <param name="timeout">Timeout for the operation</param>
		public WebDocumentRequestSettings(bool allowAutoRedirect, int maxRedirects, int timeout )
		{
			init(null, allowAutoRedirect, maxRedirects, timeout);
		}
		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="proxy">HTTP proxy settings</param>
		/// <param name="allowAutoRedirect">Allow HTTP redirects</param>
		/// <param name="maxRedirects">Max number of redirects</param>
		public WebDocumentRequestSettings(IWebProxy proxy, bool allowAutoRedirect, int maxRedirects)
		{
			init(proxy, allowAutoRedirect, maxRedirects, 100000);
		}
		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="proxy">HTTP proxy settings</param>
		/// <param name="allowAutoRedirect">Allow HTTP redirects</param>
		/// <param name="maxRedirects">Max number of redirects</param>
		/// <param name="timeout">Timeout for the operation</param>
		public WebDocumentRequestSettings(IWebProxy proxy, bool allowAutoRedirect, int maxRedirects, int timeout)
		{
			init(proxy, allowAutoRedirect, maxRedirects, timeout);
		}
		/// <summary>
		/// Initializes the object
		/// </summary>
		/// <param name="proxy">HTTP proxy settings</param>
		/// <param name="allowAutoRedirect">Allow HTTP redirects</param>
		/// <param name="maxRedirects">Max number of redirects</param>
		/// <param name="timeout">Timeout for the operation</param>
		protected void init(IWebProxy proxy, bool allowAutoRedirect, int maxRedirects, int timeout)
		{
			Proxy = (WebProxy)proxy;
			AllowAutoRedirect = allowAutoRedirect;
			MaximumAutomaticRedirections = maxRedirects;
			Timeout = timeout;
		}

		/// <summary>
		/// Gets or sets proxy information for the request.
		/// </summary>
		public WebProxy Proxy;
		/// <summary>
		/// Gets or sets a value that indicates whether the request should follow redirection responses.
		/// </summary>
		public bool AllowAutoRedirect = true;
		/// <summary>
		/// Gets or sets the maximum number of redirects that the request follows.
		/// </summary>
		public int MaximumAutomaticRedirections = 3;
		/// <summary>
		/// Gets or sets the time-out value in milliseconds for the GetResponse and GetRequestStream methods.
		/// </summary>
		public int Timeout = 100000;
	}
}
