/*
* mUDFDownloader - Copyright 2010 the European Commission
* 
* Licensed under the EUPL (the Licence");
* You may not use this work except in compliance with the Licence.
* You may obtain a copy of the Licence at:
* http://ec.europa.eu/idabc/eupl.html
* 
* Unless required by applicable law or agreed to in
  writing, software distributed under the Licence is
  distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
  express or implied.
* See the Licence for the specific language governing
  permissions and limitations under the Licence.
*
* The software binaries include MySQL-C binaries (compiled from the un-modified
  MySQL-C source). 
* MySQL-C is copyrighted by Oracle Corp. and licensed under the Gnu GPL v 2.
*
*/
/*
 * Author: Pascal Havelange (Pascal.HAVELANGE@ec.europa.eu)
 */

#ifndef __METANULL_UDF_DEFINITIONS_H__
#define __METANULL_UDF_DEFINITIONS_H__

#ifdef STANDARD
/* STANDARD is defined, don't use any mysql functions */
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#ifdef __WIN__
	typedef unsigned __int64 ulonglong;	/* Microsofts 64 bit types */
	typedef __int64 longlong;
#else
	typedef unsigned long long ulonglong;
	typedef long long longlong;
#endif /*__WIN__*/
#else // ifdef STANDARD
#include <my_global.h>
#include <my_sys.h>
#if defined(MYSQL_SERVER)
#include <m_string.h>		/* To get strmov() */
#else // ifdef MYSQL_SERVER
/* when compiled as standalone */
#include <string.h>

static inline char *stpcpy(char *dest, const char *src) {
	strcpy(dest,src);
	return dest + strlen(dest);
}

#define strmov(a,b) stpcpy(a,b)
#define bzero(a,b) memset(a,0,b)
#define memcpy_fixed(a,b,c) memcpy(a,b,c)
#endif // ifdef MYSQL_SERVER
#endif // ifdef STANDARD

#ifndef HAVE_DLOPEN
#error "HAVE_LDOPEN constant not set"
#endif



#include <mysql.h>
#include <ctype.h>
#include <stdarg.h>
#include <stdio.h>


#define RC_INIT_ERROR		1
#define RC_INIT_SUCCESS		0

#define TEXT_BUFFER_SIZE	(16 * 1024)

#define LOG_FILE "c:\\temp\\udf_processes.log"


/**
 * Formats an error message (respecting the maximum allowed length for error
 * messages in _init functions)
 */
int format_init_error( char * pszDest, char * pszFormat, ... );

/**
 * Helper function to fetch Windows error messages
 */
size_t GetLastErrorMessage( char * pszDest, size_t cbDest );

/**
 * Helper function to fetch Windows Socket error messages
 */
size_t GetLastWSAErrorMessage( char * pszDest, size_t cbDest );

/**
 * Write a message into the log file
 */
int log_write( const char * message, ... );

/**
 * Print Windows error message into a buffer, and returns the address of the
 * buffer
 */
char * udf_report_win_error( char * pszDest, size_t cbDest, unsigned long * length, char * error, const char * msg, ... );

/**
 * Print CLR error message into a buffer, and returns the address of the buffer
 */
char * udf_report_clr_error( char * pszDest, size_t cbDest, unsigned long * length, char * error, const char * msg, ...  );

/**
 * Print Custom message into a buffer, and reteurn its address
 */
char * udf_report_error( char * pszDest, size_t cbDest, unsigned long * length, char * error, const char * msg, ...  );


#endif // ifdef __METANULL_UDF_DEFINITIONS_H__