CREATE DATABASE  IF NOT EXISTS `mVideoEncoder` /*!40100 DEFAULT CHARACTER SET utf8 */;
USE `mVideoEncoder`;

CREATE USER 'VideoEncoder'@'localhost' IDENTIFIED BY 'V1d303nc0d3r';
GRANT SELECT, INSERT, UPDATE, DELETE ON `mVideoEncoder`.* TO 'VideoEncoder'@'localhost';

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

DROP TABLE IF EXISTS `channels`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `channels` (
  `number` int(11) NOT NULL default '0',
  `group_id` int(10) unsigned NOT NULL,
  `type_id` int(10) unsigned NOT NULL COMMENT 'The type identifier',
  `channel_name` varchar(255) NOT NULL,
  PRIMARY KEY  USING BTREE (`number`,`group_id`,`type_id`),
  KEY `idx_channel_name` USING BTREE (`channel_name`),
  KEY `idx_channel_group` USING BTREE (`group_id`),
  KEY `FK_channels_types` (`type_id`),
  CONSTRAINT `FK_channels_groups` FOREIGN KEY (`group_id`) REFERENCES `groups` (`group_id`),
  CONSTRAINT `FK_channels_types` FOREIGN KEY (`type_id`) REFERENCES `channels_type` (`type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COMMENT='Channels List';
/*!40101 SET character_set_client = @saved_cs_client */;

DROP TABLE IF EXISTS `satellites`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `satellites` (
  `number` varchar(5) NOT NULL default '0',
  `group_id` int(10) unsigned NOT NULL,
  `description` varchar(45) default NULL,
  PRIMARY KEY  USING BTREE (`number`,`group_id`),
  KEY `idx_sat_group` USING BTREE (`group_id`),
  CONSTRAINT `FK_satellites_groups` FOREIGN KEY (`group_id`) REFERENCES `groups` (`group_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COMMENT='Satellites List';
/*!40101 SET character_set_client = @saved_cs_client */;

DROP TABLE IF EXISTS `channels_type`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `channels_type` (
  `type_id` int(10) unsigned NOT NULL auto_increment,
  `name` varchar(45) NOT NULL,
  `description` text,
  PRIMARY KEY  (`type_id`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;
DROP TABLE IF EXISTS `groups`;

/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `groups` (
  `group_id` int(10) unsigned NOT NULL auto_increment,
  `type` varchar(20) NOT NULL,
  `description` text,
  PRIMARY KEY  USING BTREE (`group_id`),
  KEY `idx_group_type` USING BTREE (`type`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=latin1 COMMENT='Satellites List';
/*!40101 SET character_set_client = @saved_cs_client */;
DROP TABLE IF EXISTS `schedule`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `schedule` (
  `schedule_id` int(11) NOT NULL auto_increment,
  `date` datetime NOT NULL,
  `length` time NOT NULL default '00:00:00',
  `title` varchar(255) default NULL,
  `description` text,
  `channel_number` int(11) default NULL,
  `channel_group_id` int(10) unsigned default NULL,
  `channel_type_id` int(10) unsigned default NULL,
  `capture_status` enum('Waiting','Capturing','Done','Error','Aborted') NOT NULL default 'Waiting',
  `capture_filename` varchar(255) default NULL,
  PRIMARY KEY  (`schedule_id`),
  KEY `idx_date` (`date`),
  KEY `fk_schedule_channel` (`channel_number`,`channel_group_id`,`channel_type_id`),
  CONSTRAINT `fk_schedule_channel` FOREIGN KEY (`channel_number`, `channel_group_id`, `channel_type_id`) REFERENCES `channels` (`number`, `group_id`, `type_id`) ON DELETE SET NULL ON UPDATE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=63 DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

