﻿/*
 * mAggregatorStatus - © EUROPEAN COMMISSION, 2009-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la
«Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que
conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse
suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le
logiciel distribué sous la Licence est distribué «en
l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT,
expresses ou implicites.
 * Consultez la Licence pour les autorisations et les
restrictions linguistiques spécifiques relevant de la
Licence.
 *
 * Auteur de l'oeuvre: Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Net;
using MySql.Data.MySqlClient;
using System.Text.RegularExpressions;
using System.IO;
using System.Reflection;
using System.Xml;
using System.Xml.Xsl;
using System.Xml.XPath;
using System.Xml.Linq;

using System.Resources;
using System.Globalization;

namespace mAggregatorService
{
	[Serializable()]
	public partial class Feed
	{
		public long FeedId = 0;
		public Uri Url;
		public string Title;
		public string Description;
		public Uri Picture;
		public Uri PictureLink;
		public string Language;
		public string Copyright;
		public bool Internet = true;

		public int UpdateRate;
		public DateTime LastUpdated;

		public Article[] Articles;

		public Feed()
		{
		}

		public Feed( MySqlDataReader reader ) {
			for (int i = 0; i < reader.FieldCount; i++)
			{
				string fieldType = reader.GetDataTypeName(i);
				string fieldName = reader.GetName(i);
				bool fieldIsNull = reader.IsDBNull(i);
				switch (fieldName)
				{
					case "feed_id":
						{
							if (!fieldIsNull)
							{
								FeedId = reader.GetUInt32(i);
							}
						} break;
					case "url":
						{
							if (!fieldIsNull)
							{
								Url = new Uri(reader.GetString(i));
							}
						} break;
					case "title":
						{
							if (!fieldIsNull)
							{
								Title = reader.GetString(i);
							}
						} break;
					case "description":
						{
							if (!fieldIsNull)
							{
								Description = reader.GetString(i);
							}
						} break;
					case "picture":
						{
							if (!fieldIsNull)
							{
								Picture = new Uri(reader.GetString(i));
							}
						} break;
					case "link":
						{
							if (!fieldIsNull)
							{
								PictureLink = new Uri(reader.GetString(i));
							}
						} break;
					case "language":
						{
							if (!fieldIsNull)
							{
								Language = reader.GetString(i);
							}
						} break;
					case "copyright":
						{
							if (!fieldIsNull)
							{
								Copyright = reader.GetString(i);
							}
						} break;
					case "refresh_rate":
						{
							if (!fieldIsNull)
							{
								UpdateRate = (int)reader.GetUInt32(i);
							}
						} break;
					case "last_refresh":
						{
							if (!fieldIsNull)
							{
								LastUpdated = reader.GetDateTime(i);
							}
						} break;
					case "use_proxy":
						{
							if (!fieldIsNull)
							{
								Internet = reader.GetInt16(i) == 1 ? true : false;
							}
						} break;
				}
			}
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="settings"></param>
		/// <returns></returns>
		public int Download( mWebDocumentRequestSettings settings)
		{
			int rc = ParseFeed(mWebDocument.httpGet(Url, settings));
			return rc;
		}

		public int ParseFeed(mWebDocument document)
		{
			if (document.StatusCode != HttpStatusCode.OK)
			{
				if (null != document.LastException)
				{
					throw new WebException("HTTP " + document.StatusCode + ": " + document.StatusDescription, document.LastException);
				}
				throw new WebException("HTTP " + document.StatusCode + ": " + document.StatusDescription);
			}
			List<Article> Articles = new List<Article>();
			try
			{
				byte[] xmlBytes = new byte[0];

				// If the document encoding is wrongly reported as ISO-8859-1 (I.e. it happens when it is not specified at all)
				// Treat the received data as UTF-8 encoded (default encoding  for XML)
				bool badlyEncoded = false;
				if (!document.ContentString.StartsWith("<") && !document.ContentString.TrimStart(new char[] { ' ', '\r', '\n', '\0', '\t', '\x0c' }).StartsWith("<"))
				{
					string s1 = Encoding.UTF8.GetString(document.ContentBytes);
					xmlBytes = Encoding.Unicode.GetBytes(s1);
					badlyEncoded = true;
				}
				else
				{
					xmlBytes = document.ContentBytes;
				}

				// Clean up the XML string from unsupported XML characters
				xmlBytes = Encoding.Unicode.GetBytes(mXslTools.SanitizeXmlString(Encoding.Unicode.GetString(xmlBytes)));

				// Fetch the bytes from the XML using the received character set (or defaulting to UTF-8 if none specified)
				if (badlyEncoded)
				{
					xmlBytes = Encoding.Convert(Encoding.Unicode, Encoding.UTF8, xmlBytes);
				} else if (null != document.CharacterSetName && string.Empty != document.CharacterSetName)
				{
					xmlBytes = Encoding.Convert(Encoding.Unicode, Encoding.GetEncoding(document.CharacterSetName), xmlBytes);
				}
				else
				{
					xmlBytes = Encoding.Convert(Encoding.Unicode, Encoding.UTF8, xmlBytes);
				}

				// Transform the document
				XPathDocument xml;
				XDocument result;
				using (MemoryStream ms = new MemoryStream(xmlBytes))
				{
					xml = new XPathDocument(ms);
					result = mXslTools.LinqTransformXml(CompiledXslFiles.RSSParser, xml);
					ms.Close();
				}

				
				// Extract specific elements
				Title = result.XPathSelectElement("/rss/channel/title").Value;
				//Url = new Uri(result.XPathSelectElement("/rss/channel/url").Value);
				Url = document.ResponseUri;
				Description = result.XPathSelectElement("/rss/channel/description").Value;
				/*if (DateTime.TryParse(result.XPathSelectElement("/rss/channel/lastBuildDate").Value, out LastUpdated))
				{
					// ==> OK, but this is not the last_refresh date as meant in the database
					LastUpdated = DateTime.SpecifyKind(LastUpdated, DateTimeKind.Utc);
				}*/
				XElement elt = result.XPathSelectElement("/rss/channel/image/url");
				if (null != elt && !string.IsNullOrEmpty(elt.Value))
				{
					Picture = new Uri(elt.Value);
				}
				elt = result.XPathSelectElement("/rss/channel/image/link");
				if (null != elt && !string.IsNullOrEmpty(elt.Value))
				{
					PictureLink = new Uri(elt.Value);
				}

				IEnumerable<XElement> items = result.XPathSelectElements("/rss/channel/item");
				foreach (XElement item in items)
				{
					Article article = new Article();
					article.FeedId = FeedId;
					article.Title = item.XPathSelectElement("title").Value;
					XElement link = item.XPathSelectElement("link");
					if (null != link && !string.IsNullOrEmpty(link.Value))
					{
						article.Link = new Uri(link.Value);
					}
					article.Description = item.XPathSelectElement("description").Value;
					article.LoadDate = DateTime.UtcNow;
					article.Date = article.LoadDate;
					XElement date = item.XPathSelectElement("pubDate");
					if (null != date && ((string)date.Value).Length != 0)
					{
						mXslTools.TryParseDateTime(date.Value, out article.Date);
					}
					Articles.Add(article);
				}
				this.Articles = Articles.ToArray();
			}
			catch (Exception)
			{
#if DEBUG
				DebugDumpFeed(document);
#endif
				throw;
			}
			finally
			{
			}
			return this.Articles.Length;
		}

	}
}
