﻿/*
 * © EUROPEAN COMMISSION, 2009-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la
«Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que
conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse
suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le
logiciel distribué sous la Licence est distribué «en
l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT,
expresses ou implicites.
 * Consultez la Licence pour les autorisations et les
restrictions linguistiques spécifiques relevant de la
Licence.
 *
 * Auteur de l'oeuvre: Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *
 */
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Linq;
using System.ServiceProcess;
using System.Text;
using System.Threading;
using System.Configuration;
using System.Net;

namespace mAggregatorService
{
	public partial class mAggregatorService : ServiceBase
	{
		/// <summary>
		/// Flag indicating weither HTTP Proxy is set in the config (otherwise do not use any proxy)
		/// </summary>
		public bool cfgUseProxy;

		/// <summary>
		/// Default Number of threads dedicated to the downloading of web documents
		/// </summary>
		public const int defaultNumdownloaders = 20;
		/// <summary>
		/// Number of threads dedicated to the downloading of web documents
		/// </summary>
		public int cfgNumDownloaders;

		/// <summary>
		/// Default Number of threads dedicated to writing the response to the database
		/// </summary>
		public const int defaultNumSavers = 5;
		/// <summary>
		/// Number of threads dedicated to writing the response to the database
		/// </summary>
		public int cfgNumSavers;

		/// <summary>
		/// Default Timeout for HTTP requests (milliseconds)
		/// </summary>
		public const int defaultHttpRequestTimeout = 100000;
		/// <summary>
		/// Timeout for HTTP requests (milliseconds)
		/// </summary>
		public int cfgHttpRequestTimeout;

		/// <summary>
		/// Default Size of the buffer for binary transferts
		/// </summary>
		public const int defaultBytesToReadAtOnce = 4096;
		/// <summary>
		/// Size of the buffer for binary transferts
		/// </summary>
		public int cfgBytesToReadAtOnce;

		/// <summary>
		/// Default Maximum HTTP redirects
		/// </summary>
		public const int defaultHttpMaxRedirects = mWebDocumentRequestSettings.DEFAULT_MAX_REDIR;
		/// <summary>
		/// Maximum HTTP redirects
		/// </summary>
		public int cfgHttpMaxRedirects;

		/// <summary>
		/// Default database connection string
		/// </summary>
		public const string defaultDbConnectionString = "server=localhost;port=3306;database=mAggregatorService;user=guest;password=;charset=utf8;";
		/// <summary>
		/// Database connection string
		/// </summary>
		public string cfgDbConnectionString;

		/// <summary>
		/// Default character set used when writing text data to the database
		/// </summary>
		public const string defaultDbTextEncoding = "utf-8";
		/// <summary>
		/// Character set used when writing text data to the database
		/// </summary>
		public string cfgDbTextEncoding;

		/// <summary>
		/// Default value for the cfgReportStatus setting
		/// </summary>
		public const bool defaultReportStatus = false;
		/// <summary>
		/// If set to true, the service sends its status through a named pipe
		/// </summary>
		public bool cfgReportStatus;

		/// <summary>
		/// Default value for the cfgStatusPipeName setting
		/// </summary>
		public const string defaultStatusPipeName = "mAggregatorService";
		/// <summary>
		/// Name of the named pipe used for reporting the status
		/// </summary>
		public string cfgStatusPipeName;

		/// <summary>
		/// Default value for the cfgStatusPipeServer setting
		/// </summary>
		public const string defaultStatusPipeServer = ".";
		/// <summary>
		/// Name of the server hosting the named pipe used for reporting the status
		/// </summary>
		public string cfgStatusPipeServer;

		/// <summary>
		/// Settings for HTTP requests (intranet)
		/// </summary>
		private mWebDocumentRequestSettings intranetSettings;

		/// <summary>
		/// Settings for HTTP requests (internet)
		/// </summary>
		private mWebDocumentRequestSettings internetSettings;

		/// <summary>
		/// Default number of milliseconds to yield each thread while waiting for events
		/// </summary>
		public const int defaultYieldTime = 10;
		/// <summary>
		/// Number of milliseconds to yield each thread while waiting for events
		/// </summary>
		public int cfgYieldTime;
		/// <summary>
		/// Milliseconds between successive refreshes
		/// </summary>
		public const int defaultPollInterval = 60000;
		/// <summary>
		/// Milliseconds between successive refreshes
		/// </summary>
		public int cfgPollInterval;
		/// <summary>
		/// Milliseconds between successive status notifications
		/// </summary>
		public const int defaultStatusInterval = 250;
		/// <summary>
		/// Seconds between successive refreshes
		/// </summary>
		public int cfgStatusInterval;
		

		/// <summary>
		/// Load configuration
		/// </summary>
		/// <param name="args">Service's startup arguments</param>
		protected void LoadConfiguration()
		{
			cfgUseProxy = ((null == ConfigurationSettings.AppSettings["proxyHost"]) ? false : (ConfigurationSettings.AppSettings["proxyHost"].Length == 0 ? false : true));
			cfgNumDownloaders = ((null == ConfigurationSettings.AppSettings["maxDownloaders"]) ? defaultNumdownloaders : Convert.ToInt32(ConfigurationSettings.AppSettings["maxDownloaders"]));
			cfgNumSavers = ((null == ConfigurationSettings.AppSettings["maxSavers"]) ? defaultNumSavers : Convert.ToInt32(ConfigurationSettings.AppSettings["maxSavers"]));

			cfgHttpRequestTimeout = ((null == ConfigurationSettings.AppSettings["httpTimeout"]) ? defaultHttpRequestTimeout : Convert.ToInt32(ConfigurationSettings.AppSettings["httpTimeout"]));
			cfgBytesToReadAtOnce = ((null == ConfigurationSettings.AppSettings["defaultBufferSize"]) ? defaultBytesToReadAtOnce : Convert.ToInt32(ConfigurationSettings.AppSettings["defaultBufferSize"]));
			cfgHttpMaxRedirects = ((null == ConfigurationSettings.AppSettings["maxRedirects"]) ? defaultHttpMaxRedirects : Convert.ToInt32(ConfigurationSettings.AppSettings["maxRedirects"]));

			cfgYieldTime = ((null == ConfigurationSettings.AppSettings["yieldTime"]) ? defaultYieldTime : Convert.ToInt32(ConfigurationSettings.AppSettings["yieldTime"]));
			cfgPollInterval = ((null == ConfigurationSettings.AppSettings["pollInterval"]) ? defaultPollInterval : Convert.ToInt32(ConfigurationSettings.AppSettings["pollInterval"]));
			cfgStatusInterval = ((null == ConfigurationSettings.AppSettings["statusInterval"]) ? defaultStatusInterval : Convert.ToInt32(ConfigurationSettings.AppSettings["statusInterval"]));

			cfgReportStatus = ((null == ConfigurationSettings.AppSettings["reportStatus"]) ? defaultReportStatus : Convert.ToBoolean(ConfigurationSettings.AppSettings["reportStatus"]));
			cfgStatusPipeName = ((null == ConfigurationSettings.AppSettings["statusPipeName"]) ? defaultStatusPipeName : ConfigurationSettings.AppSettings["statusPipeName"]);
			cfgStatusPipeServer = ((null == ConfigurationSettings.AppSettings["statusPipeServer"]) ? defaultStatusPipeServer : ConfigurationSettings.AppSettings["statusPipeServer"]);


			cfgDbConnectionString =
				((null == ConfigurationSettings.AppSettings["dbConnectionString"])
					? defaultDbConnectionString
					: ConfigurationSettings.AppSettings["dbConnectionString"]
				);
			cfgDbTextEncoding = ((null == ConfigurationSettings.AppSettings["dbTextEncoding"]) ? defaultDbTextEncoding : ConfigurationSettings.AppSettings["dbTextEncoding"]);

			intranetSettings = new mWebDocumentRequestSettings();
			intranetSettings.AllowAutoRedirect = true;
			intranetSettings.MaximumAutomaticRedirections = cfgHttpMaxRedirects;
			intranetSettings.Timeout = cfgHttpRequestTimeout;

			internetSettings = intranetSettings;
			if (cfgUseProxy)
			{
				internetSettings.Proxy = new WebProxy();
				internetSettings.Proxy.Address = new Uri(ConfigurationSettings.AppSettings["proxyHost"]);
				if (null != ConfigurationSettings.AppSettings["proxyUser"])
				{
					internetSettings.Proxy.Credentials = new NetworkCredential(ConfigurationSettings.AppSettings["proxyUser"], ConfigurationSettings.AppSettings["proxyPassword"]);
				}
				if (null != ConfigurationSettings.AppSettings["proxyBypass"])
				{
					internetSettings.Proxy.BypassList = ConfigurationSettings.AppSettings["proxyBypass"].Split(';');
				}
			}
		}
	}
}
