﻿/*
 * mDownloaderService - © EUROPEAN COMMISSION, 2009-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la
«Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que
conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse
suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le
logiciel distribué sous la Licence est distribué «en
l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT,
expresses ou implicites.
 * Consultez la Licence pour les autorisations et les
restrictions linguistiques spécifiques relevant de la
Licence.
 *
 * Auteur de l'oeuvre: Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *
 */
using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Linq;
using System.Text;
using System.Threading;
using System.Configuration;
using System.Net;
using System.Net.Sockets;
using System.IO;
using System.IO.Pipes;
using System.Runtime.Serialization;
using System.Runtime.Serialization.Formatters;
using System.Runtime.Serialization.Formatters.Binary;
using MySql.Data.MySqlClient;
using System.ServiceProcess;
using System.ServiceModel;

namespace mDownloaderService
{
	public partial class mDownloaderService : ServiceBase
	{
		/// <summary>
		/// Service's Main Thread
		/// </summary>
		private Thread thMainThread;

		/// <summary>
		/// Event triggered by the service's OnStop() method when the process should terminate itself
		/// </summary>
		private static ManualResetEvent stopService;

		/// <summary>
		/// TCP Server socket
		/// </summary>
		private TcpListener tcpListener;

		private Thread[] downloaderThreads;
		private Thread[] saverThreads;

		private ServiceHost webServiceHost;

		/// <summary>
		/// Constructor
		/// </summary>
		public mDownloaderService()
		{
			InitializeComponent();
			CanStop = true;
			CanShutdown = true;
			CanPauseAndContinue = false;
		}

		/// <summary>
		/// Starting the service
		/// </summary>
		/// <param name="args">Service's startup arguments</param>
		protected override void OnStart(string[] args)
		{
#if DEBUG
			Debugger.Launch();
#endif

			// Load Configuration Values
			LoadConfiguration();

			// Initializes the event used to quit the service
			stopService = new ManualResetEvent(false);

			/*
			
			int tp1 = 0, tp2 = 0;
			ThreadPool.GetMaxThreads(out tp1, out tp2);
			ThreadPool.SetMaxThreads(Math.Min(256,tp1 + cfgThreadPoolSize + cfgRequestHandlerCount + cfgResponseWriterCount), tp2);
			
			// Create and launch workers
			for (int dl = 0; dl < cfgRequestHandlerCount; dl++)
			{
				thparamDownload param = new thparamDownload();
				ThreadPool.QueueUserWorkItem(threadDownload, (object)param);
			}
			for (int sv = 0; sv < cfgResponseWriterCount; sv++)
			{
				thparamSave param = new thparamSave();
				ThreadPool.QueueUserWorkItem(threadSave, (object)param);
			}
			*/
			int tp1 = 0, tp2 = 0;
			ThreadPool.GetMaxThreads(out tp1, out tp2);
			ThreadPool.SetMaxThreads(Math.Min(256,tp1 + cfgThreadPoolSize), tp2);

			downloaderThreads = new Thread[cfgRequestHandlerCount];
			for (int dl = 0; dl < cfgRequestHandlerCount; dl++)
			{
				thparamDownload param = new thparamDownload();
				ParameterizedThreadStart start = new ParameterizedThreadStart(threadDownload);
				downloaderThreads[dl] = new Thread(start);
				downloaderThreads[dl].Start((object)param);
			}

			// Allow more than 2 concurrent downloads
			ServicePointManager.DefaultConnectionLimit = cfgRequestHandlerCount * 2;

			saverThreads = new Thread[cfgResponseWriterCount];
			for (int sv = 0; sv < cfgResponseWriterCount; sv++)
			{
				thparamSave param = new thparamSave();
				ParameterizedThreadStart start = new ParameterizedThreadStart(threadSave);
				saverThreads[sv] = new Thread(start);
				saverThreads[sv].Start((object)param);
			}

			// Create and launch the main thread
			ThreadStart fct = new ThreadStart(threadMain);
			thMainThread = new Thread(fct);
			thMainThread.Start();

			// Starts the webservice
			if (null != webServiceHost)
			{
				webServiceHost.Close();
			}
			webServiceHost = new ServiceHost(typeof(mDownloaderWebService.mDownloaderWebService));
			webServiceHost.Open();
		}

		/// <summary>
		/// Stopping the service
		/// </summary>
		protected override void OnStop()
		{
			// Stops the webservice
			if (null != webServiceHost)
			{
				webServiceHost.Close();
				webServiceHost = null;
			}

			// Signal threads that the service is stopping
			stopService.Set();

			// Wait for the main thread
			if (thMainThread.IsAlive)
			{
				thMainThread.Join(5000);
			}
		}

		/// <summary>
		/// Milisseconds to yield each thread while waiting for events
		/// </summary>
		internal int threadYieldTime = 10;

		/// <summary>
		/// Main thread of the service, handles connections from the clients
		/// </summary>
		private void threadMain()
		{
			bool commitSuicide = false;
			try
			{
				tcpListener = new TcpListener(IPAddress.Any, cfgPort);
				tcpListener.Start();
				while (false == stopService.WaitOne(threadYieldTime))
				{
					if (activeDownloads == 0 || activeSaves == 0)
					{
						eventLog.WriteEntry("No threads available to process the client requests", EventLogEntryType.Error);
						stopService.Set();
						continue;
					}
					if (!tcpListener.Pending())
					{
						continue;
					}
					thparamClient param = new thparamClient(tcpListener.AcceptTcpClient());
					ThreadPool.QueueUserWorkItem(threadClient, (object)param );
				}
			}
			catch (Exception e)
			{
				eventLog.WriteEntry("MainThread: An exception has occured ("+tcpListener.LocalEndpoint.ToString()+"): " + e.Message + Environment.NewLine + e.StackTrace, EventLogEntryType.Error);
				commitSuicide = true;
			}
			finally
			{
				// Stop waiting for connections
				tcpListener.Stop();

				// Terminate worker threads
				stopService.Set();

				while (activeClients > 0) { Thread.Sleep(0); };
				while (activeDownloads > 0) { Thread.Sleep(0); };
				while (activeSaves > 0) { Thread.Sleep(0); };
			}

			if (commitSuicide)
			{
				Stop();
				Environment.Exit(1);
			}
			// Thread.CurrentThread.Abort();
			// thMainThread.Abort();
		}
	}
}
