﻿/*
 * mDownloaderService - © EUROPEAN COMMISSION, 2009-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la
«Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que
conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse
suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le
logiciel distribué sous la Licence est distribué «en
l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT,
expresses ou implicites.
 * Consultez la Licence pour les autorisations et les
restrictions linguistiques spécifiques relevant de la
Licence.
 *
 * Auteur de l'oeuvre: Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *
 */
using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Linq;
using System.ServiceProcess;
using System.Text;
using System.Threading;
using System.Configuration;
using System.Net;
using System.Net.Sockets;
using System.IO;
using System.IO.Pipes;
using System.Runtime.Serialization;
using System.Runtime.Serialization.Formatters;
using System.Runtime.Serialization.Formatters.Binary;
using MySql.Data.MySqlClient;

namespace mDownloaderService
{
	public partial class mDownloaderService : ServiceBase
	{
		/// <summary>
		/// Default TCP Port to listen on
		/// </summary>
		public const int defaultPort = 3000;
		/// <summary>
		/// TCP Port to listen on
		/// </summary>
		public int cfgPort;

		/// <summary>
		/// Flag indicating weither HTTP Proxy is set in the config (otherwise do not use any proxy)
		/// </summary>
		public bool cfgUseProxy;

		/// <summary>
		/// Default Size of the thread pool
		/// Maximum number of concurrent thread in the pool (TCP client handlers)
		/// </summary>
		public const int defaultThreadPoolSize = 10;
		/// <summary>
		/// Size of the thread pool
		/// Maximum number of concurrent thread in the pool (TCP client handlers)
		/// </summary>
		public int cfgThreadPoolSize;

		/// <summary>
		/// Default Number of threads dedicated to the downloading of web documents
		/// </summary>
		public const int defaultRequestHandlersCount = 4;
		/// <summary>
		/// Number of threads dedicated to the downloading of web documents
		/// </summary>
		public int cfgRequestHandlerCount;

		/// <summary>
		/// Default Number of threads dedicated to writing the response to the database
		/// </summary>
		public const int defaultResponseWriterCount = 2;
		/// <summary>
		/// Number of threads dedicated to writing the response to the database
		/// </summary>
		public int cfgResponseWriterCount;

		/// <summary>
		/// Default Timeout for HTTP requests (milliseconds)
		/// </summary>
		public const int defaultHttpRequestTimeout = 100000;
		/// <summary>
		/// Timeout for HTTP requests (milliseconds)
		/// </summary>
		public int cfgHttpRequestTimeout;

		/// <summary>
		/// Default Size of the buffer for binary transferts
		/// </summary>
		public const int defaultBytesToReadAtOnce = 4096;
		/// <summary>
		/// Size of the buffer for binary transferts
		/// </summary>
		public int cfgBytesToReadAtOnce;

		/// <summary>
		/// Default Maximum HTTP redirects
		/// </summary>
		public const int defaultHttpMaxRedirects = 3;
		/// <summary>
		/// Maximum HTTP redirects
		/// </summary>
		public int cfgHttpMaxRedirects;

		/// <summary>
		/// Default value for the cfgReportStatus setting
		/// </summary>
		public const bool defaultReportStatus = false;
		/// <summary>
		/// If set to true, the service sends its status through a named pipe
		/// </summary>
		public bool cfgReportStatus;

		/// <summary>
		/// Default value for the cfgStatusPipeName setting
		/// </summary>
		public const string defaultStatusPipeName = "mDownloaderService";
		/// <summary>
		/// Name of the named pipe used for reporting the status
		/// </summary>
		public string cfgStatusPipeName;

		/// <summary>
		/// Default value for the cfgStatusPipeServer setting
		/// </summary>
		public const string defaultStatusPipeServer = ".";
		/// <summary>
		/// Name of the server hosting the named pipe used for reporting the status
		/// </summary>
		public string cfgStatusPipeServer;

		/// <summary>
		/// Default database connection string
		/// </summary>
		public const string defaultDbConnectionString = "server=localhost;port=3306;database=mDownloaderService;user=guest;password=;charset=utf8;";
		/// <summary>
		/// Database connection string
		/// </summary>
		public string cfgDbConnectionString;

		/// <summary>
		/// Default character set used when writing text data to the database
		/// </summary>
		public const string defaultDbTextEncoding = "utf-8";
		/// <summary>
		/// Character set used when writing text data to the database
		/// </summary>
		public string cfgDbTextEncoding;

		/// <summary>
		/// Load configuration
		/// </summary>
		/// <param name="args">Service's startup arguments</param>
		protected void LoadConfiguration()
		{
			cfgPort = ((null == ConfigurationSettings.AppSettings["port"]) ? defaultPort : Convert.ToInt32(ConfigurationSettings.AppSettings["port"]));
			cfgUseProxy = ((null == ConfigurationSettings.AppSettings["proxyHost"]) ? false : (ConfigurationSettings.AppSettings["proxyHost"].Length == 0 ? false : true));
			cfgThreadPoolSize = ((null == ConfigurationSettings.AppSettings["maxClients"]) ? defaultThreadPoolSize : Convert.ToInt32(ConfigurationSettings.AppSettings["maxClients"]));
			cfgRequestHandlerCount = ((null == ConfigurationSettings.AppSettings["maxDownloaders"]) ? defaultRequestHandlersCount : Convert.ToInt32(ConfigurationSettings.AppSettings["maxDownloaders"]));
			cfgResponseWriterCount = ((null == ConfigurationSettings.AppSettings["maxSavers"]) ? defaultResponseWriterCount : Convert.ToInt32(ConfigurationSettings.AppSettings["maxSavers"]));

			cfgHttpRequestTimeout = ((null == ConfigurationSettings.AppSettings["httpTimeout"]) ? defaultHttpRequestTimeout : Convert.ToInt32(ConfigurationSettings.AppSettings["httpTimeout"]));
			cfgBytesToReadAtOnce = ((null == ConfigurationSettings.AppSettings["defaultBufferSize"]) ? defaultBytesToReadAtOnce : Convert.ToInt32(ConfigurationSettings.AppSettings["defaultBufferSize"]));
			cfgHttpMaxRedirects = ((null == ConfigurationSettings.AppSettings["maxRedirects"]) ? defaultHttpMaxRedirects : Convert.ToInt32(ConfigurationSettings.AppSettings["maxRedirects"]));

			cfgReportStatus = ((null == ConfigurationSettings.AppSettings["reportStatus"]) ? defaultReportStatus : Convert.ToBoolean(ConfigurationSettings.AppSettings["reportStatus"]));
			cfgStatusPipeName = ((null == ConfigurationSettings.AppSettings["statusPipeName"]) ? defaultStatusPipeName : ConfigurationSettings.AppSettings["statusPipeName"]);
			cfgStatusPipeServer = ((null == ConfigurationSettings.AppSettings["statusPipeServer"]) ? defaultStatusPipeServer : ConfigurationSettings.AppSettings["statusPipeServer"]);

			cfgDbConnectionString =
				((null == ConfigurationSettings.AppSettings["dbConnectionString"])
					? defaultDbConnectionString
					: ConfigurationSettings.AppSettings["dbConnectionString"]
				);
			cfgDbTextEncoding = ((null == ConfigurationSettings.AppSettings["dbTextEncoding"]) ? defaultDbTextEncoding : ConfigurationSettings.AppSettings["dbTextEncoding"]);
		}
	}
}
