﻿/*
 * mDownloaderServiceClient - © EUROPEAN COMMISSION, 2009-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la
«Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que
conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse
suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le
logiciel distribué sous la Licence est distribué «en
l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT,
expresses ou implicites.
 * Consultez la Licence pour les autorisations et les
restrictions linguistiques spécifiques relevant de la
Licence.
 *
 * Auteur de l'oeuvre: Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using System.Xml.Serialization;
using System.Runtime.Serialization;
using System.Runtime.Serialization.Formatters;
using System.Runtime.Serialization.Formatters.Binary;
using System.IO;
using System.IO.Compression;

namespace mDownloaderWebServiceClient
{
	class EntryPoint
	{
		static void Main(string[] args)
		{
			try
			{
				EntryPoint p = new EntryPoint();
				p.Run();
			}
			catch (Exception e)
			{
				Console.WriteLine(e.ToString());
				Console.WriteLine(e.StackTrace);
			}
		}

		private mDownloaderWebService.ImDownloaderWebServiceClient client;

		public EntryPoint()
		{
			client = new mDownloaderWebService.ImDownloaderWebServiceClient();
		}

		public void Run()
		{
			signature();
			help();
			try
			{
				client.Open();
				bool fQuit = false;
				while (!fQuit)
				{
					string cmd = Console.ReadLine();
					string[] commands = cmd.Split(new char[] { ' ' });

					string result = string.Empty;
					int queryId = -1;
					switch (commands[0].ToLower())
					{
						case "": { } break;
						case "quit": { fQuit = true; } break;
						case "get": { queryId = get(commands.Where((str, index) => index != 0).ToArray()); } break;
						case "post": { queryId = post(commands.Where((str, index) => index != 0).ToArray()); } break;
						case "process": { queryId = processMultiple(commands.Where((str, index) => index != 0).ToArray()); } break;
						case "multiple": { queryId = createMultiple(commands.Where((str, index) => index != 0).ToArray()); } break;
						case "pending": { result = "Pending: " + pending(commands.Where((str, index) => index != 0).ToArray()); } break;
						case "result": { result = results(commands.Where((str, index) => index != 0).ToArray()); } break;
						case "reset": { result = "Affected rows: " + reset(commands.Where((str, index) => index != 0).ToArray()); } break;
						case "delete": { result = "Affected rows: " + reset(commands.Where((str, index) => index != 0).ToArray()); } break;

						default: { help(); } break;
					}
					if (-1 == queryId && result == string.Empty )
					{
						continue;
					}
					if (-1 != queryId)
					{
						Console.WriteLine("RequestId: " + queryId.ToString());
					}
					if (string.Empty != result)
					{
						Console.WriteLine(result);
					}
				}
				client.Close();
			}
			catch (Exception)
			{
				client.Abort();
				throw;
			}
		}

		private string results(string[] arguments)
		{
			if (arguments.Length < 1)
			{
				help();
				return string.Empty;
			}
			List<int> urlIds = new List<int>();
			foreach (string parameter in arguments.Where((str, index) => index != 0))
			{
				urlIds.Add(int.Parse(parameter));
			}
			string gz64res = client.GetResultsFiltered(int.Parse(arguments[0]), urlIds.ToArray());

			string res = string.Empty;
			MemoryStream ms = new MemoryStream( Convert.FromBase64String(gz64res));
			using (GZipStream gz = new GZipStream(ms, CompressionMode.Decompress))
			{
				
				int by = 0;
				while (-1 != (by = gz.ReadByte()))
				{
					res += (char)by;
				}
			}
			ms.Close();
			return res;
		}
		private int pending(string[] arguments)
		{
			if (arguments.Length < 1)
			{
				return help();
			}
			return client.PendingResponses(int.Parse(arguments[0])); ;
		}
		private int delete(string[] arguments)
		{
			if (arguments.Length < 1)
			{
				return help();
			}
			return client.DeleteRequest(int.Parse(arguments[0])); ;
		}
		private int reset(string[] arguments)
		{
			if (arguments.Length < 1)
			{
				return help();
			}
			return client.ResetRequest(int.Parse(arguments[0])); ;
		}
		private int get(string[] arguments)
		{
			if (1 != arguments.Length && 2 != arguments.Length)
			{
				return help();
			}
			return client.SendGetRequest(arguments[0], 2 == arguments.Length && "intranet" == arguments[1].ToLower() ? true : false);
		}
		private int post(string[] arguments)
		{
			if (2 != arguments.Length && 3 != arguments.Length)
			{
				return help();
			}
			return client.SendPostRequest(arguments[0], arguments[1], 3 == arguments.Length && "intranet" == arguments[2].ToLower() ? true : false);
		}
		private int processMultiple(string[] arguments)
		{
			if (1 != arguments.Length)
			{
				return help();
			}
			return client.ProcessExistingMultipleRequest( int.Parse(arguments[0]) );
		}
		private int createMultiple(string[] arguments)
		{
			int remainder = 0;
			Math.DivRem(arguments.Length, 4, out remainder);
			if (0 == arguments.Length || 0 != remainder )
			{
				return help();
			}
			List<mDownloaderWebService.DownloadRequest> requests = new List<mDownloaderWebService.DownloadRequest>();
			for( int offset = 0; offset < arguments.Length / 4; offset += 4 ) {
				mDownloaderWebService.DownloadRequest dl = new mDownloaderWebService.DownloadRequest();
				dl.Method = "post" == arguments[offset + 0].ToLower() ? "Post" : "Get";
				dl.Url = arguments[offset + 1];
				dl.PostData = "post" == arguments[offset + 0].ToLower() ? arguments[offset + 2] : string.Empty;
				dl.Intranet = arguments[offset + 3].ToLower() == "no-proxy" ? true : false;
				requests.Add(dl);
			}
			return client.SendMultipleRequests(requests.ToArray());
		}
		private void signature()
		{
			Console.WriteLine("mDownloaderWebServiceClient 0.1" );
			Console.WriteLine("Author: Pascal (Meta) Havelange");
			Console.WriteLine(string.Empty);
		}
		private int help()
		{
			Console.WriteLine("Commands:" );
			Console.WriteLine("help                                    : Print this help message");
			Console.WriteLine("quit                                    : Close the application");
			Console.WriteLine("get URL [OPT]                           : Enqueue an HTTP GET request");
			Console.WriteLine("post URL DATA [OPT]                     : Enqueue an HTTP POST request");
			Console.WriteLine("process REQUEST_ID                      : Request processing of existing multiple request");
			Console.WriteLine("multiple REQUEST[ REQUEST[ ...]         : Enqueue multiple HTTP requests");
			Console.WriteLine("pending REQUEST_ID                      : Fetch the number of pending downloads");
			Console.WriteLine("result REQUEST_ID [URLID [URLID [...]]  : Feth downloaded documents");
			Console.WriteLine("reset REQUEST_ID                        : Clear results from a given request");
			Console.WriteLine("delete REQUEST_ID                       : Delete a request and its results");
			Console.WriteLine(string.Empty);
			Console.WriteLine("Command arguments:");
			Console.WriteLine("URL        ::= (String) Document's URL");
			Console.WriteLine("OPT        ::= (String) Location of the URL: 'intranet' or 'internet'(default)");
			Console.WriteLine("DATA       ::= (String) HTT POST's data");
			Console.WriteLine("REQUEST_ID ::= (Int)    ID of the request");
			Console.WriteLine("METHOD     ::= (String) Http method: 'get' or 'post'");
			Console.WriteLine("REQUEST    ::= METHOD URL DATA OPT   Note: for GET requests, DATA should be set to 0");
			Console.WriteLine(string.Empty);
			return -1;
		}
	}
}
