﻿/*
 * © EUROPEAN COMMISSION, 2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous 
 * la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou 
 * implicites.
 * Consultez la Licence pour les autorisations et les restrictions 
 * linguistiques spécifiques relevant de la Licence.
 *
 * Auteur de l'oeuvre: Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using System.Configuration;
using System.Xml;
using System.Web;
using System.Text.RegularExpressions;
using MetaNull.Configuration;

namespace mFileMonitorService
{
	/// <summary>
	/// Object holding data bout an output folder
	/// </summary>
	public class Output : ConfigurationElement
	{
		/// <summary>
		/// Constructor
		/// </summary>
		public Output()
		{
			// Attributes on the properties provide default values
		}

		/// <summary>
		/// Name of the output
		/// </summary>
		[ConfigurationProperty("name", IsRequired = true, IsKey = true, DefaultValue = "_")]
		[StringValidator(MinLength = 1, MaxLength = 255, InvalidCharacters = " ~!@#$%^&*()[]{}/;'\"|\\")]
		public string Name
		{
			get
			{
				return (string)this["name"];
			}
			set
			{
				this["name"] = value;
			}
		}

		/// <summary>
		/// Path to the output folder
		/// </summary>
		[ConfigurationProperty("path", IsRequired = true, DefaultValue = "")]
		// [StringValidator(InvalidCharacters = "*?<>|\"")]		// Disabled as output can contain commands
		public string Path
		{
			get
			{
				return (string)this["path"];
			}
			set
			{
				this["path"] = value;
			}
		}

		/// <summary>
		/// Concatenated list of inputs to be taken in consideration for this output
		/// </summary>
		[ConfigurationProperty("inputs", IsRequired = true, DefaultValue = "*")]
		[StringValidator(InvalidCharacters = "~!@#$%^&()[]{}/;'\"|\\")]
		public string Inputs
		{
			get
			{
				return (string)this["inputs"];
			}
			set
			{
				this["inputs"] = value;
			}
		}

		/// <summary>
		/// Indicate whether subfolders hierarchy should be duplicated as well
		/// </summary>
		[ConfigurationProperty("copyTree", IsRequired = true, DefaultValue = true)]
		public bool CopyTree
		{
			get
			{
				return (bool)this["copyTree"];
			}
			set
			{
				this["copyTree"] = value;
			}
		}

		/// <summary>
		/// List of input names to be taken in consideration for this output
		/// </summary>
		public string[] InputNames
		{
			get
			{
				string[] inputs = Regex.Replace((string)this["inputs"], @"\s*,\s*", ",").Trim().Split(new char[] { ',' }).ToArray();
				if (inputs.Contains("*"))
				{
					return new string[] { "*" };
				}
				return inputs;
			}
		}
	}
}