﻿/*
 * © EUROPEAN COMMISSION, 2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous 
 * la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou 
 * implicites.
 * Consultez la Licence pour les autorisations et les restrictions 
 * linguistiques spécifiques relevant de la Licence.
 *
 * Auteur de l'oeuvre: Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *
 */
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Linq;
using System.ServiceProcess;
using System.Text;
using System.Threading;
using System.Configuration;
using System.Net;

using System.Data.Common;

namespace mFileMonitorService
{
	public partial class mFileMonitorService : ServiceBase
	{
		/// <summary>
		/// Default value for the cfgReportStatus setting
		/// </summary>
		public const bool defaultReportStatus = false;
		/// <summary>
		/// If set to true, the service sends its status through a named pipe
		/// </summary>
		public bool cfgReportStatus;

		/// <summary>
		/// Default value for the cfgStatusPipeName setting
		/// </summary>
		public const string defaultStatusPipeName = "mFileMonitorService";
		/// <summary>
		/// Name of the named pipe used for reporting the status
		/// </summary>
		public string cfgStatusPipeName;

		/// <summary>
		/// Default value for the cfgStatusPipeServer setting
		/// </summary>
		public const string defaultStatusPipeServer = ".";
		/// <summary>
		/// Name of the server hosting the named pipe used for reporting the status
		/// </summary>
		public string cfgStatusPipeServer;

		/// <summary>
		/// Default number of milliseconds to yield each thread while waiting for events
		/// </summary>
		public const int defaultYieldTime = 10;
		/// <summary>
		/// Number of milliseconds to yield each thread while waiting for events
		/// </summary>
		public int cfgYieldTime;
		/// <summary>
		/// Milliseconds between successive status notifications
		/// </summary>
		public const int defaultStatusInterval = 250;
		/// <summary>
		/// Seconds between successive refreshes
		/// </summary>
		public int cfgStatusInterval;

		/// <summary>
		/// List of input folders as defined in the configuration file
		/// </summary>
		public Input[] inputFolders;

		/// <summary>
		/// List of output folders as defined in the configuration file
		/// </summary>
		public Output[] outputFolders;

		/// <summary>
		/// Load configuration
		/// </summary>
		protected void LoadConfiguration()
		{
			cfgYieldTime = ((null == ConfigurationSettings.AppSettings["yieldTime"]) ? defaultYieldTime : Convert.ToInt32(ConfigurationSettings.AppSettings["yieldTime"]));
			cfgReportStatus = ((null == ConfigurationSettings.AppSettings["reportStatus"]) ? defaultReportStatus : Convert.ToBoolean(ConfigurationSettings.AppSettings["reportStatus"]));
			cfgStatusInterval = ((null == ConfigurationSettings.AppSettings["statusInterval"]) ? defaultStatusInterval : Convert.ToInt32(ConfigurationSettings.AppSettings["statusInterval"]));
			cfgStatusPipeName = ((null == ConfigurationSettings.AppSettings["statusPipeName"]) ? defaultStatusPipeName : ConfigurationSettings.AppSettings["statusPipeName"]);
			cfgStatusPipeServer = ((null == ConfigurationSettings.AppSettings["statusPipeServer"]) ? defaultStatusPipeServer : ConfigurationSettings.AppSettings["statusPipeServer"]);

			InputsOutputs io = ConfigurationManager.GetSection("io") as InputsOutputs;
			if (null == io)
			{
				throw new System.Configuration.ConfigurationErrorsException( "Failed to load Input/Output folders form the config file" );
			}
			inputFolders = new Input[io.Inputs.Count];
			outputFolders = new Output[io.Outputs.Count];
			io.Inputs.CopyTo(inputFolders, 0);
			io.Outputs.CopyTo(outputFolders, 0);
		}
	}
}
