﻿/*
 * © EUROPEAN COMMISSION, 2009-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la
«Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que
conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse
suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le
logiciel distribué sous la Licence est distribué «en
l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT,
expresses ou implicites.
 * Consultez la Licence pour les autorisations et les
restrictions linguistiques spécifiques relevant de la
Licence.
 *
 * Auteur de l'oeuvre: Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *
 */
using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace mAggregatorService
{
	public class mMemoryTrace
	{
		public DateTime time;
		public String label;
		public long memory;

		private const int padSize = 10;

		public mMemoryTrace(string label)
		{
			this.time = DateTime.Now;
			this.label = label;
			GC.Collect();
			GC.WaitForPendingFinalizers();
			this.memory = GC.GetTotalMemory(true);
		}

		public static void DumpTraces(mMemoryTrace prevStep, mMemoryTrace curStep)
		{
			DumpTraces(new mMemoryTrace[] { prevStep, curStep });
		}
		public static void DumpTraces(mMemoryTrace[] traces)
		{
			if (traces.Length == 0)
			{
				return;
			}
			ConsoleColor c = Console.ForegroundColor;

			mMemoryTrace firstTrace = traces.First();
			mMemoryTrace lastTrace = traces.Last();
			mMemoryTrace prevTrace = null;
			foreach (mMemoryTrace trace in traces)
			{
				if (null == prevTrace)
				{
					firstTrace = trace;
					Console.ForegroundColor = ConsoleColor.Green;
					Console.Write(firstTrace.time.ToString("hh:mm:ss.fffffff") + " ");
					Console.Write(Math.Round((firstTrace.memory) / 1024.0, 3).ToString() + "kb ");
					Console.WriteLine(firstTrace.label);
				}
				else
				{
					if (trace != lastTrace)
					{
						Console.ForegroundColor = ConsoleColor.White;
						Console.Write((trace.time - prevTrace.time).TotalMilliseconds.ToString().PadLeft(padSize) + "ms ");
						Console.Write(Math.Round((trace.memory - prevTrace.memory) / 1024.0, 3).ToString().PadLeft(padSize) + "kb ");
						Console.WriteLine(trace.label);
					}
				}
				prevTrace = trace;
			}
			Console.ForegroundColor = ConsoleColor.Red;
			if (2 != traces.Length)
			{
				Console.Write(firstTrace.time.ToString("hh:mm:ss.fffffff") + " ");
				Console.WriteLine(Math.Round((firstTrace.memory) / 1024.0, 3).ToString() + "kb ");
			}
			Console.Write((lastTrace.time - firstTrace.time).TotalMilliseconds.ToString().PadLeft(padSize) + "ms ");
			Console.Write(Math.Round((lastTrace.memory - firstTrace.memory) / 1024.0, 3).ToString().PadLeft(padSize) + "kb ");
			Console.WriteLine(lastTrace.label);
			
			Console.ForegroundColor = c;
		}
	}
}
