﻿/*
 * © EUROPEAN COMMISSION, 2009-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la
«Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que
conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse
suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le
logiciel distribué sous la Licence est distribué «en
l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT,
expresses ou implicites.
 * Consultez la Licence pour les autorisations et les
restrictions linguistiques spécifiques relevant de la
Licence.
 *
 * Auteur de l'oeuvre: Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace mAggregatorService
{
	/// <summary>
	/// Base class for Thread arguments. It embeds an instance counting mechanism 
	/// accessible via the InstanceNumber property
	/// </summary>
	/// <remarks>
	/// Author: Pascal (Meta) Havelange
	/// Copyright (C) 2010
	/// </remarks>
	public class mThreadParam
	{
		/// <summary>
		/// Holds the automatically incremented instance number
		/// </summary>
		private static int StaticInstanceNumber = 0;
		/// <summary>
		/// Holds the value of the instance number as set when the mThreadParam object was initialized
		/// </summary>
		private int PrivateInstanceNumber;

		/// <summary>
		/// Get the InstanceNumber of the mThreadParam object
		/// </summary>
		public int InstanceNumber
		{
			get
			{
				return PrivateInstanceNumber;
			}
		}
		/// <summary>
		/// Create a new mThreadParam object
		/// </summary>
		public mThreadParam()
		{
			lock (mSingletonLock.Lock)
			{
				PrivateInstanceNumber = StaticInstanceNumber++;
			}
		}

		/// <summary>
		///  Implements a singleton object for locking access to static variables
		/// </summary>
		/// <remarks>
		/// Singleton: One single instance of the object
		/// Locking:   Mechanism for synchronising access to shared resource
		/// </remarks>
		private sealed class mSingletonLock
		{
			/// <summary>
			/// Singleton locker object (only one single instance for the whole application)
			/// </summary>
			/// <remarks>
			/// Accessible only through the Lock property
			/// Initialized by the private constructor
			/// </remarks>
			private object PrivateLock;

			/// <summary>
			/// Single instance of a mSingletonLock  object
			/// </summary>
			public static readonly mSingletonLock Singleton = new mSingletonLock();

			/// <summary>
			/// Access for the Singleton object
			/// </summary>
			public static object Lock
			{
				get
				{
					return Singleton.PrivateLock;
				}
			}
			/// <summary>
			/// Private constructor (called by the initializer of the static readonly Singleton property
			/// </summary>
			private mSingletonLock()
			{
				PrivateLock = new object();
			}
		}
	}
}
