<?php
/*
 * © EUROPEAN COMMISSION, 2009-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */
 
/**
 * Tarîqa 3.0 Service, doesn't require any authentication, accessible only through localhost
 * @package tariqa3
 * @copyright © EUROPEAN COMMISSION 2009-2010
 * @author Pascal Havelange, Cosmin Popescu
 * @internal
 */
namespace tariqa3 {

	define( 'TARIQA3_REL_PATH', '../tariqa3.0' );
	define( 'APPLICATION_CACHE', TARIQA3_REL_PATH . '/cache' );

	require_once( 'PEAR.php' );
	require_once( 'Config.php' );
	require_once( 'lib/MetaNull.php' );
	require_once( TARIQA3_REL_PATH . '/tariqa3/statics.class.php');

	require_once( 'Home.class.php' );

	define( 'APPLICATION_MAIN_CONFIG_FILE', 'config/config.xml');
	define( 'APPLICATION_NEWS_CONFIG_FILE', TARIQA3_REL_PATH . '/config/news_config.xml');
	define( 'APPLICATION_SOAP_CONFIG_FILE', TARIQA3_REL_PATH . '/config/soap_config.xml');
	define( 'TARIQA_MAIN_CONFIG_FILE', TARIQA3_REL_PATH . '/config/main_config.xml');
	define( 'APPLICATION_CONFIG_FORMAT', 'xml');

	try {
		if( false === Application::checkPhpSettings() ) {
			throw new Exception('Invalid PHP settings. Could not run Tarîqa 3.0 service application');
		}

		$config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'service_app_config');

		$the_app = new Application(array('config' => $config));

		$the_app->setAutoSaveConfig( false );
		$modules = array(
			// Default module should be first!
			new Home( $the_app->getConfig() ),
		);
		$moduleDescriptors = array();
		foreach( $modules as $midx => $module ) {
			$module->currentLanguage = $the_app->getCurrentLanguage();
			$module->defaultLanguage = $the_app->getDefaultLanguage();
			$module->languageList = $the_app->getLanguageList();
			$module->translationTable = $the_app->getModuleTranslationTable('home');
			if (array_key_exists('module_name', $_GET)){
				$module->translationTable = $the_app->getModuleTranslationTable($_GET['module_name']);
			}
			if( is_a( $module, 'tariqa3\\tariqa3Module' )) {
				$moduleDescriptors[] = new tariqa3ModuleDescriptor($module);
			} else {
				// Not a tariqa3Module, should not be added into the menu of the application
				// => application should provide appropriate links to this module to make it available to the end-user

				// var_dump( get_class($module));
			}
		}
		foreach( $modules as $midx => $module ) {
			$module->moduleDescriptors = $moduleDescriptors;
			$the_app->addModule( $module, 0 == $midx ? true : false );
		}
		$the_app->run();

	} catch( \Exception $e ) {
		trigger_error( 'Unexpected exception!' . "\n" . (string)$e );
	}

}
?>