<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace MetaNull\Application {

	/**
	 * Interface for objects used by the mTemplate class
	 * Evey mtemplate:object key must refer to a class extending mTemplateObject
	 * @author Pascal Havelange
 	 * @copyright © EUROPEAN COMMISSION, 2007
 	 * @package MetaNull\Application
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	abstract class mTemplateObject {
		abstract public function initialize( $data = null );
		abstract public function next();
		abstract public function destroy();
		abstract public function error();
	}
	
	// Some general purpose callbacks to be used in the template function
	/**
	 * Escapes HTML special characters
	 * @param string $data
	 * @return string
	 */
	function cb_html_escape( $data ) {
		return htmlspecialchars( $data, ENT_COMPAT, "UTF-8" );
	}
	
	/**
	 * Escapes a string so that it can be used as an attribute value in an HTML document
	 * @param string $data
	 * @return string
	 */
	function cb_html_attribute_value( $data ) {
		return str_replace("\r\n"," ", htmlspecialchars( $data, ENT_QUOTES, "UTF-8"));
	}
	
	/**
	 * Cleanup HTML data to make it fits strictly with XHTML format
	 * @param string $data
	 * @return string
	 */
	function cb_html_tidy( $data ) {
		$config = array(
			"output-xhtml" => true,
			"show-body-only" => true,
			"doctype" => "strict",
		
			"indent" => true,
			"drop-proprietary-attributes" => true,
			"lower-literals" => true,
			"drop-font-tags" => true,
			"quote-ampersand" => true,
			"wrap" => 120,
		);
		$tidy = new tidy;
		$tidy->parseString( $data, $config, "utf8" );
		$tidy->cleanRepair();
		return $tidy;
	}
	
	
	/**
	 * Convert CR & LF to HTML paragraphs
	 * @param string $data
	 * @return string
	 */
	function cb_crlf_to_br( $data ) {
		$str = preg_replace( '/\r\n/i', "\n", $data );
		$str = preg_replace( '/<br\/>[\n]?/i', "\n", $str );
		$str_paragraphs = explode( "\n\n", $str );
		foreach( $str_paragraphs as $pidx => $paragraph ) {
			$str_lines = explode( "\n", $paragraph );
			foreach( $str_lines as $lidx => $line ) {
				$str_lines[$lidx] = htmlspecialchars( $line, ENT_COMPAT, "UTF-8" );
			}
			$str_paragraphs[$pidx] = implode( "<br/>\n", $str_lines );
		}
		if( count( $str_paragraphs ) > 1 ) {
			$str_paragraphs = array_filter( array_map("trim", $str_paragraphs));
			$str = "<p>".implode("</p>\n<p>", $str_paragraphs )."</p>\n";			
		} else {
			$str = $str_paragraphs[0];
		}
		return $str;
		
	}
}