<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace MetaNull\Tools{
	/**
	 * Transform a document into various type of outputs, unsing XSL
	 * @author Cosmin Popescu
	 * @copyright © EUROPEAN COMMISSION, 2010
	 * @package MetaNull\Tools
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	class xslTransform {

		/**
		 * PDF format constant
		 * @var string
		 */
		const FORMAT_PDF = "pdf";

		/**
		 * TEXT format constant
		 * @var string
		 */
		const FORMAT_TEXT = "txt";

		/**
		 * The news XML
		 * @var string
		 * @access private
		 */
		private $xml = null;

		/**
		 * The template file name
		 * @var string
		 * @access private
		 */
		private $template = null;

		/**
		 * The output format
		 * @var string
		 * @access private
		 */
		private $output = null;

		/**
		 * The config of the news printer
		 * @var array
		 * @access private
		 */
		private $config = null;

		/**
		 * Constructs the object
		 * @param string | DOMDocument $xml The news XML
		 * @param string $template The template file name
		 * @param string $output The output format
		 * @param array $config The configuration array
		 * @access public
		 * @return void
		 */
		public function __construct($xml, $template, $output, $config) {
			if (is_string($xml)) {
				$this->xml = $xml;
			}
			else {
				$this->xml = $xml->saveXML();
			}

			$this->output = $output;
			$this->config = $config;
			$this->template = $this->config["templates"]["base"];
			if (substr($this->template, -1) != "/") $this->template .= "/";
			$this->template .= $template . ".xsl";
		}

		/**
		 * Checks the output format
		 * @access protected
		 * @return boolean
		 */
		protected function checkFormat() {
			return true;
			if (array_key_exists("format", $this->config["print-formats"])) {
				foreach ($this->config["print-formats"]["format"] as $format) {
					if ($format == $this->output) {
						return true;
					}
				}
			}

			return false;
		}

		/**
		 * Gets the format in PDF format
		 * @access protected
		 * @return string
		 */
		protected function outputPDF() {
			$fop = new \MetaNull\Tools\mFop();
			$fop->disable_warnings = true;
			$content = $fop->getPdfFromXMLString($this->xml, $this->template);
			if ($content === false) {
				throw new \Exception("Error while generating the PDF. Please see the logs. ");
			}

			return $content;
		}

		/**
		 * Gets the output in text format (tabs separated)
		 * @access protected
		 * @return string
		 */
		protected function outputTEXT() {
			$xsl = file_get_contents($this->template);
			$xml = new \DOMDocument();
			$xslt = new \XSLTProcessor();
			$xml->loadXML( $xsl );
			$xslt->importStyleSheet( $xml );
			$xml->loadXML( $this->xml );

			// Get the result as a dom document for formatted output
			return $xslt->transformToXML($xml);
		}

		/**
		 * Transforms a news XML into desired output (pdf, xhtml, text etc.)
		 * @access public
		 * @return string
		 */
		public function transform() {
			if (!$this->checkFormat()) {
				throw new \Exception("Unknown format", E_ERROR);
			}

			try {
				switch ($this->output) {
					case xslTransform::FORMAT_PDF: {
							return $this->outputPDF();
						}break
						;
					case xslTransform::FORMAT_TEXT: {
							return $this->outputTEXT();
						}break
						;
					default: {
					    require_once('tariqa3/briefcase_export/' . $this->output . '.class.php');
					    $class_name = "\\tariqa3\\{$this->output}";
					    $exportClass = new $class_name();
					    return $exportClass->output($this->template, $this->xml);
					}break;
				}
			}
			catch(\Exception $e) {
				throw new \Exception("Error transforming the news results into {$this->output}. Please see the log for details", E_ERROR);
			}
		}
	}
}
?>