/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

var PAGE_SEARCHES = null;
var $tabs;
var selected_sources = new Array();

function selectAll(sel){
    if (typeof(sel) == 'undefined' || sel == null) sel = true;

    var sources = $('input[type=checkbox]');

    for (var i in sources){
        sources[i].checked = sel;
    }
}

function submitSearch(){
    if ($('#query')[0].value == ''){
        tariqaAlert(MESSAGES['INPUT_QUERY'], 'Error', TYPE_ALERT_ERROR);
        return false;
    }

    var source_selected = false;

    var sources = $('input[type=checkbox]');
    for (var i in sources){
        if (sources[i].checked){
            source_selected = true;
            break;
        }
    }

    if (!source_selected){
        tariqaAlert(MESSAGES['SELECT_SOURCE'], 'Error', TYPE_ALERT_ERROR);
        return false;
    }

    return true;
}

function initForm(){
    $('.select_date').datepicker({
        dateFormat: 'yy-mm-dd',
        changeMonth: true,
        changeYear: true
    });
}

function initTabs(){
    $tabs = $('#results_tabs_id').tabs({
        });
}

function initHelp(id){
    $('#' + id).dialog({
        autoOpen: false,
        width: 700,
        height: 400,
        modal: false,
        hide: 'slide',
        show: 'slide',
        buttons: {
            'Ok': function(){
                $(this).dialog('close');
            }
        }
    });
}

function initFullSearchUI(selected_tab){
    if (typeof(selected_tab) == 'undefined' || selected_tab == null) selected_tab = 0;
    initForm();
    $tabs = $('#main_tabs').tabs({
        selected: selected_tab,
        cookie: {
            // store cookie for a day, without, it would be a session cookie
            expires: 1
        }
    });
    $sources = $('#selected_sources_ui').selectable({
        stop: function(){
            while (selected_sources.length > 0) selected_sources.pop();
            $('.ui-selected', this).each(function(){
                var id = $('#selected_sources_ui li')[$('#selected_sources_ui li').index(this)].getAttribute('id');
                selected_sources.push(id);
            });
        }
    });

    $autocompl = $('#sources_select').autocomplete({
        minLength: 3,
        source: URL(TARIQA_URL, 'module=ajax&action=searchLexisSource&content_type=text&no_root_node'),
	open: function(event, ui){
	    var el = $('.ui-autocomplete:visible');
	    var top = el.position().top;
	    var height = $(window).height() - top - 10;
	    var width = 500;
	    if (el.height() > height){
		el.css('height', height + 'px').css('overflow-y', 'auto');
	    }
	    if (el.width() > width){
		el.css('width', width + 'px').css('overflox-x', 'auto');
	    }
	    return true;
	},
        select: function(event, ui){
            addSource(ui.item.id, ui.item.value);
        }
    });

    /*$feed_autocomplete = $('#feed_RSS_aggregator').autocomplete({
        minLength: 3,
        source: URL(TARIQA_URL, 'module=ajax&action=searchFeed&content_type=text&no_root_node&type=RSS_aggregator'),
        select: function(event, ui){
            feedFound(event, ui, 'RSS_aggregator');
        }
    });

    $feed_autocomplete = $('#feed_LatestNews_aggregator').autocomplete({
        minLength: 3,
        source: URL(TARIQA_URL, 'module=ajax&action=searchFeed&content_type=text&no_root_node&type=LatestNews_aggregator'),
        select: function(event, ui){
            feedFound(event, ui, 'LatestNews_aggregator');
        }
    });*/
}

function feedFound(event, ui, type){
    $('#selected_feed_' + type)[0].value = ui.item.id;
}

/**
 * Performs a multi AJAX search
 * @param searches An array of searchObject - The searches to be performed
 * @param onBegin A function to be called before the search is performed
 * @param onEnd A function to be called when all the results are retrieved
 */
function performMultiAjaxSearch(searches, onBegin, onEnd){
    if (searches.length == 0){
        tariqaAlert(MESSAGES['LOADING_PROBLEM'], 'Error', TYPE_ALERT_ERROR);
        return false;
    }
    PAGE_SEARCHES = searches;
    var urls = new Array();
    var multi_ajax;
    for(var i in searches){
        multi_ajax = new multiAjaxURL(searches[i].getSearchURL());
        multi_ajax.set_method('post');
        urls.push(multi_ajax);
    }

    sendURLS(urls, renderResult, onBegin, onEnd, true);
}

function renderResult(_response){
    var response = new multiAjaxResponse(_response);
    if (response.http_code == 200){
        var xp = new xpath(response.content);
        var result = xp.doXPath('//error');
        var error = result.firstNode();
        if (error){
            tariqaAlert(error.firstChild.data, 'Error', TYPE_ALERT_ERROR);
        }
        else {
            var result = xp.doXPath('//source_id');
            var source_id = null;
            if (result.firstNode()){
                source_id = result.firstNode().firstChild.data;
            }
            var result = xp.doXPath('//articles');
            var news = result.firstNode();
            if (news && source_id != null){
                news = news.firstChild.data;
                result = xp.doXPath('//add_tab');
                var add_tab = 'true';
                if (result.firstNode()){
                    add_tab = result.firstNode().firstChild.data;
                }
                var result_id = 'html_result_' + source_id;
                result = xp.doXPath('//result_id');
                if (result.firstNode()){
                    result_id = result.firstNode().firstChild.data;
                }

                if (add_tab == 'true'){
                    var title = 'Title N/A';
                    result = xp.doXPath('//source');
                    if (result.firstNode()){
                        title = result.firstNode().firstChild.data;
                    }
                    title += '<span style="padding-left: 10px; display: none;" id="nav_load_' + result_id + '"><img src="/themes/default/images/ajax-loader-mini.gif"/></span>';
                }
                var navigation_id = 'navigation_' + source_id;
                result = xp.doXPath('//navigation_id');
                if (result.firstNode()){
                    navigation_id = result.firstNode().firstChild.data;
                }
                $('#' + navigation_id)[0].innerHTML = '';
                news = news.replace("preload_", "preload_" + result_id);
                document.getElementById(result_id).innerHTML = news;
                result = xp.doXPath('//navigation');
                if (result.firstNode()){
                    if (result.firstNode().childNodes.length > 0){
                        result = xp.doXPath('//navigation/html_code');
                        if (result.firstNode()){
                            var html_code = result.firstNode().firstChild.data;
                            $('#' + navigation_id).html(html_code);
                            result = xp.doXPath('//navigation/object_name');
                            if (result.firstNode()){
                                var object_name = result.firstNode().firstChild.data;
                                result = xp.doXPath('//navigation/js_code');
                                if (result.firstNode()){
                                    showTopNav(result_id, navigation_id);
                                    var js_code = result.firstNode().firstChild.data;
                                    result = xp.doXPath('//count');
                                    js_code += "\nsearchResult_" + navigation_id + " = " + object_name + ";\n";
                                    if (result.firstNode()){
                                        var results = result.firstNode().firstChild.data;
                                        js_code += "searchResult_" + navigation_id + ".setResults(" + results + ");\n";
                                    }
                                    //js_code += "\nsearchResult_" + navigation_id + ".setResultId('" + result_id + "');\n";
                                    js_code += "\nsearchResult_" + navigation_id + ".clearPreloadedPages();\n";
                                    js_code += "\nsearchResult_" + navigation_id + ".preloadPage(1);\n";
                                    eval(js_code);
                                }
                            }
                        }
                    }
                    else {
                        hideTopNav(result_id);
                    }
                }
                if ($(".source_list_widget").length > 0){
                    //alert(flavour_id);
                    $(".source_list_widget").treeview({
                        animated:"fast"
                    });
                }
                $('#nav_load_' + result_id).hide();
                if (add_tab == 'true'){
                    var tab_id = 'result_' + source_id;
                    result = xp.doXPath('//tab_id');
                    if (result.firstNode()){
                        tab_id = result.firstNode().firstChild.data;
                    }

                    result = xp.doXPath('//controls');
                    if (result.firstNode()){
                        var controls = result.firstNode().firstChild.data;
                        var flavour_id = result_id.replace(/^html_result_(.*)$/, '$1');
                        $('#controls_part_' + flavour_id).html(controls);
                    }

                    $tabs.tabs("add", '#' + tab_id, title);
                }
                else {
                    var id = $tabs[0].getAttribute('id');
                    var $panel = $('#' + result_id).parent();
                    $panel.appendTo($('#' + id));
                }
                if ($(".source_list_widget").length > 0){
                    var flavour_id = result_id.replace(/^news_(.*)$/, '$1');
                    setCombosHeight(flavour_id);
                }
            }
            else {
        //alert('test');
        }
        }
    }
    else tariqaAlert(response.error, 'Error', TYPE_ALERT_ERROR);
}

function setCombosHeight(flavour_id){
    var containers = $('.resultContainer');
    for (var _i = 0; _i < containers.length; _i++){
        if (containers[_i].childNodes.length < 4){
            containers[_i].style.height = '300px';
        }
    }
    if ($('#sources_list_' + flavour_id).length > 0){
        if ($('#sources_list_' + flavour_id)[0].style.display != 'none'){
            if ($('#sources_list_' + flavour_id).innerHeight() != 0){
                if (typeof(TABS_SET[flavour_id]) == 'undefined' || TABS_SET[flavour_id] == null){
                    var el2 = $('#sources_list_' + flavour_id);
                    var h2 = el2.innerHeight();

                    var cond = _isFF ? ($('#sources_list_' + flavour_id + ' > div > ul > li').length > 23) : h2 >= 600;

                    if (cond){
                        el2.children().first().next()[0].style.height = '600px';
                        //el2[0].style.height = "600px";
                    }

                    TABS_SET[flavour_id] = true;
                }
            }
        }
    }
/*if ($('#sources_list_' + flavour_id).length > 0){
		if ($('#sources_list_' + flavour_id)[0].style.display != 'none'){
			if ($('#sources_list_' + flavour_id).innerHeight() != 0){
				if (typeof(TABS_SET[flavour_id]) == 'undefined' || TABS_SET[flavour_id] == null){
					var el1 = $('#article_controls_' + flavour_id);
					var el2 = $('#sources_list_' + flavour_id);
					var el3 = $('#news_' + flavour_id);
					var h1 = el1.innerHeight();
					var h2 = el2.innerHeight();
					var h3 = el3.innerHeight();

					if (h2 > h3){
						el3[0].style.height = (h1 * 1 + h2 * 1) + "px";
					}
					else {
						el2[0].style.height = (h3 - h2) + "px";
					}

					TABS_SET[flavour_id] = true;
				}
			}
		}
	}*/
}

function showLoading(display, id){
    if (typeof(id) == 'undefined' || id == null) id = 'loading';
    //document.getElementById(id).style.display = display;
    if (display == 'none') $('#' + id).hide();
    else $('#' + id).show();
}

function showLoading2(display, selector){
    if (typeof(display) == 'undefined' || display == null) display = 'loading';
    if (typeof(selector) == 'undefined' || selector == null || selector == ''){
        selector = '#loading';
    }
    if (!display) $(selector).hide();
    else $(selector).show();
}

function articlesSent(){
    //showLoading('none', 'saving');
    showLoading2(false, '.search_saving')
    tariqaAlert(MESSAGES['ARTICLES_SAVED']);
}

function saveSearch(){
    tariqaPrompt(MESSAGES['SEARCH_TITLE'], function(title){
        saveSearchToBriefcase(title, document.getElementById('form_get').value, document.getElementById('form_post').value);
    })
}

function modifySearch(){
    var type = 1, params = document.getElementById('form_post').value;
    var get_data = myDecode(document.getElementById('form_get').value).split('?');
    if (get_data.length >= 2) {
        var values = get_data[1].split('&');
        var key;
        for (var i in values){
            key = values[i].split('=')[0];
            if (key == 'search_type'){
                type = values[i].split('=')[1];
                break;
            }
        }
    }
    js_open('index.php?module=search&type=' + type + '&urldecode=', '_self', 'POST', params);
}

function fullSearch(){
    return false;
}

function rebuildSources(){
    $('#selected_sources')[0].value = '';
    $('#selected_sources_names')[0].value = '';

    $('#selected_sources_ui').children().each(function(){
        var id = $('#selected_sources_ui li')[$('#selected_sources_ui li').index(this)].getAttribute('id');
        id = ($('#selected_sources')[0].value == '' ? '' : ';') + id;
        $('#selected_sources')[0].value += id;
        var text = $('#selected_sources_ui li')[$('#selected_sources_ui li').index(this)].firstChild.data;
        var text = text.replace(/\n/gi, '');
        text = ($('#selected_sources_names')[0].value == '' ? '' : '\n') + text;
        $('#selected_sources_names')[0].value += text;
    });
}

function addSource(id, title){
    var element = document.createElement('li');
    element.setAttribute('id', id);
    element.innerHTML = title;

    $('#selected_sources_ui')[0].appendChild(element);

    rebuildSources();
}

function removeSource(){
    if (selected_sources.length == 0) {
        tariqaAlert(MESSAGES['SELECT_REMOVE_SOURCE'], 'Error', TYPE_ALERT_ERROR);
        return false;
    }

    for (var i in selected_sources){
        $('#' + selected_sources[i]).remove();
    }

    while (selected_sources.length > 0) selected_sources.pop();

    rebuildSources();

    return false;
}

function lexisSearch(){
    var form = $('#lexisnexis_form')[0];
    if (form.query.value == ''){
        tariqaAlert(MESSAGES['INPUT_QUERY'], 'Error', TYPE_ALERT_ERROR);
        return false;
    }

    if (form.results_per_page.value * 1 == 0){
        tariqaAlert(MESSAGES['SELECT_RESULTS_NUMBER'], 'Error', TYPE_ALERT_ERROR);
        return false;
    }

    if (form.selected_sources.value == ''){
        tariqaAlert(MESSAGES['SELECT_REMOVE_SOURCE'], 'Error', TYPE_ALERT_ERROR);
        return false;
    }

    return true;
}

function latestnewsSearch(){
    var form = $('#latestnews_form')[0];

    if (form.results_per_page.value * 1 == 0){
        tariqaAlert(MESSAGES['SELECT_RESULTS_NUMBER'], 'Error', TYPE_ALERT_ERROR);
        return false;
    }

    //if (form.range.value == '') form.range.value = 0;

    return true;
}

function virageSearch(){
    var form = $('#virage_form')[0];

    if (form.query.value == ''){
        form.query.value = '*';
    }

    if (form.results_per_page.value * 1 == 0){
        tariqaAlert(MESSAGES['SELECT_RESULTS_NUMBER'], 'Error', TYPE_ALERT_ERROR);
        return false;
    }

    //if (form.range.value == '') form.range.value = 0;

    return true;
	
}

function aggSearch(type){
    if ($('#feed_' + type).val() * 1 != 0){
	$('#selected_feed_' + type).val($('#feed_' + type).val());
    }
    var form = $('#aggsearch_form')[0];

    if ($('#selected_feed_' + type)[0].value == ''){
        tariqaAlert(MESSAGES['SELECT_FEED'], 'Error', TYPE_ALERT_ERROR);
        return false;
    }

    if (form.results_per_page.value * 1 == 0){
        tariqaAlert(MESSAGES['SELECT_RESULTS_NUMBER'], 'Error', TYPE_ALERT_ERROR);
        return false;
    }

    //if (form.range.value == '') form.range.value = 0;

    return true;
}

function setDateRestrictions(radio_name, what){
    $('#' + radio_name + '_' + what)[0].checked = true;
}

function initLexisNexisSources(){
    $('#sources_tree')
    .jstree({
        'html_data': {
            'ajax':{
                'url': URL(TARIQA_URL, 'module=ajax&action=browseLexisNexisSources&no_root_node=&content_type=text/html'),
                'data': function(n){
                    return {
                        folder_id: n.attr ? n.attr('id') : 'null'
                        };
                }

            }
        },
        'types':{
            'valid_children': ['folder', 'source'],
            'types':{
                'folder': {
                    'valid_children': ['folder', 'source']
                },
                'source': {
                    'max_children': 0,
                    'icon': {
                        'image': 'themes/default/images/iconText.gif'
                    }
                }
            }
        },
        plugins: ['themes', 'html_data', 'types']
    }
    );
}

function initOxanTree(id){
    $('#' + id)
    .jstree({
        'types':{
            'valid_children': ['folder', 'file'],
            'types':{
                'folder': {
                    'valid_children': ['file']
                },
                'file': {
                    'max_children': 0,
                    'icon': {
                        'image': 'themes/default/images/iconText.gif'
                    }
                }
            }
        },
        'ui':{
           'select_limit': 1,
           'disable_selecting_children': true
        },
        plugins: ['themes', 'html_data', 'ui', 'types']
    }
    )
}

function getSelectedId(tree_id){
    var sel = $('#' + tree_id).jstree('get_selected');
    var id = null;
    if (sel.length > 0){
        id = sel.attr('id');
        if (id.substring(0, 2) == 'I_'){
            id = id.substring(6);
        }
        else {
            return null;
        }
    }
    if (id != null){
        return id;
    }

    return null;
}

function oxanSearch(){
    var form = $('#oxan_form')[0];
    /*if (form.query.value == '' && form.oxan_titling.value == ''){
        tariqaAlert(MESSAGES['You have to input at least a free text or a titling'], 'Error', TYPE_ALERT_ERROR);
        return false;
    }*/

    var cid = getSelectedId('countries_tree');
    var tid = getSelectedId('topics_tree');

    if (cid != null){
        $('#selected_country').val(cid);
    }
    if (tid != null){
        $('#selected_topic').val(tid);
    }

    return true;
}

function doChangeStyle(){
    changeStyle('.jstree a', null, 'line-height:16px; height:16px; color:black; white-space:nowrap; text-decoration:none; padding:1px 2px; margin:0;');
}

function displayHelp(id){
    $('#' + id).dialog('open');
}

function correctComboSize(id){
    $('.hjsel_container').each(function(idx){
	if ($(this).width() == 0){
	    $(this).width(400);
	}
    });
    $('.hjsel_options').each(function(idx){
	if ($(this).width() == 0){
	    $(this).width(400);
	}
    });
    $('.hjsel_txtbox').each(function(idx){
	if ($(this).width() != 365){
	    $(this).width(365);
	}
    });

    setTimeout(function(){
	correctComboSize(id)
    }, 300);
}

function initJqueryCombo(id){
    $('#' + id).hyjack_select({
	ddImage: 'themes/default/styles/jquery/hyjack.select/arrow_down.png',
	ddCancel: 'themes/default/styles/jquery/hyjack.select/cancel.png'
    });

    $('.hjsel_options').each(function(idx){
	$(this).height(200);
	$(this).css('overflow-y', 'auto');
    });
    
    correctComboSize(id);
}