<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace tariqa3\SOAP {

	require_once("lib/nusoap/nusoap.php");
	
	/**
	 * DUMMY CLASS (nevers used) TO FORCE IDE TO RECOGNISE WHILE AUTOCOMPLETING CODE
	 * @package tariqa3/SOAP
	 * @author Pascal Havelange, Cosmin Popescu
	 * @copyright © EUROPEAN COMMISSION, 2009-2010
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	class TariqaClient {
		/**
		 * Search for articles in the LatestNews database
		 * @param string $token Session Identifier
		 * @param string $query SQL query
		 * @param float $range Time range in days (you may use fractions!) [OPTIONAL]
		 * @return LatestNewsResultset
		 * */
		public function latestNewsSearch( $token, $query, $range = null ) ;

		/**
		 * Fetch the articles from the LatestNews database
		 * @param string $token Session Identifier
		 * @param LatestNewsResultset $resultset The resultset returned by a latestNewsSearch() operation
		 * @param int $first [OPTIONAL]
		 * @param int $count [OPTIONAL]
		 * @return LatestNewsDocument[]
		 * */
		public function latestNewsFetch( $token, $resultset, $first = null, $count = null ) ;

		/**
		 * Get a LatestNews Document
		 * @param string $token Session Identifier
		 * @param int $id Article ID
		 * @return LatestNewsDocument
		 * */
		public function latestNewsGetDocument( $token, $id ) ;

		/**
		 * Fetch the articles from the LatestNews database
		 * @param string $token Session Identifier
		 * @param string $query SQL query
		 * @param float $range Time range in days (you may use fractions!) [OPTIONAL]
		 * @param int $page_number Which page of articles to fetch [OPTIONAL]
		 * @param int $page_size How many articles should be displayed on each page [OPTIONAL]
		 * @param boolean $paginal If set to true, the results are paginated, else page_number represents the first result, and page_size the number of results [OPTIONAL]
		 * @return Resultset
		 * */
		public function fetchLatestNews( $token, $query, $range = null, $page_number = null, $page_size = null, $paginal = true) ;

		/**
		 * Fetch the articles from the LatestNews database
		 * @param string $token Session Identifier
		 * @param string $id Article ID
		 * @return Article
		 * */
		public function getLatestNewsArticle( $token, $id ) ;

		/**
		 * Get a feed from RSS Aggregator
		 * @param string $token The session identifier
		 * @param int $feed_id The feed identifier
		 * @return RSS_feed
		 * */
		public function GetAggregatedRSSFeed($token, $feed_id);

		/**
		 * Get the list of available feeds from RSS Aggregator
		 * @param string $token The session identifier
		 * @return RSS_feed[]
		 * */
		public function ListAggregatedRSSFeeds($token);

		/**
		 * Get the list of available feeds for a selected country from the RSS aggregator
		 * @param string $token The session identifier
		 * @param Country $country The selected country
		 * @return RSS_feed[]
		 * */
		public function GetCountryAggregatedRSSFeeds($token, $country);

		/**
		 * Get the list of available feeds for a selected theme from the RSS Aggregator
		 * @param string $token The session identifier
		 * @param int $theme_id The selected theme
		 * @return RSS_feed[]
		 * */
		public function GetThemeAggregatedRSSFeeds($token, $theme_id);

		/**
		 * Get an article from the RSS Aggregator
		 * @param string $token The session identifier
		 * @param int $article_id The article identifier
		 * @return RSS_article
		 * */
		public function GetAggregatedRSSArticle($token, $article_id);

		/**
		 * Get the list of available articles from the Aggregator
		 * @param string $token The session identifier
		 * @param int $feed_id The feed identifier (null means all articles) [OPTIONAL]
		 * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
		 * @param int $record_range_from The number of the first article to be retrieved (null means all articles) [OPTIONAL]
		 * @param int $record_range_no The number of the first articles to be retrieved from the first article (null means all articles) [OPTIONAL]
		 * @param int $time_range_count The time range count for articles in days (null means all articles) [OPTIONAL]
		 * @return RSS_article[]
		 * */
		public function ListAggregatedRSSArticles($token, $feed_id = null, $time_range = null, $record_range_from = null, $record_range_no = null, $time_range_count = null);

		/**
		 * Get the number of available articles from the Aggregator
		 * @param string $token The session identifier
		 * @param int $feed_id The feed identifier (null means all articles) [OPTIONAL]
		 * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
		 * @param int $time_range_count The time range count for articles in days (null means all articles) [OPTIONAL]
		 * @return int
		 * */
		public function GetAggregatedRSSArticlesNumber($token, $feed_id = null, $time_range = null, $time_range_count = null);

		/**
		 * Get the list of available articles for a country from the RSS Aggregator
		 * @param string $token The session identifier
		 * @param Country $country The selected country
		 * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
		 * @param int $time_range_count The time range count for articles in days (null means all articles) [OPTIONAL]
		 * @param int $record_range_from The number of the first article to be retrieved (null means all articles) [OPTIONAL]
		 * @param int $record_range_no The number of the first articles to be retrieved from the first article (null means all articles) [OPTIONAL]
		 * @return RSS_article[]
		 * */
		public function GetCountryAggregatedRSSArticles($token, $country, $time_range = null, $time_range_count = null, $record_range_from = null, $record_range_no = null);

		/**
		 * Get the list of available articles for a country from the RSS Aggregator
		 * @param string $token The session identifier
		 * @param Country $country The selected country
		 * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
		 * @param int $time_range_count The time range count for articles in days (null means all articles) [OPTIONAL]
		 * @param int $record_range_from The number of the first article to be retrieved (null means all articles) [OPTIONAL]
		 * @param int $record_range_no The number of the first articles to be retrieved from the first article (null means all articles) [OPTIONAL]
		 * @return int
		 * */
		public function GetCountryAggregatedRSSArticlesNumber($token, $country, $time_range = null, $time_range_count = null, $record_range_from = null, $record_range_no = null);

		/**
		 * Get the list of available articles for a theme
		 * @param string $token The session identifier
		 * @param int $theme_id The selected theme
		 * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
		 * @param int $time_range_count The time range count for articles in days (null means all articles) [OPTIONAL]
		 * @param int $record_range_from The number of the first article to be retrieved (null means all articles) [OPTIONAL]
		 * @param int $record_range_no The number of the first articles to be retrieved from the first article (null means all articles) [OPTIONAL]
		 * @return RSS_article[]
		 * */
		public function GetThemeAggregatedRSSArticles($token, $theme_id, $time_range = null, $time_range_count = null, $record_range_from = null, $record_range_no = null);

		/**
		 * Get a feed from Latestnews Aggregator
		 * @param string $token The session identifier
		 * @param int $feed_id The feed identifier
		 * @return Latestnews_feed
		 * */

		public function GetAggregatedLatestnewsFeed($token, $feed_id);

		/**
		 * Get the list of available feeds from latestnews aggregator
		 * @param string $token The session identifier
		 * @return Latestnews_feed[]
		 * */
		public function ListAggregatedLatestnewsFeeds($token);

		/**
		 * Get the list of available latestnews feeds for a selected country
		 * @param string $token The session identifier
		 * @param Country $country The selected country
		 * @return Latestnews_feed[]
		 * */

		public function GetAggregatedLatestnewsCountryFeeds($token, $country);

		/**
		 * Get the list of available latestnews feeds for a selected theme
		 * @param string $token The session identifier
		 * @param int $theme_id The selected theme
		 * @return Latestnews_feed[]
		 * */

		public function GetAggregatedLatestnewsThemeFeeds($token, $theme_id);

		/**
		 * Get an article from Latestnews Aggregator
		 * @param string $token The session identifier
		 * @param int $article_id The article identifier
		 * @return Latestnews_article
		 * */

		public function GetAggregatedLatestnewsArticle($token, $article_id);

		/**
		 * Get the list of available articles from Latestnews aggregator
		 * @param string $token The session identifier
		 * @param int $feed_id The feed identifier (null means all articles) [OPTIONAL]
		 * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
		 * @param int $record_range_from The number of first article to be retrieved (null means all articles) [OPTIONAL]
		 * @param int $record_range_no The number of articles to be retrieved from the first article(null means all articles) [OPTIONAL]
		 * @param int $time_range_count The number of days starting from time range (null means all articles) [OPTIONAL]
		 * @return Latestnews_article[]
		 * */
		public function ListAggregatedLatestnewsArticles($token, $feed_id = null, $time_range = null, $record_range_from = null, $record_range_no = null, $time_range_count = null);

		/**
		 * Get the number of available articles from Latestnews aggregator
		 * @param string $token The session identifier
		 * @param int $feed_id The feed identifier (null means all articles) [OPTIONAL]
		 * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
		 * @param int $time_range_count The number of days starting from time range (null means all articles) [OPTIONAL]
		 * @return int
		 * */
		public function GetAggregatedLatestnewsArticlesNumber($token, $feed_id = null, $time_range = null, $time_range_count = null);

		/**
		 * Get the number of available latestnews articles for a country
		 * @param string $token The session identifier
		 * @param Country $country The selected country
		 * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
		 * @param int $time_range_count The time range count for articles in days (null means all articles) [OPTIONAL]
		 * @return int
		 * */
		public function GetAggregatedLatestnewsCountryArticlesNumber($token, $country, $time_range = null, $time_range_count = null);

		/**
		 * Get the list of available latestnews articles for a country
		 * @param string $token The session identifier
		 * @param Country $country The selected country
		 * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
		 * @param int $time_range_count The time range count for articles in days (null means all articles) [OPTIONAL]
		 * @param int $record_range_from The number of the first article to be retrieved (null means all articles) [OPTIONAL]
		 * @param int $record_range_no The number of the first articles to be retrieved from the first article (null means all articles) [OPTIONAL]
		 * @return Latestnews_article[]
		 * */
		public function GetAggregatedLatestnewsCountryArticles($token, $country, $time_range = null, $time_range_count = null, $record_range_from = null, $record_range_no = null);

		/**
		 * Get the list of available latestnews articles for a theme
		 * @param string $token The session identifier
		 * @param int $theme_id The selected theme
		 * @param int $time_range The time range for articles in days (null means all articles) [OPTIONAL]
		 * @param int $time_range_count The time range count for articles in days (null means all articles) [OPTIONAL]
		 * @param int $record_range_from The number of the first article to be retrieved (null means all articles) [OPTIONAL]
		 * @param int $record_range_no The number of the first articles to be retrieved from the first article (null means all articles) [OPTIONAL]
		 * @return RSS_article[]
		 * */
		public function GetAggregatedLatestnewsThemeArticles($token, $theme_id, $time_range = null, $time_range_count = null, $record_range_from = null, $record_range_no = null);

		/**
		 * Creates a new RSS Feed
		 * @param string $token The session identifier
		 * @param RSS_feed $feed The new feed to be inserted in the database
		 * @param Country $country The feed country (null if there is not a country for this feed)
		 * @param Theme $theme The feed theme (null if there is not a theme for this feed)
		 * @return boolean
		 * */

		public function CreateAggregatedRSSFeed($token, $feed, $country, $theme);

		/**
		 * Updates an existing RSS Feed
		 * @param string $token The session identifier
		 * @param RSS_feed $feed The new feed to be inserted in the database
		 * @return int (The number of records affected)
		 * */

		public function UpdateAggregatedRSSFeed($token, $feed);

		/**
		 * Deletes a RSS Feed
		 * @param string $token The session identifier
		 * @param int $feed_id The feed identificator
		 * @return boolean
		 * */

		public function DeleteAggregatedRSSFeed($token, $feed_id);

		/**
		 * Creates a new Latestnews Feed
		 * @param string $token The session identifier
		 * @param Latestnews_feed $feed The new feed to be inserted in the database
		 * @param Country $country The feed country (null if there is not a country for this feed)
		 * @param Theme $theme The feed theme (null if there is not a theme for this feed)
		 * @return boolean
		 * */

		public function CreateAggregatedLatestnewsFeed($token, $feed, $country, $theme);

		/**
		 * Updates an existing Latestnews Feed
		 * @param string $token The session identifier
		 * @param Latestnews_feed $feed The new feed to be inserted in the database
		 * @return int (The number of records affected)
		 * */

		public function UpdateAggregatedLatestnewsFeed($token, $feed);

		/**
		 * Deletes a Latestnews Feed
		 * @param string $token The session identifier
		 * @param int $feed_id The feed identificator
		 * @return boolean
		 * */

		public function DeleteAggregatedLatestnewsFeed($token, $feed_id);

		/**
		 * Returns the list of maps for a country
		 * @param string $token The session identifier
		 * @param Country $country The country for which to retrieve the map
		 * @param int $dayRange The days for which to retrieve the maps [OPTIONAL]
		 * @return GlobalAtlas[]
			*/
		public function ListGlobalAtlasMaps($token, $country, $dayRange = null);

		/**
		 * Get the Buzztracker map of a given date
		 * @param string $token Session identifier
		 * @param int $date The date to fetch (unix format timestamp)
		 * @return string[] The First element of the array is the HTML imagemap, the second element is the list of major hotspots
		 * */
		public function fetchBuzztracker( $token, $date ) ;

		/**
		 * Get a list of maps for a given country
		 * @param string $token The session identifier
		 * @param Country $country The country to search for
		 * @param int $day_range The maximum age of the maps in days [OPTIONAL]
		 * @return DMAMap[]
		 * */
		public function GetCountryMaps( $token, $country, $day_range ) ;

		/**
		 * Get the number of articles per day or per hour for the selected countries
		 * @param string $token The session identifier
		 * @param Country[] $countries The countries for which to retrieve the statistics
		 * @param int $type The type of statistics (0 - per day, 1 - per hour)
		 * @param int $startDate The start date (UNIX timestamp format) - null means current day [OPTIONAL]
		 * @param int $endDate The end date (UNIX timestamp format) - null means current day. For type 1 (articles per hour) it will not be considered [OPTIONAL]
		 * @return CountryStatisticsResult[]
		 * */
		private function GetCountryStatistics($token, $countries, $type, $startDate = null, $endDate = null);

		/**
		 * Get the number of articles per day for the selected countries
		 * @param string $token The session identifier
		 * @param Country[] $countries The countries for which to retrieve the statistics
		 * @param int $startDate The start date (UNIX timestamp format) - null means current day [OPTIONAL]
		 * @param int $endDate The end date (UNIX timestamp format) - null means current day. For type 1 (articles per hour) it will not be considered [OPTIONAL]
		 * @return CountryStatisticsResult[]
		 * */
		public function GetCountryStatisticsPerDay($token, $countries, $startDate = null, $endDate = null);

		/**
		 * Get the number of articles per hour for the selected countries
		 * @param string $token The session identifier
		 * @param Country[] $countries The countries for which to retrieve the statistics
		 * @param int $date The date (UNIX timestamp format) - null means current day [OPTIONAL]
		 * @return CountryStatisticsResult[]
		 * */
		public function GetCountryStatisticsPerHour($token, $countries, $date = null);

		/**
		 * Get the master list of countries
		 * @param string $token The session identifier
		 * @param int $continent_id Restricts the list to a given Continent [OPTIONAL]
		 * @param boolean $eu_members_only If true, restricts the list to EU countries, if False, restricts it to NON-EU members [OPTIONAL]
		 * @param boolean $official_only It true, restricts the list to official countries, if False, restricts it to non official countries [OPTIONAL]
		 * @param int $region_id The official region identifier [OPTIONAL]
		 * @return Country[]
		 * */
		public function listCountries( $token, $continent_id = null, $eu_members_only = null, $official_only = null, $region_id = null ) ;

		/**
		 * Get the master list of countries
		 * @param string $token The session identifier
		 * @param int $continent_id Restricts the list to a given Continent [OPTIONAL]
		 * @param boolean $eu_members_only If true, restricts the list to EU countries, if False, restricts it to NON-EU members [OPTIONAL]
		 * @param boolean $official_only It true, restricts the list to official countries, if False, restricts it to non official countries [OPTIONAL]
		 * @return Country2[]
		 * */
		public function listCountries2( $token, $continent_id = null, $eu_members_only = null, $official_only = null ) ;

		/**
		 * Get the information about a country identified by a code
		 * @param string $token The session identifier
		 * @param string $iso2 ISO 3166(2 alpha) [OPTIONAL]
		 * @param string $iso3 ISO 3166(3 alpha) [OPTIONAL]
		 * @param int $isonum ISO 3166(numeric) [OPTIONAL]
		 * @param string $comref E.C. COMREF PriKey [OPTIONAL]
		 * @param string $sysper E.C. SYSPER2 [OPTIONAL]
		 * @param string $iana Internet Assigned Numbers Authority [OPTIONAL]
		 * @param string $ioc International Olympic Committee [OPTIONAL]
		 * @param string $un U.N. International Traffic Distinguished Signs [OPTIONAL]
		 * @param string $itu I.T.U Codes for International Telephone calls [OPTIONAL]
		 * @param string $oxan_id Oxford Analytica's Country Name [OPTIONAL]
		 * @param string $comref_del E.C. COMREF - Delegation Country ID (if it differs from $comref) [OPTIONAL]
		 * @return Country
		 * */
		public function getCountry( $token, $iso2, $iso3, $isonum, $comref, $sysper, $iana, $ioc, $un, $itu, $oxan_id, $comref_del ) ;

		/**
		 * Get the information about a country identified by a code
		 * @param string $iso2 ISO 3166(2 alpha) [OPTIONAL]
		 * @param string $iso3 ISO 3166(3 alpha) [OPTIONAL]
		 * @param int $isonum ISO 3166(numeric) [OPTIONAL]
		 * @param string $comref E.C. COMREF PriKey [OPTIONAL]
		 * @param string $sysper E.C. SYSPER2 [OPTIONAL]
		 * @param string $iana Internet Assigned Numbers Authority [OPTIONAL]
		 * @param string $ioc International Olympic Committee [OPTIONAL]
		 * @param string $un U.N. International Traffic Distinguished Signs [OPTIONAL]
		 * @param string $itu I.T.U Codes for International Telephone calls [OPTIONAL]
		 * @param string $oxan_id Oxford Analytica's Country Name [OPTIONAL]
		 * @param string $comref_del E.C. COMREF - Delegation Country ID (if it differs from $comref) [OPTIONAL]
		 * @return Country
		 * */
		protected function _getCountry( $iso2 = null, $iso3 = null, $isonum = null, $comref = null, $sysper = null, $iana = null, $ioc = null, $un = null, $itu = null, $oxan_id = null, $comref_del = null ) ;

		/**
		 * Get the master list of continents
		 * @param string $token The session identifier
		 * @return Continent[]
		 * */
		public function listContinents( $token ) ;

		/**
		 * Get the information about a continent
		 * @param string $token The session identifier
		 * @param int $continent_id Id of the continent
		 * @return Continent
		 * */
		public function getContinent( $token, $continent_id ) ;

		/**
		 * Get the master list of regions (Regions containing regions I.E: Continents)
		 * @param string $token The session identifier
		 * @param int $level What level of data to fetch (0 ::= Only Main Regions; 1 ::= Main Regions + Sub regions; 2 ::= Main Regions + Sub regions + Countries ) [OPTIONAL]
		 * @return MainRegion[]
		 * */
		public function getRegionList( $token, $level = null ) ;

		/**
		 * Gets a list of the official regions
		 * @param string $token The session identifier
		 * @param int $continent_id The continent identifier [OPTIONAL]
		 * @access public
		 * @return OfficialRegion[]
		 */
		public function listOfficialRegions($token, $continent_id);

		/**
		 * Get the list of all regions
		 * @param string $token The session identifier
		 * @param boolean $fetch_countries If set to true, the method will also return the list of countries belonging to the region (default: false) [OPTIONAL]
		 * @return Region[]
		 * */
		public function listRegions( $token, $fetch_countries = null ) ;

		/**
		 * Get the information about a region
		 * @param string $token The session identifier
		 * @param int $region_id Id of the region
		 * @return Region
		 * */
		public function getRegion( $token, $region_id ) ;

		/**
		 * Get the content of a cluster
		 * @param string $token The session identifier
		 * @param int $cluster_id The cluster identifier
		 * @return Cluster
		 * */

		public function GetCluster($token, $cluster_id);

		/**
		 * Get the list of available clusters
		 * @param string $token The session identifier
		 * @param boolean $fetch_countries If set to true, the method will also return the list of countries belonging to the region (default: false) [OPTIONAL]
		 * @return Cluster[]
		 * */

		public function ListClusters( $token, $fetch_countries = null );

		/**
		 * Get the reliefweb maps for a country
		 * @param string $token The session identifier
		 * @param string $country_id The country ISO2 code
		 * @return ReliefWebMap[]
			*/
		public function GetReliefWebMaps($token, $country_id);

		/**
		 * Get a list of all available delegations (eventually filtered by country)
		 * @param string $token Session identifier
		 * @param Country $country Country filter [OPTIONAL]
		 * @return Delegation[]
		 * */
		public function listDelegations( $token, $country ) ;

		/**
		 * Get a list of all available delegations (eventually filtered on a list of countries)
		 * @param string $token Session identifier
		 * @param Country[] $countries Country list filter
		 * @return Delegation[]
		 * */
		public function listDelegations2( $token, $countries ) ;

		/**
		 * Get information about a delegation
		 * @param string $token Session identifier
		 * @param int $delegation_id Identifier of the delegation
		 * @return Delegation
		 * */
		public function getDelegation( $token, $delegation_id ) ;

		/**
		 * Get the list of personnel working in a given delegation
		 * @param string $token Session identifier
		 * @param int $delegation_id Identifier of the delegation
		 * @return DelegationPersonnel[]
		 * */
		public function getDelegationPersonnel( $token, $delegation_id ) ;

		/**
		 * Get the list of Head of Delegation and Deputy Head of Delegation of a given Delegation
		 * @param string $token Session identifier
		 * @param int $delegation_id Identifier of the delegation
		 * @return DelegationPersonnel[]
		 * */
		public function getHeadsOfDelegation( $token, $delegation_id ) ;

		/**
		 * Get the list of CrisisCorrepondents (eventually filtered on a list of countries)
		 * @param string $token Session Identifier
		 * @param Country[] $countries Country list filter [OPTIONAL]
		 * @return CrisisCorrespondent[]
		 * */
		public function listCrisisCorrespondents( $token, $countries ) ;

		/**
		 * Get the details of the Crisis Correpondent Informations of a specific Delegation
		 * @param string $token Session Identifier
		 * @param Country $country Identifier of the Country
		 * @return CrisisCorrespondent
		 * */
		public function getCrisisCorrespondent( $token, $country ) ;

		/**
		 * Gets the headlines result set from a search result
		 * @param factiva_ContentSearchResult $content The factiva query
		 * @param int $first The first result to fetch
		 * @param int $count The number of results to fetch
		 * @return FactivaContentHeadline[]
		 **/
		private function factivaGetHeadlines($content, $first, $count);

		/**
		 * Search for articles using Factiva
		 * @param string $token Session Identifier
		 * @param FactivaContentQuery $query The factiva query
		 * @return FactivaContentResultSet
		 **/
		public function FactivaContentSearch($token, $query);

		/**
		 * Initializes the factiva client
		 * @return FactivaClient
		 * */
		private function initializeFactivaClient();

		/**
		 * Authenticates and return the controlData
		 * @param FactivaClient $client The factiva client
		 * @param string $user The username
		 * @param string $password The password
		 * @param string $namespace Thenamespace
		 * @param bool $connReused That variable will receive a boolean indicating weither the connection was reused or if a new connection was made
		 * @param bool $freshConnect If set to true, discard existing control data and establish a new session
		 * @return factiva_LoginResultType
		 * */
		private function factivaLogin( $client, $user, $password, $namespace, &$connReused, $freshConnect = false ) ;

		/**
		 * Save the control data into the session files
		 * @param factiva_LoginResultType $login_result Login Result
		 * @return boolean
		 * */
		private function factivaLoginSetControlData( $login_result ) ;

		/**
		 * Return the session file name
		 * @return string
		 * */
		private function factivaLoginGetcontrolDataFileName() ;

		/**
		 * Logout from factiva
		 * @param FactivaClient $client The factiva client
		 * @return void
		 * */
		private function factivaLogout($client) ;

		/**
		 * Deletes the session file
		 * @return boolean
		 * */
		private function factivaLoginClearControlData() ;

		/**
		 * Retrieve the control data from the session files
		 * @return factiva_LoginResultType
		 * */
		public function factivaLoginGetControlData() ;

		/**
		 * Retrieve a factiva document
		 * @param string $token Session Identifier
		 * @param string $accessionNo The document identifier
		 * @return FactivaDocument
		 * */
		public function FactivaGetDocument($token, $accessionNo);

		/**
		 * Search for sources using Factiva
		 * @param string $token Session Identifier
		 * @param FactivaSourceQuery $query The factiva query
		 * @return FactivaSourceResultSet
		 **/
		public function FactivaSourceSearch($token, $query);

		/**
		 * Gets the sources result set from a search result
		 * @param factiva_SourceSearchResult $content The factiva result set
		 * @param int $first The first result to fetch
		 * @param int $count The number of results to fetch
		 * @return FactivaSource[]
		 **/
		private function factivaGetSources($content, $first, $count);

		/**
		 * Search for articles using Google News
		 * @param string $token Session Identifier
		 * @param FactivaSourceGroupQuery $query The factiva query
		 * @return FactivaSourceGroupResultSet
		 **/
		public function FactivaSourceGroupSearch($token, $query);

		/**
		 * Gets the sources groups result set from a search result
		 * @param factiva_SourceGroupSearchResult $content The factiva result set
		 * @param int $first The first result to fetch
		 * @param int $count The number of results to fetch
		 * @return FactivaSourceGroup[]
		 **/
		private function factivaGetSourcesGroups($content, $first, $count);

		/**
		 * Search for articles using Google News
		 * @param string $token Session Identifier
		 * @param GoogleQuery $query Query
		 * @return GoogleResultset
		 **/
		public function googleSearch( $token, $query ) ;

		/**
		 * Fetch the next articles from a Google Search (returns NULL when no more articles are available)
		 * @param string $token Session Identifier
		 * @param GoogleResultset $resultset Resultset
		 * @param int $first The first article [OPTIONAL]
		 * @param int $count Count of articles [OPTIONAL]
		 * @return GoogleResultset
		 **/
		public function googleFetch( $token, $resultset, $first = null, $count = null ) ;

		/**
		 * Search for articles using Google News
		 * @param string $token Session Identifier
		 * @param GoogleQuery $query Query
		 * @return GoogleResultset
		 **/
		protected function _googleSearch( $query ) ;

		/**
		 * Parses a google document
		 * @param string $token The session identifier
		 * @param string $url The document url
		 * @access protected
		 * @return string
		 */
		protected function googleGetDocument($token, $url);

		/**
		 * Get the list of hotspots for a day
		 * @param string $token The session identifier
		 * @param int $day The day for which to retrieve the hotspots (null means the current date) [OPTIONAL]
		 * @return string[] A list of countries iso codes.
		 * */
		public function ListHotSpots($token, $day = null);

		/**
		 * Get the list of hotspots for a day without authentification
		 * @param int $day The day for which to retrieve the hotspots (null means the current date) [OPTIONAL]
		 * @return string[] A list of countries iso codes.
		 * */
		protected function _listHotSpots( $day = null);

		/**
		 * Searches LexisNexis sources
		 * @param string $token The session identifier
		 * @param LexisNexisSourceSearchRequest $query The query for searching the sources
		 * @return LexisNexisSourceSearchResponse
		 */
		public function LexisNexisSourceSearch($token, $query);

		/**
		 * Search LexisNexis datawarehouse, and return a SearchID
		 * @param string $token Session Identifier
		 * @param LexisNexisQuery $query The search query
		 * @return LexisNexisSearchResult
		 * */
		public function LexisNexisSearch( $token, $query ) ;

		/**
		 * Retrieve specific documents in SITE (preview) format
		 * @param string $token Session Identifier
		 * @param string $searchId Contains a unique identifier that identifies the original search.
		 * @param int $begin Identifies the first document to be returned in the response. It must be used in conjunction with end.
		 * @param int $end Identifies the last document to be returned in the response. It must be used in conjunction with begin.
		 * @return LexisNexisDocument[]
		 * */
		public function LexisNexisGetDocuments( $token, $searchId, $begin = 1, $end = 20) ;

		/**
		 * Retrieve specific document in full text
		 * @param string $token Session Identifier
		 * @param string $documentId Document ID
		 * @return LexisNexisDocument
		 * */
		public function LexisNexisGetFullDocument( $token, $documentId ) ;

		/**
		 * Retrieve specific document in full text [WITHOUT CHECKING USER's TOKEN]
		 * @param string $documentId Document ID
		 * @return LexisNexisDocument
		 * */
		protected function _LexisNexisGetFullDocument( $documentId ) ;

		/**
		 * Retrieve a specific attachment [WITHOUT CHECKING USER's TOKEN]
		 * @param string $token Session Identifier
		 * @param string $attachmentId Attachment ID
		 * @return LexisNexisAttachment[]
		 * */
		public function LexisNexisGetAttachments( $token, $attachmentId ) ;

		/**
		 * Retrieve a specific attachment [WITHOUT CHECKING USER's TOKEN]
		 * @param string $attachmentId Attachment ID
		 * @return LexisNexisAttachment[]
		 * */
		protected function _LexisNexisGetAttachments( $attachmentId ) ;

		/**
		 * Establish a connection with the LexisNexis WSK and return the security token (might be cached for performance reasons)
		 * @return string WSK BinarySecurityToken
		 * */
		protected function WSKAuthenticate() ;

		/**
		 * Get a list of available Sources
		 * @param int $folderId [OPTIONAL]
		 * @return WSKBrowseSourcesResponse
		 * */
		protected function WSKBrowseSources( $folderId = null ) ;

		/**
		 * Browse LexisNexis Source Folders
		 * @param string $token Session Identifier
		 * @param int $folderId ID of the folder to browse (if null, the root folder will be browsed) [OPTIONA]
		 * @return LexisNexisBrowseSourcesResponse
		 * */
		public function LexisNexisBrowseSources( $token, $folderId = null ) ;

		/**
		 * Get the Sort Keys available for each row of a LexisNexis SearchResult
		 * @param string $token Session Identifier
		 * @param string $searchId LexisNexis Search ID
		 * @return Pair[]
		 * */
		public function LexisNexisGetSortKeys( $token, $searchId ) ;

		/**
		 * Converts a WSKBrowseSourcesResponse into a LexisNexisBrowseSourcesResponse
		 * @param WSKBrowseSourcesResponse $object Response object
		 * @param int $folderId ID of the folder currently browsed
		 * @return LexisNexisBrowseSourcesResponse
		 */
		protected function WSK2LN_BrowseSourcesResponse( $object, $folderId = null ) ;

		/**
		 * Get the list of available newsletters
		 * @param string $token The session identifier
		 * @param int $category_id The category identifier [OPTIONAL]
		 * @return Newsletter[]
		 * */
		public function ListNewsletters( $token, $category_id = null ) ;

		/**
		 * Get the content of a newsletter
		 * @param string $token The session identifier
		 * @param int $newsletter_id The newsletter identifier
		 * @return Newsletter
		 * */
		public function getNewsletter( $token, $newsletter_id) ;

		/**
		 * Get the list of available newsletters
		 * @param string $token The session identifier
		 * @return Newsletter[]
		 * */
		public function listIndarNewsletters( $token ) ;

		/**
		 * Get the content of a newsletter
		 * @param string $token The session identifier
		 * @param int $newsletter_id The newsletter identifier
		 * @return Newsletter
		 * */
		public function getIndarNewsletter( $token, $newsletter_id) ;

		/**
		 * Lists the newsletters categories
		 * @param string $token The session identifier
		 * @access public
		 * @return NewsletterCategory[]
		 */
		public function listNewslettersCategories($token);

		/**
		 * Gets a newsletter category
		 * @param string $token The session identifier
		 * @param int $category_id The category identifier
		 * @access public
		 * @return NewsletterCategory
		 */
		public function getNewsletterCategory($token, $category_id);

		/**
		 * Tells if an user can edit a newsletter
		 * @param string $token The session identifier
		 * @param string $user_id The user identifier
		 * @param int[] $newsletter_ids An array of newsletter identifiers
		 * @access public
		 * @return int[]
		 */
		public function canEditNewsletter($token, $user_id, $newsletter_ids);

		/**
		 * Tells if an user can edit a newsletter category
		 * @param string $token The session identifier
		 * @param string $user_id The user identifier
		 * @param int[] $category_ids An array of newsletter categories identifiers
		 * @access public
		 * @return int[]
		 */
		public function canEditNewsletterCategory($token, $user_id, $category_ids);

		/**
		 * Saves or updates a newsletter into the database database (for insert, just set the newsletter_id to null)
		 * @param string $token The session identifier
		 * @param Newsletter $newsletter The newsletter
		 * @access public
		 * @return int
		 */
		public function saveNewsletter($token, $newsletter);

		/**
		 * Deletes a newsletter
		 * @param string $token The session identifier
		 * @param int $newsletter_id The newsletter identifier
		 * @access public
		 * @return boolean
		 */
		public function deleteNewsletter($token, $newsletter_id);

		/**
		 * Authenticate with Oxford Analytica
		 * @param string $token Session Identifier
		 * @return string[] The oxan cookies
		 
		 * */
		protected function oxanAuthenticate( $token ) ;

		/**
		 * Parse a page from Oxford Analytica
		 * @param string $html The html page
		 * @return OxfordAnalyticaDocument
		 
		 * */
		protected function oxanParsePage( $html ) ;

		/**
		 * Fetch a document from the Oxford Analytica engine
		 * @param string $token Session Identifier
		 * @param string $documentId The Oxan document identifier
		 * @return OxfordAnalyticaDocument
		 * */
		public function oxanFetchDocument( $token, $documentId ) ;

		/**
		 * Fetch a document from the Oxford Analytica engine
		 * @param string $token Session Identifier
		 * @param string $documentId The Oxan document identifier
		 * @return OxfordAnalyticaDocument
		 * */
		public function oxanFetchUrl( $token, $relative_url ) ;

		/**
		 * Search Oxford Analytica
		 * @param string $token Session Identifier
		 * @param OxfordAnalyticaSimpleQuery $query
		 * @return OxfordAnalyticaSearchResult
		 * */
		public function oxanSimpleSearch( $token, $query  ) ;

		/**
		 * Search Oxford Analytica
		 * @param string $token Session Identifier
		 * @param OxfordAnalyticaDetailedQuery $query
		 * @return OxfordAnalyticaSearchResult
		 * */
		public function oxanDetailedSearch( $token, $query  ) ;

		/**
		 * Get the URL of a Country Profile page
		 * NOTES:
		 * Oxford Analytica is setup to accept access to its data from TarÃ®qa users
		 * No token is required here, as the user will neeed to be authenticated into TarÃ®qa to be able to proceed!
		 * @param Country $country Country descriptor
		 * @return string
		 * */
		public function oxanCountryProfileURL( $country  ) ;

		/**
		 * This function will transform oxan urls into tariqa urls suitable for the oxan special logon mechanism mechanism
		 * NOTES:
		 * Oxford Analytica is setup to accept access to its data from TarÃ®qa users
		 * No token is required here, as the user will neeed to be authenticated into TarÃ®qa to be able to proceed!
		 * @param string $oxan_url The Oxford Analytica URL
		 * @return string The Tariqa url
		 * */
		public function oxanGateway( $oxan_url ) ;

		/**
		 * Runs a search amongst OxfordAnalytica articles
		 * @param string $token Session Identifier
		 * @param OxfordAnalyticaSimpleQuery|null Simple query or null if detailed query is used
		 * @param OxfordAnalyticaDetailedQuery|null Detailed query or null if simple query is used
		 * @return OxfordAnalyticaSearchResult
		 * */
		protected function oxanSearch( $token, $simpleQuery = null, $detailedQuery = null ) ;

		/**
		 * Get the "static" list of countries as defined in Oxford Analytica documentation
		 * @return MultiPair[]
		 * */
		public function oxanGetStaticCountryList() ;

		/**
		 * Get the "static" list of topics as defined in Oxford Analytica documentation
		 * @return MultiPair[]
		 * */
		public function oxanGetStaticTopicList() ;

		/**
		 * Get the list of available queries for the homepage
		 * @param string $token The session identifier
		 * @return Query[]
		 * */
		public function GetHomepageQueries($token);

		/**
		 * Get the list of available queries for the homepage
		 * @param string $token The session identifier
		 * @return Query[]
		 * */
		public function GetVideoQueries($token);

		/**
		 * Get the list of quicksearch sources
		 * @param string $token The session identifier
		 * @return QuickSearchSource[]
		 * */

		public function ListQuickSearchSources($token);

		/**
		 * Get the content of a source without authentication
		 * @param string $token The session identifier
		 * @param int $source_id The source identifier
		 * @return Source
		 * */

		private function _getSource($token, $source_id);

		/**
		 * Get the content of a source
		 * @param string $token The session identifier
		 * @param int $source_id The source identifier
		 * @return Source
		 * */

		public function GetSource($token, $source_id);

		/**
		 * Get the list of available sources
		 * @param string $token The session identifier
		 * @return Source[]
		 * */

		public function ListSources($token);

		/**
		 * Get the content of flavour
		 * @param string $token The session identifier
		 * @param int $flavour_id The flavour identifier
		 * @return Flavour
		 * */

		public function GetFlavour($token, $flavour_id);

		/**
		 * Get the list of available flavours
		 * @param string $token The session identifier
		 * @return Flavour[]
		 * */

		public function ListFlavours($token);

		/**
		 * Get the content of an engine without authentication
		 * @param string $token The session identifier
		 * @param string $engine_id The engine identifier
		 * @return Engine
		 * */

		public function _getEngine($token, $engine_id);

		/**
		 * Get the content of an engine
		 * @param string $token The session identifier
		 * @param string $engine_id The engine identifier
		 * @return Engine
		 * */

		public function GetEngine($token, $engine_id);

		/**
		 * Get the list of available engines
		 * @param string $token The session identifier
		 * @return Engine[]
		 * */

		public function ListEngines($token);

		/**
		 * Get the content of a query
		 * @param string $token The session identifier
		 * @param int $query_id The query identifier
		 * @param boolean $get_source If set to true, also fetch the source [OPTIONAL]
		 * @param boolean $get_engine If set to true, also fetch the engine [OPTIONAL]
		 * @return Query
		 * */

		public function GetQuery($token, $query_id, $get_source = false, $get_engine = false);

		/**
		 * Get the content of one or more query
		 * @param string $token The session identifier
		 * @param int[] $query_ids A list of query identifiers
		 * @return Query[]
		 * */

		private function _GetQuery($token, $query_ids);

		/**
		 * Get the list of available queries
		 * @param string $token The session identifier
		 * @return Query[]
		 * */

		public function ListQueries($token);

		/**
		 * Get the list of available queries for a defined contry
		 * @param string $token The session identifier
		 * @param Country $country The selected country
		 * @param int $flavour_id The flavour identifier [OPTIONAL]
		 * @return Query[]
		 * */

		public function GetCountryQueries($token, $country, $flavour_id = null);

		/**
		 * Get the list of available queries for a defined region
		 * @param string $token The session identifier
		 * @param int $region_id The selected country
		 * @param int $flavour_id The flavour identifier [OPTIONAL]
		 * @return Query[]
		 * */

		public function GetRegionQueries($token, $region_id, $flavour_id = null);

		/**
		 * Lists the news stickers groups
		 * @param string $token The session identifier
		 * @return NewStickerGroup[]
		 */
		public function ListNewStickerGroups($token);

		/**
		 * List the TV channels category
		 * @param string $token The session identifier
		 * @return TariqaTVChannelCategory[]
		 */
		public function ListTVChannelsCategories($token);

		/**
		 * List the TV channels
		 * @param string $token The session identifier
		 * @param integer $category_id The channel category [OPTIONAL]
		 * @return TariqaTVChannel[]
		 */
		public function ListTVChannels($token, $category_id = null);

		/**
		 * List the Radio channels category
		 * @param string $token The session identifier
		 * @return TariqaRadioChannelCategory[]
		 */
		public function ListRadioChannelsCategories($token);

		/**
		 * List the Radio channels
		 * @param string $token The session identifier
		 * @param integer $category_id The channel category [OPTIONAL]
		 * @return TariqaRadioChannel[]
		 */
		public function ListRadioChannels($token, $category_id = null);

		/**
		 * Checks the validity of a token
		 * @param string $token The session identifier
		 * @return string|false Returns false on error, the userId in case of success
		 * */
		protected function CheckToken( $token ) ;

		/**
		 * Fetch the value of a variable saved in the user's session
		 * @param string $token The session identifier
		 * @param string $key The variable name (255 characters max)
		 * @return string The value of the variable
		 * */
		public function GetUserSessionVariable( $token, $key ) ;

		/**
		 * Fetch the value of a variable saved in the user's session
		 * @param string $token The session identifier
		 * @param string $key The variable name (255 characters max)
		 * @return string The value of the variable
		 * */
		public function GetUserPersistentVariable( $token, $key ) ;

		/**
		 * Save a variable in the user's session
		 * @param string $token The session identifier
		 * @param string $key The variable name (255 characters max)
		 * @param string $value The variable's value
		 * @return boolean
		 * */
		public function SetUserSessionVariable( $token, $key, $value ) ;

		/**
		 * Save a variable in the user's persistent storage
		 * @param string $token The session identifier
		 * @param string $key The variable name (255 characters max)
		 * @param string $value The variable's value
		 * @return boolean
		 * */
		public function SetUserPersistentVariable( $token, $key, $value ) ;

		/**
		 * Save a variable in the user's session
		 * @param string $token The session identifier
		 * @param string $key The variable name (255 characters max)
		 * @param string $value The variable's value
		 * @param boolean $persistent If false (default) look for the value in the session, otherwise look in the persistent data of the user
		 * @return boolean
		 * */
		protected function SetUserVariable( $token, $key, $value, $persistent = false ) ;

		/**
		 * Set all user's session variables at once
		 * @param string $token The session identifier
		 * @param Pair[] $variables The list of variables
		 * @return boolean
		 * */
		public function SetUserSessionVariables( $token, $variables ) ;

		/**
		 * Set all user's persistent variables at once
		 * @param string $token The session identifier
		 * @param Pair[] $variables The list of variables
		 * @return boolean
		 * */
		public function SetUserPersistentVariables( $token, $variables ) ;

		/**
		 * Save all variables in the user's session or persistent storage at once
		 * @param string $token The session identifier
		 * @param Pair[] $variables The list of variables
		 * @param boolean $persistent If false (default) look for the value in the session, otherwise look in the persistent data of the user
		 * @return boolean
		 * */
		protected function SetUserVariables( $token, $variables, $persistent = false ) ;

		/**
		 * Fetch the list of user's session variables
		 * @param string $token The session identifier
		 * @return Pair[] List of variables
		 * */
		public function GetUserSessionVariables( $token) ;

		/**
		 * Fetch the list of user's persistent variables
		 * @param string $token The session identifier
		 * @return Pair[] List of variables
		 * */
		public function GetUserPersistentVariables( $token) ;

		/**
		 * Fetch the value of a variable saved in the server's persistent storage (WITHOUT CHECKING THE SESSION TOKEN)
		 * @param string $key The variable name (255 characters max)
		 * @return string The value of the variable
		 * @access protected
		 * */
		protected function _GetServerVariable( $key ) ;

		/**
		 * Save a variable in the server's persistent storage (WITHOUT CHECKING THE SESSION TOKEN)
		 * @param string $token Session identifier
		 * @param string $key Variable name (255 characters max)
		 * @param string $value Value
		 * @return boolean
		 * @access protected
		 * */
		protected function _SetServerVariable( $key, $value ) ;

		/**
		 * Fetch the list of server variables (WITHOUT CHECKING THE SESSION TOKEN)
		 * @param string $token The session identifier
		 * @return Pair[] List of variables
		 * @access protected
		 * */
		protected function _GetServerVariables() ;
		/**
		 * Set all server variables at once (WITHOUT CHECKING THE SESSION TOKEN)
		 * @param string $token The session identifier
		 * @param Pair[] $variables The list of variables
		 * @return boolean
		 * @access protected
		 * */
		protected function _SetServerVariables( $variables ) ;

		/**
		 * Fetch the value of a variable saved in the server's persistent storage
		 * @param string $token The session identifier
		 * @param string $key The variable name (255 characters max)
		 * @return string The value of the variable
		 * */
		public function GetServerVariable( $token, $key ) ;

		/**
		 * Fetch the list of server variables
		 * @param string $token The session identifier
		 * @return Pair[] List of variables
		 * */
		public function GetServerVariables( $token) ;

		/**
		 * Set all server variables at once
		 * @param string $token The session identifier
		 * @param Pair[] $variables The list of variables
		 * @return boolean
		 * */
		public function SetServerVariables( $token, $variables ) ;

		/**
		 * Save a variable in the server's persistent storage
		 * @param string $token Session identifier
		 * @param string $key Variable name (255 characters max)
		 * @param string $value Value
		 * @return boolean
		 * */
		public function SetServerVariable( $token, $key, $value ) ;

		/**
		 * Gets a list of users from the system cache
		 * @param string $token The session identifier
		 * @param string $department The LDAP departments from which to list the users [OPTIONAL]
		 * @return SystemCacheUser[]
		 */
		public function ListSystemCachedUsers($token, $department = null);

		/**
		 * Get a system cached LDAP user
		 * @param string $token The session identifier
		 * @param string $user_id The user identifier
		 * @return SystemCacheUser
		 */
		public function GetSystemCachedUser($token, $user_id);

		/**
		 * List the LDAP departments from system cache
		 * @param string $token The session identifier
		 * @return string[]
		 */
		public function ListLDAPCachedDepartments($token);

		/**
		 * Get the content of a theme
		 * @param string $token The session identifier
		 * @param int $theme_id The theme identifier
		 * @return Theme
		 * */

		public function GetTheme($token, $theme_id);

		/**
		 * Get the list of available themes
		 * @param string $token The session identifier
		 * @param boolean $no_texts If true, do not fetch the texts [OPTIONAL]
		 * @return Theme[]
		 * */

		public function ListThemes($token, $no_texts = false);

		/**
		 * Sets the short text and long text of a theme
		 * @param string $token The session identifier
		 * @param int $theme_id The theme identifier
		 * @param string $short_text The short text
		 * @param string $long_text The long text
		 * @return boolean
		 * */
		public function SetThemeText($token, $theme_id, $short_text, $long_text);

		/**
		 * Get the list of available queries for a defined contry
		 * @param string $token The session identifier
		 * @param int $theme_id The selected theme identifier
		 * @return Query[]
		 * */

		public function GetThemeQueries($token, $theme_id);

		/**
		 * Sets the user defined query for the theme
		 * @param string $token The session identifier
		 * @param int $theme_id The theme identifier
		 * @param Query $query The query
		 * @return int
		 * */
		public function SetThemeUserDefinedQuery($token, $theme_id, $query);

		/**
		 * Lists the topics for a given theme
		 * @param string $token The session identifier
		 * @param int $theme_id The theme identifier
		 * @return ThemeTopic[]
		 */
		public function ListThemeTopics($token, $theme_id);

		/**
		 * Lists the topics for a given theme
		 * @param string $token The session identifier
		 * @param int $theme_id The theme identifier
		 * @return ThemeTopic[]
		 */
		private function _ListThemeTopics($token, $theme_id);

		/**
		 * Get a topic theme
		 * @param string $token The session identifier
		 * @param int $topic_id The topic identifier
		 * @return ThemeTopic
		 */
		public function GetThemeTopic($token, $topic_id);

		/**
		 * Lists the queries for a theme topic
		 * @param string $token The session identifier
		 * @param int $topic_id The topic identifier
		 * @return TopicQuery[]
		 */
		public function ListTopicQueries($token, $topic_id);

		/**
		 * Lists the queries for a theme topic
		 * @param string $token The session identifier
		 * @param int $topic_id The topic identifier
		 * @return TopicQuery[]
		 */
		private function _ListTopicQueries($token, $topic_id);

		/**
		 * Get a topic query
		 * @param string $token The session identifier
		 * @param int $topic_id The topic identifier
		 * @param int $query_id The query identifier
		 * @return TopicQuery
		 */
		public function GetTopicQuery($token, $topic_id, $query_id);

		/**
		 * List the topics themes with queries
		 * @param string $token The session identifier
		 * @param int $theme_id The theme identifier
		 * @return ThemeTopicCollection[]
		 */
		public function ListThemeTopicsWithQueries($token, $theme_id);

		/**
		 * Lists the theme users
		 * @param string $token The session identifier
		 * @param int $theme_id The theme identifier
		 * @return ThemeUsers
		 */
		public function ListThemeUsers($token, $theme_id);

		/**
		 * Deletes a theme user defined query
		 * @param string $token The session identifier
		 * @param int $theme_id The theme identifier
		 * @return boolean
		 */
		public function DeleteThemeUserDefinedQuery($token, $theme_id);

		/**
		 * Search the Commission's LDAP database by name or user id
		 * @param string $token Session Identifier
		 * @param string $name A portion of the name to search (if not including any wildcards ('*') characters, it will be automatically appended AT THE END of the name)
		 * @param int $max_time Maximum duration of the LDAP request in seconds [OPTIONAL]
		 * @param int $max_results Maximum number of entries returned by the query [OPTIONAL]
		 * @return LDAPResultSet
		 **/
		public function ldapSearch( $token, $name, $max_time, $max_results ) ;

		/**
		 * Search the Commission's LDAP database
		 * @param string $token Session Identifier
		 * @param string $filter LDAP Query
		 * @param int $max_time Maximum duration of the LDAP request in seconds [OPTIONAL]
		 * @param int $max_results Maximum number of entries returned by the query [OPTIONAL]
		 * @return LDAPResultSet
		 **/
		public function ldapFullSearch( $token, $filter, $max_time, $max_results ) ;

		/**
		 * Send an e-mail message to a list of recipients
		 * @param string[] $to
		 * @param string $sujet
		 * @param string $contenu
		 * @param Attachment[] $attachments [OPTIONAL]
		 * @param string[] $cc List of recipients (Carbon copy) [OPTIONAL]
		 * @param string[] $bcc List of recipients (Blind carbon copy) [OPTIONAL]
		 * @return boolean
		 * */
		public function sendMail( $to, $sujet, $contenu, $attachments, $cc, $bcc ) ;

		/**
		 * Fetch a document from the internet
		 * @param WebRequest $request HTTP query
		 * @return WebDocument
		 * @access protected
		 * */
		protected function _fetchUrl( $request ) ;

		/**
		 * Fetch a document from the internet
		 * @param string $token Session identifier
		 * @param WebRequest $request HTTP query
		 * @return WebDocument
		 * */
		public function fetchUrl( $token, $request ) ;

		/**
		 * Fetch a document from the intranet
		 * @param WebRequest $request HTTP query
		 * @return WebDocument
		 * @access protected
		 * */
		private function fetchUrlNoProxy( $token, $request ) ;

		/**
		 * Fetch a document from the intranet
		 * @param WebRequest $request HTTP query
		 * @return WebDocument
		 * @access protected
		 * */
		protected function _fetchUrlNoProxy( $request ) ;

		/**
		 * Retrieve the content of an RSS feed
		 * @param string $token Session Identifier
		 * @param string $url Url of the feed
		 * @param int $first The first article to fetch [OPTIONAL]
		 * @param int $count The number of articles to fetch [OPTIONAL]
		 * @return Channel The Rss Feed's channel and articles
		 * */
		public function fetchRSS( $token, $url, $first = null, $count = null ) ;

		/**
		 * Gets the nymex market share quotations
		 * @param string $token The session identifier
		 * @return NymexQuotation[]
			*/
		public function GetNymexQuotations($token);

		/**
		 * List the crisis room users
		 * @param string $token The session identifier
		 * @return string[]
			*/
		public function ListCrisisRoomUsers($token);

		/**
		 * Get the list of available Channels from the video archive (channels that have records)
		 * @param string $token The session identifier
		 * @param string $channel Channel name (* wildcard supported) [OPTIONAL]
		 * @param int $start_date Start date (unix timestamp) [OPTIONAL]
		 * @param int $end_date End date (unix timestamp) [OPTIONAL]
		 * @param string $title Program title (* wildcard supported) [OPTIONAL]
		 * @return string[]
		 * */
		public function listVideoArchiveChannels( $token, $channel = null, $start_date = null, $end_date = null, $title = null ) ;

		/**
		 * Get the list of available Records from the video archive
		 * @param string $token The session identifier
		 * @param int $first_record Number of the first record to return (default 0) [OPTIONAL]
		 * @param int $record_count Number of records to return (default all) [OPTIONAL]
		 * @param string $channel Channel name (* wildcard supported) [OPTIONAL]
		 * @param int $start_date Start date (unix timestamp) [OPTIONAL]
		 * @param int $end_date End date (unix timestamp) [OPTIONAL]
		 * @param string $title Program title (* wildcard supported) [OPTIONAL]
		 * @return VideoArchiveRecord[]
		 * */
		public function listVideoArchiveRecords( $token, $first_record = null, $record_count = null, $channel = null, $start_date = null, $end_date = null, $title = null ) ;

		/**
		 * Count the number of available Records from the video archive
		 * @param string $token The session identifier
		 * @param string $channel Channel name (* wildcard supported) [OPTIONAL]
		 * @param int $start_date Start date (unix timestamp) [OPTIONAL]
		 * @param int $end_date End date (unix timestamp) [OPTIONAL]
		 * @param string $title Program title (* wildcard supported) [OPTIONAL]
		 * @return int
		 * */
		public function countVideoArchiveRecords( $token, $channel = null, $start_date = null, $end_date = null, $title = null ) ;

		/**
		 * Build the SQL query for Vide Archive Access
		 * @param int $first_record Number of the first record to return (default 0) [OPTIONAL]
		 * @param int $record_count Number of records to return (default all) [OPTIONAL]
		 * @param string $channel Channel name (* wildcard supported) [OPTIONAL]
		 * @param int $start_date Start date (unix timestamp) [OPTIONAL]
		 * @param int $end_date End date (unix timestamp) [OPTIONAL]
		 * @param string $title Program title (* wildcard supported) [OPTIONAL]
		 * @return string
		 * */
		protected function videoArchiveBuildSQLQuery( $first_record = null, $record_count = null, $channel = null, $start_date = null, $end_date = null, $title = null ) ;

		/**
		 * Search for a video in the database using Virage
		 * @param string $token The session identifier
		 * @param VirageSearchQuery $query The query to be executed
		 * @param boolean $completeDocs If set to true, it returns the complete document without the images. Else, it returns only a few fields [OPTIONAL]
		 * @return VirageSearchResult
		 * */
		private function DoVirageSearch($token, $query, $completeDocs = false);

		/**
		 * Search for a video in the database using Virage
		 * @param string $token The session identifier
		 * @param VirageSearchQuery $query The query to be executed
		 * @return VirageSearchResult
		 * */
		public function VirageSearch($token, $query);

		/**
		 * Search for a video in the database using Virage and returns the complete document without the images
		 * @param string $token The session identifier
		 * @param VirageSearchQuery $query The query to be executed
		 * @return VirageSearchResult
		 * */
		public function VirageSearch2($token, $query);

		/**
		 * Get a Virage document
		 * @param string $token The session identifier
		 * @param int $document_id The document identifier
		 * @param boolean $getImages If true, then it also returns the document images
		 * @return VirageDocument
		 * */

		public function VirageGetDocument($token, $document_id, $getImages);

		/**
		 * Get a Virage document images
		 * @param string $token The session identifier
		 * @param int $document_id The document identifier
		 * @return VirageDocumentImages
		 * */

		public function VirageGetDocumentImages($token, $document_id);

		/**
		 * Return a country profile from Wikipedia
		 * @param string $token Security Token
		 * @param Country $country Country object
		 * @return WikipediaCountryProfile
		 */
		public function GetWikipediaCountryProfile( $token, $country ) ;

		/**
		 * Lists the sources for the advanced search
		 * @param string $token The token identifier
		 * @access public
		 * @return AdvancedSearch[]
		*/
		public function ListAdvancedSearchSources($token);

		/**
		 * Get the full text of a video document
		 * @param string $token The session identifier
		 * @param string $document_id The document identifier
		 * @param VirageDocument $document The document [OPTIONAL]
		 * @access public
		 * @return string
		*/
		public function VirageGetFullText($token, $document_id, $document = null);

		/**
		 * Gets all the headlines of a video document
		 * @param string $token The session identifier
		 * @access public
		 * @return VirageHeadline[]
		*/
		public function VirageGetDocumentHeadlines($token);

		/**
		 * Gets the list of words
		 * @param string $token The session identifier
		 * @param string $document_id The document identifier
		 * @param boolean $complete If set to true, get the words for the entire movie [OPTIONAL]
		 * @param VirageDocument $document The document [OPTIONAL]
		 * @access public
		 * @return VirageWord[]
		*/
		public function VirageGetWords($token, $document_id, $complete = true, $document = null);

		/**
		 * Gets all the images from a document
		 * @param string $token The session identifier
		 * @param string $document_id The document identifier
		 * @param string $type The type of image to retrieve (small or big)
		 * @param boolean $getContent If set to false, do not retrieve the image content [OPTIONAL]
		 * @param boolean $cache If set to true, also cache the image [OPTIONAL]
		 * @param VirageDocument $document The document [OPTIONAL]
		 * @access public
		 * @return VirageDocumentImage[]
		*/
		public function VirageGetDocumentAllImages($token, $document_id, $type, $getContent, $cache, $document = null);
	}
}
?>