<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3{

	require_once('tariqa3/modules/sharing/Sharing.class.php');
	
	/**
     * News Article
	 * @author Cosmin Popescu
	 * @copyright © EUROPEAN COMMISSION, 2010
     * @package tariqa3
	 * @license http://ec.europa.eu/idabc/eupl
     */
class Article extends tariqa3Module {

	/**
	 * The selected article
	 * @var DOMDocument
	 * @access private
	 */
	private $article;

	/**
	 * The engine of the article
	 * @var string
	 * @access private
	 */
	private $engine;

	/**
	 * The title of the article
	 * @var string
	 * @access private
	 */
	private $article_title;

	/**
	 * The news configuration array
	 * @var array
	 * @access private
	 */
	private $newsConfig;

	/**
	 * Construct the Module object
	 * @param array $config The multidimentionnal array containing the application's configuration
	 */
	public function __construct( $config ) {
		parent::__construct($config);
		$this->_isMenuable = false;
	}

	/**
	 * Render the module
	 * @return string
	 */
	public function getPageContent() {
		//\MetaNull\Tools\mDump::dumpVariable(statics::$tariqaToken);
		$this->info_setTitle($this->article_title);

		$this->info_setJavascript(array(
		    'scripts/briefcase.js',
		    'scripts/article.js',
		));
		$type = 'new';
		if (array_key_exists('type', $_GET)) $type = $_GET['type'];

		switch ($this->engine){
			case "GoogleBlogs":
			case "GoogleImages":
			case "GoogleNews":
			case "GoogleVideo":
			case "GoogleWeb":
			case "RSS":
			case "Website":
			case "Google":{
				if ($type == 'new') {
					$xsl = 'site';
					$txt = $this->article->saveXML();
					$txt = preg_replace('/[\x00-\x08\x0b\x0c\x0e-\x1f]/', '', $txt);
					$this->article = new \DOMDocument('1.0', 'UTF-8');
					$this->article->loadXML($txt);
					$this->info_setBodyOnLoad('setFrameHeight()');
                                        //$this->info_setBodyOnLoad('getExternalArticleTitle();');
					/*header('Content-Type: text/xml; charset=UTF-8');
					echo $this->article->saveXML();
					die();*/

				}
				else {
                                    if (array_key_exists('force_briefcase', $_GET)){
                                        $xsl = 'intern';
                                    }
                                    else {
                                        $xsl = 'site';
					$this->info_setBodyOnLoad('setFrameHeight()');
                                    }
                                }
			}break;
			/*case "Virage":{
				$this->info_setStyleSheet(array(
					$this->getTemplateFileUrl( 'styles/main.css' ),
				));
				$xpath = new \DOMXPath($this->article);
				
				$currentPosition = 0;
				$rs = $xpath->query('//title');
				if ($rs->length != 0) {
					$title = $rs->item(0)->nodeValue;
					$currentPosition = preg_replace('/[^:]*: (.*)$/i', '\1', $title);
					$currentPosition = round($currentPosition);
				}
				$xsl = "virage";
				$rs = $xpath->query('//id');
				if ($rs->length == 0) return "Document not found";
				$parts = explode(':', $rs->item(0)->nodeValue);
				if (count($parts) == 1){
					$id = $parts[0];
				}
				else {
					$id = $parts[2];
				}
				$words = statics::$tariqaClient->VirageGetWords(statics::$tariqaToken, $id);
				$split_words = array();
				while (count($words) > 0){
					$_w = array_splice($words, 0, 200);
					if (count($words) > 0){
						$_w = array_merge($_w, array_slice($words, 0, 1));
					}
					$innerHTML = '';
					foreach ($_w as $key => $word){
						$innerHTML .= ' <a class="virage_normal" id="word_' . $word->time . '" href="#" onclick="setPosition(' . $word->time . '); return false;">' . $word->word . '</a>';
					}
					$innerHTML = '<div style="width: 100%; text-align: justify">' . $innerHTML . '</div>';
					$split_words[] = array(
						'startTime' => $_w[0]->time,
						'endTime' => $_w[count($_w) - 1]->time,
						'words' => $_w,
						'innerHTML' => $innerHTML
					);
				}

				$words_str = json_encode($split_words);
				$js = <<<js
var chunks;
function loadChunks(){
	chunks = {$words_str};
	getPlayer('VIDEO_IE', 'VIDEO_FF');
	setPosition({$currentPosition});
}
js;
				$this->info_setInlineJavascript($js);
				$this->info_setBodyOnLoad('loadChunks()');
				$this->info_setJavascript(array(
					'/scripts/virage.js',
					'/scripts/commons.js',
					'/scripts/briefcase.js'
				));
			}break;*/
			default:{
				$xsl = 'intern';
			}break;
		}

                if ($xsl == 'intern' && !array_key_exists('print', $_GET)){
                    $tpl = new \MetaNull\Application\MTemplate('m');
                    $tpl->data = $this->translationTable;
                    $tpl->loadTemplate($this->getTemplateFilePath('controls.html'));
                    $title = str_replace("\n", ' ', $this->article_title);
                    $title = str_replace("'", "\\'", $title);
                    $tpl->data['article_title'] = $title;
		    $tpl->data['article_url'] = statics::URL('index.php', $_SERVER['QUERY_STRING'] . '&print=');

                    $xp = new \DOMXPath($this->article);
                    $rs = $xp->query('/article/id');
                    $tpl->data['article_id'] = $rs->item(0)->nodeValue;

                    $node = $this->article->createElement('article_controls');
                    $cdata = $this->article->createCDATASection($tpl->transform());
                    $node->appendChild($cdata);

                    $rs = $xp->query('/article');
                    $rs->item(0)->appendChild($node);
                }

                /*header('Content-Type: text/xml; charset=UTF-8');
		echo $this->article->saveXML();
		die();*/

		$printer = new \MetaNull\Tools\xslTransform($this->article, 'newsPrinter/' . $xsl, \MetaNull\Tools\xslTransform::FORMAT_TEXT, $this->newsConfig);
		return $printer->transform();
	}

        /**
         * Is the article from an external site?
         * @access protected
         * @return boolean
         */
        protected function externalArticle() {
            return substr(strtolower($this->engine), 0, 6) == 'google' || $this->engine == 'RSS' || $this->engine == 'Website';
        }

	/**
	 * At initialisation, request authentication, or throw an exception on failure
	 */
	protected function onInitialize() {
		parent::onInitialize();

		if (array_key_exists('print', $_GET)){
		    $this->setDefaultLayout('empty_page.html');
		    $this->info_setBodyOnLoad("$('#share_results_form').remove(); $('#share_search_form').remove(); window.print();");
		}
		
		$this->newsConfig = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_NEWS_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'news_config');

		if (!array_key_exists('id', $_GET) && !(array_key_exists('oxan_page', $_GET))) {
			error_log('Trying to fetch an article without specifying the type (new or briefcase)');
			return false;
		}
		$db = \tariqa3\statics::open_db_connection($this->config['database']);
		if (!array_key_exists('oxan_page', $_GET)){
		    $id = $db->real_escape_string($_GET['id']);
		}

		$type = 'new';
		if (array_key_exists('type', $_GET)) $type = $_GET['type'];

		if ($type == 'new'){
			if (!$this->canReadArticle($this->user, $id)){
				throw new \MetaNull\Authentication\insufficientPrivilegesException( 'Access to this page is restricted' );
			}
			if (array_key_exists('oxan_page', $_GET)){
			    $id = '';
			    $data = statics::post2array($_SERVER['QUERY_STRING']);
			    foreach ($data as $key => $value){
				if ($key != 'module' && $key != 'type' && $key != 'oxan_page'){
				    $id .= ($id == ''?'':'&') . $key . '=' . $value;
				}
			    }

			    $id = 'OxfordAnalytica:3:' . $_GET['oxan_page'] . ($_GET['oxan_page'] == ''?'':'?') . $id;
			}

			$this->article = newsAdapter::fetchArticle($id, $this->newsConfig);
		}
		else if ($type == 'briefcase'){
			$sql = "select * from `briefcase_content` where `content_id` = '{$id}'";
			$query = $db->mQuery($sql);
			if ($row = $query->fetch_assoc()){
				if ($row["user_id"] != $this->user->user_id) {
					error_log('Access denied to ' . $this->user->user_id . ' to the ' . $id . ' article. ');
					throw new \MetaNull\Authentication\insufficientPrivilegesException( 'Access to this page is restricted' );
				}
				$this->article = new \DOMDocument();
				$this->article->loadXML($row["data"]);
			}
			else {
				throw new \MetaNull\News\articleNotFoundException('The ' . $id . ' article was not found in the briefcase database. ');
			}
		}
		else {
			throw new \MetaNull\News\articleNotFoundException('The ' . $type . ' is not defined for article types.');
		}

		$xpath = new \DOMXPath($this->article);
		$rs = $xpath->query('//engine');
		if ($rs->length == 0){
			throw \MetaNull\News\articleNotFoundException('The engine for the ' . $id . ' article was not set');
		}
		$this->engine = $rs->item(0)->nodeValue;

		$rs = $xpath->query('//extra_headers');
		if ($rs->length != 0){
		    $this->info_setRawHeaders($rs->item(0)->nodeValue);
		}

		$rs = $xpath->query('//title');
		$this->article_title = '';
		if ($rs->length != 0) {
			if ($rs->item(0)->nodeValue != ''){
				$this->article_title = ' - ' . $rs->item(0)->nodeValue;
			}
                        else {
                            $title = preg_replace('/^.*\/([^\/]*)$/U', '\1', $_GET['id']);
                            if ($title != '' && $title != null){
                                $this->article_title = ' - ' . $this->engine . ':' . $title;
                            }
                        }
		}
                $this->article_title = $this->config['application']['name'] . $this->article_title;
		
		$nodes = $this->article->getElementsByTagName('article');
		if ($nodes->length > 0){
			$nodes->item(0)->setAttribute('link1', $this->translate('send_article_to_briefcase'));
			$nodes->item(0)->setAttribute('link2', $this->translate('share_article'));
			$nodes->item(0)->setAttribute('link4', $this->translate('print_article'));
			$base_url = $this->config['application']['url'];
			if (substr($base_url, -1) != '/') {
			    $base_url .= '/';
			}
			$app_url = $this->config['application']['url'];
			if (substr($app_url, -1) != '/') {
			    $app_url .= '/';
			}
			if ($type == 'new'){
			    preg_match_all('/id=([^:]*):([^:]*):([^&]*)/', $_SERVER['QUERY_STRING'], $matches);
			    if (count($matches) >= 4){
				if (count($matches[3]) > 0){
				    $url = $matches[3][0];
				}
			    }
			}
			else if ($type == 'briefcase'){
			    $rs = $xpath->query('//document_id');
			    if ($rs->length > 0){
				$url = \MetaNull\Tools\mTools::rawurlencode($rs->item(0)->nodeValue);
			    }
			}
			$nodes->item(0)->setAttribute('print_link', statics::URL($app_url . 'article/' . $url . '/print-site/'));
			$nodes->item(0)->setAttribute('display', (array_key_exists('print', $_GET)?'none':'inherit'));
                        if (!array_key_exists('force_briefcase', $_GET) && $this->externalArticle() && $type == 'briefcase'){
                            $nodes->item(0)->setAttribute('link3', $this->translate('open_article_from_briefcase'));
                            $nodes->item(0)->setAttribute('link3_id', $_GET['id']);
                        }
			$nodes->item(0)->setAttribute('load_src', $this->config['templates']['baseurl'] . '/' . $this->config['templates']['default'] .
					'/images/ajax-loader-mini.gif');
			$sharing = new Sharing($this->config, $this->translationTable);
			$txt = '<span>' . $sharing->run() . "</span>";
			$doc = new \DOMDocument('1.0', 'UTF-8');
			$txt = str_replace('&nbsp;', ' ', $txt);
			$doc->loadXML($txt);
			$divs = $doc->getElementsByTagName('div');
			$id1 = 0; $id2 = 0;
			for ($i = 0; $i < $divs->length && $id1 == 0 && $id2 == 0; $i++){
				if ($divs->item($i)->getAttribute('id') == 'share_search_form') {
					$id1 = $i;
				}
				if ($divs->item($i)->getAttribute('id') == 'share_results_form') {
					$id2 = $i;
				}
			}
			$root = $nodes->item(0);
			$node = $this->article->createElement('sharing_form');
			$node2 = $this->article->importNode($divs->item($id1), true);
			$node->appendChild($node2);
			$node2 = $this->article->importNode($divs->item($id2), true);
			$node->appendChild($node2);
			$root->appendChild($node);
			$this->setMoreInfos($sharing->getInfo());
			$js_title = str_replace("\n", ' ', $this->article_title);
			$js_title = str_replace("'", "\\'", $js_title);
			$nodes->item(0)->setAttribute("js_title", $js_title);
		}
	}

	/**
	 * Process all requests (this is the default module)
	 */
	public function canProcessRequest() {
		return array_key_exists('module', $_GET) && $_GET['module'] == 'article';
	}

	/**
	 * Returns the short name of the module (used by menus)
	 * @return string
	 */
	public function getName(){return 'article';}
	/**
	 * Returns the title of the module (used in html/head/title)
	 * @return string
	 */
	public function getTitle(){return '';}
	/**
	 * Returns the description of the module (used in html/head/description)
	 * @return string
	 */
	public function getDescription(){return '';}
	/**
	 * Returns the url to the current module (used in menus)
	 * @return string
	 */
	public function getLink() {
		return statics::URL( 'index.php', array( 'module'=>$this->getName(), 'type' => $_GET['type'], 'id' => $_GET['id'] ), true );
	}

	/**
	 * Return the items of the current breadcrumb path
	 * @return tariqa3ModuleDescriptor[]
	 */
	public function getBreadCrumb() {
		$breadCrumb = array();
		$b = new tariqa3ModuleDescriptor($this);
		$b->label = $this->translate('module/tabTitle');
		$breadCrumb[] = $b;
		return $breadCrumb;
	}
}

}

?>