<?php

/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 * 	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 * 	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3 {

require_once('BriefcaseFolder.class.php');

/**
 * Briefcase module
 * @author Cosmin Popescu, Pascal Havelange
 * @copyright © EUROPEAN COMMISSION, 2010
 * @package tariqa3
 * @license http://ec.europa.eu/idabc/eupl
 */
class Briefcase extends tariqa3Module {
    /**
     * The article type
     * @var int
     * @access public
     */
    const TYPE_ARTICLE = 1;

    /**
     * The document type
     * @var int

     */
    const TYPE_DOCUMENT = 2;

    /**
     * The location type
     * @var int

     */
    const TYPE_LOCATION = 3;

    /**
     * The search type
     * @var int

     */
    const TYPE_SEARCH = 4;

    /**
     * The shared object type
     * @var int

     */
    const TYPE_SHARED_OBJECT = 5;

    /**
     * The checkbox selection type
     * @var string
     */
    const CHECKBOX_SEL_TYPE = 'checkbox';

    /**
     * The ui selection type
     * @var string
     */
    const UI_SEL_TYPE = 'ui';

    /**
     * The briefcase sort by date
     * @var string
     */
    const BRIEFCASE_DATE_SORT = 'date';

    /**
     * The briefcase sort by date
     * @var string
     */
    const BRIEFCASE_TITLE_SORT = 'title';

    /**
     * The briefcase sort by date
     * @var string
     */
    const BRIEFCASE_PUBLISHER_SORT = 'publisher';

    /**
     * The selection type
     * @var string
     * @access protected
     */
    protected $selection = null;
    /**
     * The sorting of the briefcase
     * @var string
     * @access protected
     */
    protected $sorting;

    /**
     * If true, then display the archive
     * @var boolean
     * @access protected
     */
    protected $archive = false;

    /**
     * If set, then only display this folder
     * @var int
     * @access protected
     */
    protected $folder_id = null;

    /**
     * Construct the Module object
     * @param array $config The multidimentionnal array containing the application's configuration
     */
    public function __construct($config) {
	if (array_key_exists('archive', $_GET)) {
	    $this->archive = true;
	}
	parent::__construct($config);
	if ($this->archive) {
	    $this->config['jquery']['theme'] = 'cupertino';
	}
	if (array_key_exists('folder_id', $_GET)) {
	    $this->folder_id = $_GET['folder_id'];
	}
    }

    /**
     * Sorts the briefcase
     * @param string $criteria The criteria to sort
     * @param int $type_id The type of items to sort;
     * @param tariqaUser The user identifier
     * @param mMysql $db The database conneection
     * @access protected
     * @static
     * @return void
     */
    public static function sortBriefcase($criteria, $type_id, $user, $db) {
	$sql = "create temporary table briefcase_sorting(content_id int primary key, data varchar(255) default '', display_order int)";
	$db->mQuery($sql);

	$sql = "select content_id, data from briefcase_content where user_id = '{$user->user_id}' and type_id = '{$type_id}' order by content_id";

	$query = $db->mQuery($sql);
	while ($row = $query->fetch_assoc()) {
	    switch ($criteria) {
		case self::BRIEFCASE_DATE_SORT:
		    $pattern = '/<date>([^<]*)<\/date>/i';
		    break;
		case self::BRIEFCASE_PUBLISHER_SORT:
		    $pattern = '/<publisher><!\[CDATA\[([^\]|\]^\]]*)\]\]><\/publisher>/';
		    break;
		case self::BRIEFCASE_TITLE_SORT:
		    $pattern = '/<title><!\[CDATA\[([^\]|\]^\]]*)\]\]><\/title>/';
		    break;
	    }

	    preg_match($pattern, $row['data'], $data);
	    if (count($data) > 0) {
		$data = $data[1];
	    }
	    if ($criteria == self::BRIEFCASE_DATE_SORT) {
		$data = strtotime($data);

		if ($data == "") {
		    $data = 0;
		}

		$data = time() + 365 * 100 * 24 * 60 * 60 - $data;
	    } else if ($criteria == self::BRIEFCASE_TITLE_SORT && $data == '') {
		$data = '_';
	    }
	    $data = $db->real_escape_string($data);
	    $sql = "insert into briefcase_sorting values('{$row['content_id']}', '{$data}', '0')";
	    $db->mQuery($sql);
	}

	$sql = "set @i = 0";
	$db->mQuery($sql);

	$sql = "update briefcase_sorting set display_order = @i := @i + 10 order by data, content_id";
	$db->mQuery($sql);

	$sql = "update briefcase_content b inner join briefcase_sorting s using(content_id) set b.display_order = s.display_order";
	$db->mQuery($sql);

	$sql = "drop table briefcase_sorting";
	$db->mQuery($sql);
    }

    /**
     * Initializes the module
     * @access public
     * @return void
     */
    public function onInitialize() {
	parent::onInitialize();
	/*$content_id = null;
	if (array_key_exists('unique_id', $_GET)){
	    $content_id = $this->db->get_value('briefcase_content', 'content_id', 'item_id = "' . $this->db->real_escape_string($_GET['unique_id']) .
		'" and user_id = "' . $this->user->user_id . '"');
	}

	if (array_key_exists('content_id', $_GET)){
	    $content_id = $_GET['content_id'];
	}

	if ($content_id != null && is_numeric($content_id)){
	    //$this->info_setBodyOnLoad('briefcaseOpen(' . $content_id . ')');
	    $this->redirect($content_id);
	}*/

	if (array_key_exists('export', $_GET)) {
	    $this->setDefaultLayout('module.html');
	}

	$this->sorting = $this->user->get_preference('general/briefcase_sorting');
	if ($this->sorting == null) {
	    $this->sorting = self::BRIEFCASE_DATE_SORT;
	}

	if (array_key_exists('sort_briefcase', $_GET)) {
	    $this->sorting = $_GET['sort_briefcase'];
	    self::sortBriefcase($this->sorting, 1, $this->user, $this->db);
	}
	$this->user->set_preference('general/sorting', $this->sorting, $this->db);
	$_SESSION['pages'] = array();
	$_SESSION['pages'][] = 'http://d02di0414709:8085/index.php?module=briefcase&content_id=808&redirect=briefcase';
	$_SESSION['pages'][] = 'http://d02di0414709:8085/index.php?module=briefcase&content_id=764&redirect=briefcase';
	$_SESSION['pages'][] = 'http://d02di0414709:8085/index.php?module=briefcase&content_id=809&redirect=briefcase';
    }

    /**
     * Render the module
     * @return string
     */
    public function getPageContent() {
	if (array_key_exists('export', $_GET)) {
	    require_once($this->config['modules']['base'] . '/../search/searchEngine.class.php');
	    return $this->export($_GET['type'], $_GET['export']);
	}
	$tpl = new \MetaNull\Application\MTemplate('m');
	$tpl->data = $this->translationTable;

	$formats = $this->config['briefcase']['export'];
	$tpl->data['formats'] = array();
	foreach ($formats as $key => $value) {
	    $tpl->data['formats'][] = array(
		    'value' => $this->translate('module/export_briefcase_' . $key),
		    'id' => $key
	    );
	}

	//This page needs JQuery UI capabilities, so return an error if JQuery is disabled
	if (!$this->config['jquery']['use-it']) {
	    $tpl->loadTemplate($this->getTemplateFilePath('error.html'));

	    return $tpl->transform();
	}

	$tpl->loadTemplate($this->getTemplateFilePath('main.html'));

	$this->info_setJavascript(
		array(
		/* 'scripts/jquery.cookie.js',
                          'scripts/jquery.treeview.min.js', */
		    'scripts/jquery.jstree.js',
		    'scripts/jquery.cookie.js',
		    'scripts/briefcase.js',
		    'scripts/jquery.contextmenu.js',
		)
	);

	$this->info_setStylesheet(
		array(
		    $this->getThemeFileUrl('styles/jquery/tree/jquery.treeview.css'),
		    $this->getThemeFileUrl('styles/jquery/contextmenu/contextmenu.css'),
		)
	);

	$selection = $this->user->get_preference('general/selection_type');
	if ($selection == null) {
	    $selection = self::CHECKBOX_SEL_TYPE;
	}

	$this->info_setBodyOnLoad('initTree(selection_' . $selection . '); setHelpSize(); initContextMenu();');

	$tpl->data['briefcase_content_types'] = array();
	//For each type of briefcase content, generate a JQuery tree.
	$sql = "select * from `briefcase_contents_types` order by name";
	$query = $this->db->mQuery($sql);
	while ($row = $query->fetch_assoc()) {
	    $folder = new BriefcaseFolder($this->db, $this->user->user_id, $row['type_id'], $this->archive, $this->folder_id);
	    $tpl->data['briefcase_content_types'][] = array(
		    'html' => $folder->folderHTML($row['name'], null, 'root_folder')
	    );
	}
	$query->close();

	$tpl->data['module_name'] = $this->getName();

	$sql = "select * from briefcase_contents_types order by type_id";
	$query = $this->db->mQuery($sql);

	$tpl->data['content_types'] = array();

	while ($row = $query->fetch_assoc()) {
	    $options = self::selectFolderForm(null, $row['type_id'], 0, $this->user, $this->db, $this->translationTable, true, true);
	    $tpl->data['content_types'][] = array(
		    'name' => $row['name'],
		    'options' => $options,
	    );
	}

	$tpl->data['date_selected'] = ($this->sorting == self::BRIEFCASE_DATE_SORT ? 'selected="selected"' : '');
	$tpl->data['title_selected'] = ($this->sorting == self::BRIEFCASE_TITLE_SORT ? 'selected="selected"' : '');
	$tpl->data['publisher_selected'] = ($this->sorting == self::BRIEFCASE_PUBLISHER_SORT ? 'selected="selected"' : '');

	$tpl->data['mode_archive'] = false;
	$tpl->data['mode_prod'] = false;

	if ($this->archive) {
	    $tpl->data['mode_archive'] = true;
	}
	else {
	    $tpl->data['mode_prod'] = true;
	}

	require_once('tariqa3/modules/sharing/Sharing.class.php');

	$sharing = new Sharing($this->config, $this->translationTable);
	$tpl->data['sharing_form'] = $sharing->run();
	$this->setMoreInfos($sharing->getInfo());

	return $tpl->transform();
    }

    /**
     * String the HTML tags using xslt
     * @param string $html The html string
     * @access protected
     * @return string
     */
    protected function strip_tags($html) {
	//\MetaNull\Tools\mDump::dumpVariable($html);
	$config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_NEWS_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'news_config');
	$html = "<root>{$html}</root>";
	$xslt = new \MetaNull\Tools\xslTransform($html, 'html/strip_tags', \MetaNull\Tools\xslTransform::FORMAT_TEXT, $config);
	return $xslt->transform();
    }

    /**
     * Gets the folder sql condition
     * @param int $folder_id The folder identifier
     * @param array $selected_ids The selected articles
     * @param string $field_name The field to check [OPTIONAL]
     * @access protected
     * @return string
     */
    protected function getExportFolderCond($folder_id, $selected_ids, $field_name = 'folder_id') {
	$folder_cond = ($folder_id == null ? $field_name . ' is null' : ($folder_id == -1 ? $field_name . ' <> -1 or ' . $field_name . ' is null' : $field_name . ' = ' . $folder_id));

	if ($folder_id == null) {
	    foreach ($selected_ids as $id) {
		if (substr($id, 0, 2) == 'I_') {
		    $fid = $this->db->get_value('briefcase_content', 'folder_id', 'content_id = ' . substr($id, 2));
		    if (is_numeric($fid)) {
			$folder_cond .= ' or folder_id = ' . $fid;
		    }
		}
	    }
	}

	return "(({$folder_cond}) and (archived = 'n' or archived is null))";
    }

    /**
     * Exports the briefcase
     * @param string $format The output format - default PDF [OPTIONAL]
     * @param string $folder_id The folder identifier: -1 if you don't want to consider the folders, null for root, folder_id for any folder [OPTIONAL]
     * @param array $selected_ids The list of selected items to export [OPTIONAL]
     * @access protected
     * @return boolean
     */
    protected function exportArticles($format = \MetaNull\Tools\xslTransform::FORMAT_PDF, $folder_id = null, $selected_ids = null) {
	$type_id = self::TYPE_ARTICLE;

	if ($folder_id == null &&  !array_key_exists('export-folders', $this->config['briefcase']['export'][$_GET['export']])) {
	    $folder_id = -1;
	}

	$doc = new \DOMDocument('1.0', 'UTF-8');

	$add_folder = true;
	if ($folder_id != -1 && $folder_id != null && $selected_ids != null) {
	    $add_folder = false;
	    foreach ($selected_ids as $id) {
		if (substr($id, 0, 2) == 'F_') {
		    if (statics::findSubTree($this->db, $folder_id, substr($id, 2))) {
			$add_folder = true;
			break;
		    }
		}
	    }
	}

	if (!$add_folder) {
	    return false;
	}

	$root = $doc->createElement('articles');
	$root->setAttribute('user', $this->user->user_id);
	$root->setAttribute('date', time());
	$root->setAttribute('page_breaks', (array_key_exists('include_page_breaks', $_GET) ? 'on' : 'off'));

	$sel_cond = ' content_id <> -1 ';
	if ($selected_ids != null) {
	    $sel_cond = '';
	    foreach ($selected_ids as $id) {
		if (substr($id, 0, 2) == 'F_') {
		    $sel_cond .= ( $sel_cond == '' ? '' : ' or ') . 'folder_id = ' . $this->db->real_escape_string(substr($id, 2)) .
			' or subfolder(folder_id, ' . $this->db->real_escape_string(substr($id, 2)) . ')';
		} else if (substr($id, 0, 2) == 'I_') {
		    $sel_cond .= ( $sel_cond == '' ? '' : ' or ') . 'content_id = ' . $this->db->real_escape_string(substr($id, 2));
		}
	    }
	}

	if ($folder_id != -1) {
	    $folder_cond = ($folder_id == null ? 'parent_id is null' : 'parent_id = ' . $folder_id);
	    $folder_name = ($folder_id == null ? '_root_' : $this->db->get_value('briefcase_folders', 'name', 'folder_id = ' . $folder_id));

	    $sql = <<<sql
select
	folder_id
from briefcase_folders
	where {$folder_cond} and user_id = '{$this->user->user_id}' and type_id = '{$type_id}' and archived = 'n'
order by
	name
sql;

	    $root->setAttribute('folder', $folder_name);
	    $query = $this->db->mQuery($sql);

	    while ($row = $query->fetch_assoc()) {
		$result = $this->exportArticles($format, $row['folder_id'], $selected_ids);
		if ($result != false) {
		    $collection = $result->getElementsByTagName('articles');
		    if ($collection->length > 0) {
			$node = $doc->importNode($collection->item(0), true);
			$root->appendChild($node);
		    }
		}
	    }
	}

	$folder_cond = $this->getExportFolderCond($folder_id, $selected_ids, 'folder_id');

	$sql = <<<sql
select
		c.content_id, c.data, c.item_id, c.name
from
		briefcase_content c left join briefcase_folders f using(folder_id)
where
	c.type_id = '{$type_id}' and c.user_id = '{$this->user->user_id}' and ({$folder_cond}) and ({$sel_cond})
order by display_order, content_id
sql;

	$query = $this->db->mQuery($sql);

	$pdf_documents = '';

	while ($row = $query->fetch_assoc()) {
	    $xml = new \DOMDocument('1.0', 'UTF-8');
	    $xml->loadXML($row['data']);
	    $xpath = new \DOMXPath($xml);
	    $nodes = $xpath->query('//title');
	    $title = $row['name'];
	    //$title = $nodes->item(0)->nodeValue;
	    $nodes = $xpath->query('//date');
	    $date = $nodes->item(0)->nodeValue;
	    $nodes = $xpath->query('//publisher');
	    $publisher = $nodes->item(0)->nodeValue;
	    $nodes = $xpath->query('//body');
	    $body = $nodes->item(0)->nodeValue;
	    $id = $row['content_id'];

	    /*if ($title == '') {
		$matches = array();
		preg_match('/<title[^>]*>([^<]*)<\/title>/i', $body, $matches);
		if (count($matches) == 0) {
		    $pattern = '/<meta\b[ ]*[^n|n^a|na^m|nam^e]*\b[ ]*name="title"[^>]*>/i';
		    preg_match($pattern, $body, $matches);

		    if (count($matches) != 0) {
			preg_match('/<meta\b[ ]*[^c|c^o|co^n|con^t|cont^e|conte^n|conten^t]*\b[ ]*content="([^"]*)"[^>]*>/i', $matches[0]);
			if (count($matches) != 0) {
			    $title = $matches[1];
			}
		    }
		} else {
		    $title = $matches[1];
		}
	    }*/

	    //$encoding = mb_detect_encoding($body, 'UTF-8');
	    $encoding = 'UTF-8';

	    //$body = iconv($encoding, 'utf-8//TRANSLIT', $body );
	    $body = iconv($encoding, 'UTF-8//IGNORE', $body);

	    $tidy_opt = array(
		    "indent" => true,
		    "show-body-only" => true,
		    "input-encoding" => $encoding,
		    "output-encoding" => "UTF-8",
		    "output-xhtml" => true,
		    "word-2000" => true,
		    "lower-literals" => true,
		    "drop-font-tags" => true,
		    "drop-proprietary-attributes" => true,
		    "wrap" => 160,
		    'preserve-entities' => true,
		    "newline" => "LF",
		    "doctype" => "omit",
	    );

	    $tidy = tidy_parse_string($body, $tidy_opt);
	    tidy_clean_repair($tidy);

	    $body = $tidy->value;
	    //$body = str_replace("&nbsp;", " ", $body);
	    //$body = preg_replace('/&([^;]+);/', '<xsl:text disable-output-escaping="yes">&amp;\1;</xsl:text>', $body);
	    $body = str_replace("&", "&amp;", $body);

	    $body = $this->strip_tags($body);

	    $body = preg_replace('/&amp;([^;]+);/', '&\1;', $body);

	    $body = "<root>" . $body . '</root>';

	    if ($body != "<root></root>" || $title != "") {
		$article = $doc->createElement('article');
		$main_url = $this->config['application']['url'];
		if (substr($main_url, -1) != '/')
		    $main_url .= '/';
		$article->appendChild(search\searchEngine::addNode('title', $title, $doc, true));
		$article->appendChild(search\searchEngine::addNode('url', $main_url . 'index.php?module=article&amp;type=briefcase&amp;id=' . $id, $doc, false));
		$article->appendChild(search\searchEngine::addNode('date', $date, $doc, false));
		$article->appendChild(search\searchEngine::addNode('id', $id, $doc, false));
		$article->appendChild(search\searchEngine::addNode('publisher', $publisher, $doc, false));
		$doc2 = new \DOMDocument('1.0', 'UTF-8');
		$doc2->resolveExternals = false;
		$doc2->substituteEntities = false;
		$doc2->encoding = 'UTF-8';
		//$body = utf8_encode($body);
		$body = preg_replace('/[\x00-\x08\x0b\x0c\x0e-\x1f]/', '', $body);
		$body = preg_replace('/\]+>+/', '', $body);
		$body = '<?xml version="1.0" encoding="UTF-8"?>' . $body;
		//\MetaNull\Tools\mDump::dumpVariable($body);
		$doc2->loadHTML($body);
		//\MetaNull\Tools\mDump::dumpVariable($doc2->saveXML());
		$doc2->resolveExternals = false;
		$doc2->substituteEntities = false;
		$doc2->encoding = 'UTF-8';
		$node = $doc->importNode($doc2->getElementsByTagName('root')->item(0), true);
		$nbody = $doc->createElement('body');
		$nbody->appendChild($node);
		//$article->appendChild(search\searchEngine::addNode('body', $body, $doc, true));
		$article->appendChild($nbody);

		$root->appendChild($article);
	    }
	    else {
		$url_parts = explode(':', $row['item_id'], 3);
		if (count($url_parts) == 3) {
		    $url = $url_parts[2];
		} else {
		    $url = $main_url . 'index.php?module=article&amp;type=briefcase&amp;id=' . $id;
		}
		$pdf_documents .= ( $pdf_documents == '' ? '' : '<br/>') . "<a href=\"" . $url . "\">" . $url . "</a>";
	    }
	}

	if ($pdf_documents != '') {
	    if ($folder_id == -1) {
		$document_nodes = $doc->createElement('article');
		$document_nodes->appendChild(search\searchEngine::addNode('title', $this->translate('generic_pdf_title'), $doc, true));
		$document_nodes->appendChild(search\searchEngine::addNode('url', '', $doc, false));
		$document_nodes->appendChild(search\searchEngine::addNode('date', '', $doc, false));
		$document_nodes->appendChild(search\searchEngine::addNode('id', 'exported_pdf_documents', $doc, false));
		$document_nodes->appendChild(search\searchEngine::addNode('publisher', '', $doc, false));
		$pdf_documents = "<root>{$pdf_documents}</root>";

		$doc2 = new \DOMDocument('1.0', 'UTF-8');
		$doc2->resolveExternals = false;
		$doc2->substituteEntities = false;
		$doc2->encoding = 'UTF-8';
		$pdf_documents = '<?xml version="1.0" encoding="UTF-8"?>' . $pdf_documents;
		$doc2->loadHTML($pdf_documents);
		$doc2->resolveExternals = false;
		$doc2->substituteEntities = false;
		$doc2->encoding = 'UTF-8';
		$node = $doc->importNode($doc2->getElementsByTagName('root')->item(0), true);
		$nbody = $doc->createElement('body');
		$nbody->appendChild($node);
		$document_nodes->appendChild($nbody);
		//$document_nodes->appendChild(search\searchEngine::addNode('body', $pdf_documents, $doc, false));

		$root->appendChild($document_nodes);
	    } else {
		$folder = $doc->createElement('articles');
		$folder->setAttribute('folder', $this->translate('generic_pdf_title'));
		$folder->setAttribute('user', $this->user->user_id);
		$folder->setAttribute('date', time());
		$articles = explode('<br/>', $pdf_documents);
		foreach ($articles as $article) {
		    $url = preg_replace('/<a[^>]*>([^<]*)<\/a>/', '\1', $article);
		    $document = $doc->createElement('article');
		    $document->appendChild(search\searchEngine::addNode('title', $url, $doc, true));
		    $document->appendChild(search\searchEngine::addNode('url', '', $doc, false));
		    $document->appendChild(search\searchEngine::addNode('date', '', $doc, false));
		    $document->appendChild(search\searchEngine::addNode('id', 'exported_pdf_documents', $doc, false));
		    $document->appendChild(search\searchEngine::addNode('publisher', '', $doc, false));

		    $doc2 = new \DOMDocument('1.0', 'UTF-8');
		    $doc2->resolveExternals = false;
		    $doc2->substituteEntities = false;
		    $doc2->encoding = 'UTF-8';
		    $article = "<root>{$article}</root>";
		    $body = '<?xml version="1.0" encoding="UTF-8"?>' . $article;
		    $doc2->loadHTML($body);
		    $doc2->resolveExternals = false;
		    $doc2->substituteEntities = false;
		    $doc2->encoding = 'UTF-8';
		    $node = $doc->importNode($doc2->getElementsByTagName('root')->item(0), true);
		    $nbody = $doc->createElement('body');
		    $nbody->appendChild($node);
		    $document->appendChild($nbody);

		    $folder->appendChild($document);
		}
		$root->appendChild($folder);
	    }
	}

	$doc->appendChild($root);

	if ($folder_id != null && $folder_id != -1) {
	    return $doc;
	}

	$doc->resolveExternals = false;
	$doc->substituteEntities = false;
	$doc->encoding = 'UTF-8';

	/* $txt = $doc->saveXML();
              $txt = str_replace('<![CDATA[', '', $txt);
              $txt = preg_replace('/\]+>+/', '', $txt);
              $doc = new \DOMDocument('1.0', 'UTF-8');
              $doc->loadHTML($txt);
              $doc->resolveExternals = false;
              $doc->substituteEntities = false;
              $doc->encoding = 'UTF-8';
              $doc->loadXML($txt); */

	/* header("Content-Type: text/xml; charset=UTF-8");
              echo $doc->saveXML();
              die(); */

	$xsl = $this->config['briefcase']['export'][$format]['xsl'];

	//\MetaNull\Tools\mDump::dumpVariable($doc->saveXML());

	$newsConfig = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_NEWS_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'news_config');
	$printer = new \MetaNull\Tools\xslTransform($doc, 'newsPrinter/' . $xsl, $this->config['briefcase']['export'][$format]['format'], $newsConfig);

	$result = $printer->transform();
	//\MetaNull\Tools\mDump::dumpVariable($doc->saveXML());
	header("Content-Length: " . strlen($result));
	header( "Content-Disposition: inline; filename=\"".$this->config['briefcase']['export'][$_GET['export']]['file-name']."\"" );
	header( "Last-Modified: " . date("r") );
	header('Pragma: no-cache');
	header('Pragma: hack');
	header('Expires: ' . date( "r", time()-86400 ));
	header('Cache-Control: no-store, no-cache, must-revalidate, public');     // HTTP/1.1
	header('Cache-Control: pre-check=0, post-check=0, max-age=0');    // HTTP/1.1
	return $result;
    }

    /**
     * Retrieves the for for selecting a folder
     * @param int $folder_id The folder identifier
     * @param int $type_id The type identifier
     * @param int $level The current level
     * @param tariqaUser $user The user identifier
     * @param mMysql $db The database connection
     * @param array $translationTable The translation matrix
     * @param boolean $just_options If set to true, return only the option's HTML code [OPTIONAL]
     * @param boolean $archive If set to true, returned the archived folders [OPTIONAL]
     * @access public
     * @static
     * @return string | array
     */
    public static function selectFolderForm($folder_id, $type_id, $level, $user, $db, $translationTable, $just_options = false, $archive = false) {
	$cond_folder = ($folder_id == null ? 'parent_id is null' : 'parent_id = ' . $folder_id);
	$result = array();

	$cond_archive = "archived = 'n'";
	if ($archive) {
	    $cond_archive = "archived = 'y'";
	}

	$spaces = '';
	for ($i = 0; $i < $level; $i++)
	    $spaces .= '&nbsp;&nbsp;';

	$sql = <<<sql
select * from briefcase_folders
    where {$cond_archive} and {$cond_folder} and user_id = '{$user->user_id}' and type_id = {$type_id}
sql;

	$query = $db->mQuery($sql);
	while ($row = $query->fetch_assoc()) {
	    $result[] = array(
		    'id' => $row['folder_id'],
		    'name' => $row['name'],
		    'spaces' => $spaces
	    );

	    $result = array_merge($result, self::selectFolderForm($row['folder_id'], $type_id, $level + 1, $user, $db, $translationTable, $just_options, $archive));
	}

	if ($folder_id != null) {
	    return $result;
	}

	$tpl = new \MetaNull\Application\MTemplate('m');
	$config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
	$tpl->loadTemplate($config['templates']['base'] . '/' . $config['templates']['default'] . '/modules/tariqa3/Briefcase/select_folder' .
		($just_options?'_options':'') . '.html');
	$tpl->data = $translationTable;
	$tpl->data['briefcase_folders'] = $result;

	return $tpl->transform();
    }

    /**
     * Process all requests (this is the default module)
     */
    public function canProcessRequest() {

	return array_key_exists('module', $_GET) && $_GET['module'] == $this->getName();
    }

    /**
     * Returns the name of the class (what it should appear in the menu
     * @access public
     * @return string
     */
    public function getName() {
	return 'briefcase';
    }

    /**
     * Returns the title of the page
     * @access public
     * @return string
     */
    public function getTitle() {
	return 'Tariqa 3 Briefcase';
    }

    /**
     * Returns the description of the page
     * @access public
     * @return string
     */
    public function getDescription() {
	return 'The user briefcase (it can contain saved articles, maps, locations or links)';
    }

    /**
     * Gets the link of the module
     * @access public
     * @return string
     */
    public function getLink() {
	return statics::URL('index.php', 'module=' . $this->getName());
    }

    /**
     * Return the items of the current breadcrumb path
     * @return tariqa3ModuleDescriptor[]
     */
    public function getBreadCrumb() {
	$breadCrumb = array();
	$breadCrumb[] = new tariqa3ModuleDescriptor($this);
	return $breadCrumb;
    }

    /**
     * Tells if a user can modify a folder
     * @param string $user_id The user identifier
     * @param int $folder_id The folder identifier
     * @param mMysql $db A database connection
     * @access public
     * @static
     * @return boolean
     */
    public static function canModifyFolder($user_id, $folder_id, $db) {
	$owner_id = $db->get_value('briefcase_folders', 'user_id', 'folder_id = "' . $db->real_escape_string($folder_id) . '"');
	if ($owner_id != $user_id)
	    return false;
	return true;
    }

    /**
     * Moves an item to a folder
     * @param string $user_id The user identifier
     * @param mMysql $db The database connection
     * @param int $source_id The source identifier
     * @param int $dest_id The folder destination identifier
     * @param int $dest_type The destination type
     * @access public
     * @static
     * @return boolean
     */
    public static function moveItemToFolder($user_id, $db, $source_id, $dest_id, $dest_type) {
	if ($dest_id != null) {
	    if (!self::canModifyFolder($user_id, $dest_id, $db)) {
		throw new \Exception("The user " . $user_id . " cannot modify the folder with the ID " . $dest_id);
	    }
	}

	$source_id = $db->real_escape_string($source_id);
	if ($dest_id == null) {
	    $dest_id = 'null';

	} else {
	    $dest_id = $db->real_escape_string($dest_id);
	}

	$dest_type = $db->real_escape_string($dest_type);

	$sql = "update briefcase_content set folder_id = {$dest_id}, type_id = {$dest_type} where content_id = {$source_id}";
	$db->mQuery($sql);

	return true;
    }

    /**
     * Change the type of a folder
     * @param int $folder_id The folder identifier
     * @param int $type_id The new type identifier
     * @param mMysql $db The database connection
     * @access protected
     * @static
     * @return void
     */
    protected static function changeFolderType($folder_id, $type_id, $db) {
	$type_id = $db->real_escape_string($type_id);
	$folder_id = $db->real_escape_string($folder_id);
	$sql = "update briefcase_content set type_id = '{$type_id}' where folder_id = '{$folder_id}'";
	$db->mQuery($sql);

	$sql = "update briefcase_folders set type_id = '{$type_id}' where folder_id = '{$folder_id}'";
	$db->mQuery($sql);

	$sql = "select * from briefcase_folders where parent_id = '{$folder_id}'";
	$query = $db->mQuery($sql);

	while ($row = $query->fetch_assoc()) {
	    self::changeFolderType($row['folder_id'], $type_id, $db);
	}
    }

    /**
     * Moves a folder to another folder
     * @param string $user_id The user identifier
     * @param mMysql $db The database connection
     * @param int $source_id The source folder identifier
     * @param int $dest_id The destination folder identifier
     * @param int $dest_type The destination type
     * @access public
     * @static
     * @return boolean
     */
    public static function moveFolder($user_id, $db, $source_id, $dest_id, $dest_type) {
	if ($dest_id != null) {
	    if (!self::canModifyFolder($user_id, $dest_id, $db)) {
		throw new \Exception("The user " . $user_id . " cannot modify the folder with the ID " . $dest_id);
	    }
	}

	$source_id = $db->real_escape_string($source_id);
	if ($dest_id == null) {
	    $dest_id = 'null';
	} else {
	    $dest_id = $db->real_escape_string($dest_id);
	}

	$dest_type = $db->real_escape_string($dest_type);

	if ($dest_type != $db->get_value('briefcase_folders', 'type_id', 'folder_id = ' . $source_id)) {
	    self::changeFolderType($source_id, $dest_type, $db);
	}

	$sql = "update briefcase_folders set parent_id = {$dest_id}, type_id = {$dest_type} where folder_id = {$source_id}";
	$db->mQuery($sql);

	return true;
    }

    /**
     * Archives a folder
     * @param string $user_id The user identifier
     * @param mMysql $db The database connection
     * @param int $folder_id the folder identifier
     * @access public
     * @static
     * @return boolean
     */
    public static function archiveFolder($user_id, $db, $folder_id) {
	if (!self::canModifyFolder($user_id, $folder_id, $db)) {
	    throw new \Exception("The user " . $user_id . " cannot modify the folder with the ID " . $dest_id);
	}

	$m = date('m');
	$y = date('Y');

	$q = floor(($m - 1) / 3) + 1;
	$name = $y . ' - Q' . $q;

	$folder_id = $db->real_escape_string($folder_id);

	$type_id = $db->get_value('briefcase_folders', 'type_id', 'folder_id = ' . $folder_id);

	$parent_id = self::createFolderIfNotExists($name, $type_id, $user_id, $db);

	$sql = "update briefcase_folders set archived = 'y' where folder_id = '{$parent_id}'";
	$db->mQuery($sql);

	if ($parent_id == $folder_id) {
	    $parent_id = 'null';
	}

	$sql = "update briefcase_folders set archived = 'y', parent_id = {$parent_id} where folder_id = '{$folder_id}'";
	$db->mQuery($sql);

	self::setArchived($db, $folder_id, 'y');

	return true;
    }

    /**
     * Set the subfolders archived attribute
     * @param mMysql $db The database connection
     * @param int $folder_id The folder identifier
     * @param $value The value of the parameter
     * @access protected
     * @return void
     */
    protected function setArchived($db, $folder_id, $value) {
	$sql = "update briefcase_folders set archived = '{$value}' where parent_id = '{$folder_id}'";
	$db->mQuery($sql);

	$sql = "select * from briefcase_folders where parent_id = '{$folder_id}'";
	$query = $db->mQuery($sql);
	while ($row = $query->fetch_assoc()) {
	    self::setArchived($db, $row['folder_id'], $value);
	}
    }

    /**
     * Archives a folder
     * @param string $user_id The user identifier
     * @param mMysql $db The database connection
     * @param int $folder_id the folder identifier
     * @access public
     * @static
     * @return boolean
     */
    public static function unarchiveFolder($user_id, $db, $folder_id) {
	if (!self::canModifyFolder($user_id, $folder_id, $db)) {
	    throw new \Exception("The user " . $user_id . " cannot modify the folder with the ID " . $dest_id);
	}

	$sql = "update briefcase_folders set archived = 'n', parent_id = null where folder_id = '{$folder_id}'";
	$db->mQuery($sql);

	self::setArchived($db, $folder_id, 'n');

	return true;
    }

    /**
     * Empty a folder
     * @param string $user_id The user identifier
     * @param mMysql $db The database connection
     * @param int $folder_id The folder identifier
     * @param int $type_id The type identifier
     * @param boolean $subfolders If true, also delete the subfolders
     * @access public
     * @static
     * @return void
     */
    public static function emptyFolder($user_id, $db, $folder_id, $type_id, $subfolders) {
	if ($folder_id != null) {
	    if (!self::canModifyFolder($user_id, $folder_id, $db)) {
		throw new \Exception("The user " . $user_id . " cannot modify the folder with the ID " . $folder_id);
	    }
	    $folder_id = ' = "' . $db->real_escape_string($folder_id) . '"';
	} else {
	    $folder_id = 'is null';
	}

	$_type_id = ($type_id == null ? ' = "' . $db->real_escape_string($db->get_value('briefcase_folders', 'type_id', 'folder_id ' . $folder_id)) . '"' : ' = "' . $db->real_escape_string($type_id) . '"');

	$sql = "delete from briefcase_content where folder_id {$folder_id} and type_id {$_type_id} and user_id = '{$user_id}'";
	$db->mQuery($sql);

	if ($subfolders) {
	    $sql = "select * from briefcase_folders where parent_id {$folder_id} and type_id {$_type_id} and user_id = '{$user_id}'";
	    $query = $db->mQuery($sql);

	    while ($row = $query->fetch_assoc()) {
		self::emptyFolder($user_id, $db, $row['folder_id'], $type_id, $subfolders);
	    }

	    $sql = "delete from briefcase_folders where parent_id {$folder_id} and type_id {$_type_id} and user_id = '{$user_id}'";
	    $db->mQuery($sql);
	}
    }

    /**
     * Adds a folder to the briefcase
     * @param string $user_id The user identifier
     * @param mMysql $db The database connection
     * @param int $_parent_id The parent identifier
     * @param int $type_id The type identifier
     * @param string $name The name of the new folder
     * @access public
     * @static
     * @return boolean
     */
    public static function addFolder($user_id, $db, $parent_id, $type_id, $name) {

	if ($parent_id != null) {
	    if (!self::canModifyFolder($user_id, $parent_id, $db)) {
		throw new \Exception("The user " . $user_id . " cannot modify the folder with the ID " . $parent_id);
	    }
	} else {
	    $parent_id = 'null';
	}

	$name = $db->real_escape_string($name);

	$sql = <<<sql
	insert into
		`briefcase_folders`
			(`name`, `description`, `parent_id`, `type_id`, `user_id`)
	values
		('{$name}', null, {$parent_id}, '{$type_id}', '{$user_id}')
sql;

	$db->mQuery($sql);

	$new_id = $db->last_insert_id();
	$folder = new BriefcaseFolder($db, $user_id, $type_id);

	return "<new_html><![CDATA[" . $folder->folderHTML($name, $new_id) . "]]></new_html><new_id>{$new_id}</new_id>";
    }

    /**
     * Deletes a briefcase folder
     * @param string $user_id The user identifier
     * @param mMysql $db The database connection
     * @param int $folder_id The folder identifier
     * @access public
     * @static
     * @return string
     */
    public static function deleteFolder($user_id, $db, $folder_id) {
	if (!self::canModifyFolder($user_id, $folder_id, $db)) {
	    throw new \Exception("The user " . $user_id . " cannot modify the folder with the ID " . $folder_id);
	}

	$id = $db->real_escape_string($folder_id);

	$sql = <<<sql
delete from `briefcase_content` where folder_id = '{$id}';
sql;

	$db->mQuery($sql);

	$sql = <<<sql
select * from `briefcase_folders` where parent_id = '{$id}'
sql;

	$query = $db->mQuery($sql);
	while ($row = $query->fetch_assoc()) {
	    self::deleteFolder($user_id, $db, $row['folder_id']);
	}
	$query->close();

	$sql = "delete from `briefcase_folders` where folder_id = '{$id}'";
	$db->mQuery($sql);

	return "<deleted>ok</deleted>";
    }

    /**
     * Renames a folder
     * @param string $user_id The user identifier
     * @param mMysql $db The database connection
     * @param int $folder_id The folder identifier
     * @param string $new_name The new name of the folder
     * @access public
     * @static
     * @return string
     */
    public static function renameFolder($user_id, $db, $folder_id, $new_name) {
	if (!self::canModifyFolder($user_id, $folder_id, $db)) {
	    throw new \Exception("The user " . $user_id . " cannot modify the folder with the ID " . $folder_id);
	}

	$name = $db->real_escape_string($new_name);
	$folder_id = $db->real_escape_string($folder_id);

	$sql = "update `briefcase_folders` set name = '{$name}' where folder_id = '{$folder_id}'";
	$db->mQuery($sql);

	return "<renamed>ok</renamed><new_name>{$new_name}</new_name>";
    }

    /**
     * Saves an article to the briefcase
     * @param string $user_id The user identifier
     * @param mMysql $db The database connection
     * @param int $folder_id The folder identifier
     * @param int $type_id The type identifier
     * @param string $article_id The article identifier
     * @param string $title The article title (for google engine) [OPTIONAL]
     * @access public
     * @static
     * @return int|string
     */
    public static function doSaveArticle($user_id, $db, $folder_id, $type_id, $article_id, $title = null) {
	$article_id = str_replace('%26', '&', $article_id);
	$newsConfig = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_NEWS_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'news_config');
	//Check the type of the content
	switch ($type_id) {
	    case self::TYPE_ARTICLE : {
		    //Set the folder identifier (this should com through the HTTP request
		    if ($folder_id != 'null')
			$folder_id = $db->real_escape_string($folder_id);
		    $user_id = $db->real_escape_string($user_id);
		    $_id = $db->real_escape_string($article_id);

		    //If the article has not been allready added
		    if ($db->count_rows('briefcase_content', "`item_id` = '{$_id}' and `user_id` = '{$user_id}'") == 0) {
			//Fetch the article
			$doc = newsAdapter::fetchArticle($_id, $newsConfig);
			$xpath = new \DOMXPath($doc);
			$engine = '';
			//Check the engine (for Google, the title will also come through the HTTP request)
			$rs = $xpath->query('//engine');
			if ($rs->length == 0) {
			    throw new \Exception('Article not fetched correctly. ID:' . $_id);
			}
			$engine = $rs->item(0)->nodeValue;
			if (strtolower(substr($engine, 0, 6)) == 'google' || $engine == 'RSS') {
			    $title = $db->real_escape_string($_GET['title']);
			} else {
			    //Fetch the article title
			    $title = '';
			    $rs = $xpath->query('//title');
			    if ($rs->length != 0) {
				$title = $db->real_escape_string($rs->item(0)->nodeValue);
			    }
			}

			//Fetch the article body
			$id = $db->real_escape_string($article_id);
			$data = $doc->saveXML();

			if ($engine == "GoogleBlogs" || $engine == "GoogleImages" || $engine == "GoogleNews"
				|| $engine == "GoogleVideo" || $engine == "GoogleWeb" || $engine == "RSS" ||
				$engine == "Website" || "Google") {
			    /* $parts = explode(':', $article_id, 3);
                                  $url = $parts[2];
                                  $url = preg_replace('/^http:\/\/([^\/^\?]*)[\/|\?].*$/', 'http://\1', $url);
                                  $pattern = '/<a (.*)href[ ]*=[ |[ ]*["|' . "'" . ']]*([^h|h^t|ht^t|htt^p][^ ^"^' . "'" . ']*)[ |"|' . "'" . ']([^>]*)>/i';
                                  $data1 = preg_replace($pattern, '<a \1 href="' . $url . '\2" \3>', $data);
                                  while ($data1 != $data){
                                  $data = $data1;
                                  $data1 = preg_replace($pattern, '<a \1 href="' . $url . '\2" \3>', $data);
                                  }
                                  $pattern = '/<img (.*)src[ ]*=[ |[ ]*["|' . "'" . ']]*([^h|h^t|ht^t|htt^p][^ ^"^' . "'" . ']*)[ |"|' . "'" . ']([^>]*)>/i';
                                  $data1 = preg_replace($pattern, '<img \1 src="' . $url . '\2" \3>', $data);
                                  while ($data1 != $data){
                                  $data = $data1;
                                  $data1 = preg_replace($pattern, '<img \1 src="' . $url . '\2" \3>', $data);
                                  } */
			    //$data = str_replace("\n", "", $data);
			    /* $data = preg_replace('/<script[^>]*>.*?<\/script>/si', '', $data);
                                  $data = preg_replace('/<script[^>]*>/si', '', $data);
                                  preg_match('/<head[^>]*>(.*?)<\/head>/si', $data, $matches);
                                  if (count($matches) == 2){
                                  $data = str_replace("</article>", "<extra_headers><![CDATA[{$matches[1]}]]></extra_headers></article>", $data);
                                  $data = preg_replace('/<head[^>]*>.*?<\/head>/si', '', $data);
                                  }
                                  $data = preg_replace('/<html[^>]*>/', '', $data);
                                  $data = str_replace('</html>', '', $data);
                                  $data = str_replace('</publisher><body>', '</!publisher!><!body!>', $data);
                                  $data = preg_replace('/<body[^>]*>/si', '', $data);
                                  $data = preg_replace('/<body[^>]*>/si', '', $data);
                                  $data = preg_replace('/<\/body>/si', '', $data, 1);
                                  $data = str_replace('</!publisher!><!body!>', '</publisher><body>', $data); */
			}

			$data = $db->real_escape_string($data);

			//Insert it into the database
			$length = strlen($data);

			$sql = <<<sql
insert into
	`briefcase_content`(`name`, `type_id`, `folder_id`, `data`, `item_id`, `user_id`, `length`)
values
	('{$title}', '{$type_id}', {$folder_id}, '{$data}', '{$id}', '{$user_id}', '{$length}');
sql;

			$db->mQuery($sql);

			//self::sortBriefcase($criteria, $type_id, $user, $db)
		    } else {
			return "The article " . $article_id . " has allready been added";
		    }
		}break

		;
	    case self::TYPE_DOCUMENT: {

		}break

		;
	    case self::TYPE_LOCATION: {

		}break

		;
	    case self::TYPE_SEARCH: {

		}break

		;
	    case self::TYPE_SHARED_OBJECT: {

		}break

		;
	}

	return $db->last_insert_id();
    }

    /**
     * Saves a free text to the briefcase
     * @param string $user_id The user identifier
     * @param mMysql $db The database connection
     * @param int $folder_id The folder identifier
     * @param string $title The title of the text
     * @param string $text The text
     * @access public
     * @static
     * @return int|string
     */
    public static function doSaveText($user_id, $db, $folder_id, $title, $text) {
	//$text = \MetaNull\Tools\mTools::rawurldecode($text);
	//Set the folder identifier (this should com through the HTTP request
	if ($folder_id != 'null')
	    $folder_id = $db->real_escape_string($folder_id);

	$user_id = $db->real_escape_string($user_id);

	$tpl = new \MetaNull\Application\MTemplate('m');
	$tpl->loadTemplate('themes/default/modules/tariqa3/Briefcase/userText.xml');
	$tpl->data['id'] = time();
	$tpl->data['document_id'] = 'd_' . time();
	$tpl->data['title'] = $title;
	$tpl->data['date'] = date('r');
	$tpl->data['body'] = "<![CDATA[" . $text . "]]>";

	$data = $tpl->transform();
	$data = $db->real_escape_string($data);

	//Insert it into the database
	$length = strlen($data);

	$sql = <<<sql
insert into
`briefcase_content`(`name`, `type_id`, `folder_id`, `data`, `item_id`, `user_id`, `length`)
values
('{$title}', '1', {$folder_id}, '{$data}', '{$tpl->data['id']}', '{$user_id}', '{$length}');
sql;

	$db->mQuery($sql);

	return $db->last_insert_id();
    }

    /**
     * Deletes an item from the briefcase
     * @param string $user_id The user identifier
     * @param mMysql $db The database connection
     * @param int $content_id The content identifier
     * @access public
     * @static
     * @return string
     */
    public static function deleteContent($user_id, $db, $content_id) {
	$content_id = $db->real_escape_string($content_id);
	$owner_id = $db->get_value('briefcase_content', 'user_id', 'content_id = "' . $content_id . '"');

	if ($owner_id != $user_id) {
	    throw new \Exception("The user " . $user_id . " does not own the briefcase content " . $content_id);
	}

	$sql = "delete from briefcase_content where content_id = '{$content_id}'";
	$db->mQuery($sql);

	return "<deleted>ok</deleted>";
    }

    /**
     * Renames a content item
     * @param string $user_id The user identifier
     * @param mMysql $db The database connection
     * @param int $content_id The content identifier
     * @param string $new_name The new name
     * @access public
     * @static
     * @return string
     */
    public static function renameContent($user_id, $db, $content_id, $new_name) {
	$content_id = $db->real_escape_string($content_id);
	$owner_id = $db->get_value('briefcase_content', 'user_id', 'content_id = "' . $content_id . '"');

	if ($owner_id != $user_id) {
	    throw new \Exception("The user " . $user_id . " does not own the briefcase content " . $content_id);
	}

	$name = $db->real_escape_string($new_name);

	$sql = "update briefcase_content set name = '{$name}' where content_id = '{$content_id}'";
	$db->mQuery($sql);

	return "<renamed>ok</renamed><new_name>{$new_name}</new_name>";
    }

    /**
     * Saves a search to the briefcase
     * @param string $user_id The user identifier
     * @param mMysql $db The database connection
     * @param string $GET_data The search form GET data to be saved
     * @param string $POST_data The search form POST data to be saved
     * @param string $title The title of the search
     * @param int $folder_id The folder identifier
     * @access public
     * @static
     * @return string
     */
    public static function saveSearch($user_id, $db, $GET_data, $POST_data, $title, $folder_id) {
	$POST_data = str_replace(array("\n", "\r"), ' ', $POST_data);
	$GET_data = str_replace(array("\n", "\r"), ' ', $GET_data);
	$data = $GET_data . "\n" . $POST_data;
	$title = $db->real_escape_string($title);
	if ($folder_id == null)
	    $folder_id = 'null';
	else
	    $folder_id = $db->real_escape_string($folder_id);

	$data = $db->real_escape_string($data);
	$length = strlen($data);

	$sql = <<<sql
insert into briefcase_content
	(name, type_id, folder_id, data, length, user_id)
values
	('{$title}', 2, {$folder_id}, '{$data}', {$length}, '{$user_id}')
sql;

	$db->mQuery($sql);

	return '<saved/>';
    }

    /**
     * Exports the briefcase
     * @param int $type What to export from the briefcase (articles, searches etc.)
     * @param string $format The export format - default PDF [OPTIONAL]
     * @access protected
     * @return boolean
     */
    protected function export($type, $format = \MetaNull\Tools\xslTransform::FORMAT_PDF) {
	switch ($type) {
	    case self::TYPE_ARTICLE:
		$selected_ids = ($_GET['selected_articles'] == '' ? null : explode(',', $_GET['selected_articles']));
		return $this->exportArticles($format, null, $selected_ids);
		break;
	    case self::TYPE_DOCUMENT:
	    case self::TYPE_LOCATION:
	    case self::TYPE_SEARCH:
	    case self::TYPE_SHARED_OBJECT:
		break;
	}

	return false;
    }

    /**
     * Gets the application headers sent by the module
     * @access public
     * @return array
     */
    public function getHeaders() {
	if (array_key_exists('export', $_GET)) {
	    return array("Content-Type: " . $this->config['briefcase']['export'][$_GET['export']]['content-type'],
		    /*"Content-disposition: attachment; filename=" . $this->config['briefcase']['export'][$_GET['export']]['file-name']*/);
	}
	else
	    return ("Content-Type: text/xml; charset=utf8");
    }

    /**
     * Gets the default template file
     * @access public
     * @return string|null
     */
    public function getDefaultTemplateFile() {
	return array_key_exists('export', $_GET) ? 'module.html' : null;
    }

    /**
     * Creates a folder if it doesn't exists
     * @param string $folder_name the folder name
     * @param int $type_id The type of folder to be created or checked
     * @param string $user_id The current user
     * @param mMysql $db The database connection
     * @access public
     * @static
     * @return int
     */
    public static function createFolderIfNotExists($folder_name, $type_id, $user_id, $db) {
	$folder_id = $db->get_value('briefcase_folders', 'folder_id', 'type_id = ' . $type_id . ' and user_id = "' . $user_id . '" and name = "' . $folder_name . '"');
	if ($folder_id == null) {
	    $sql = <<<sql
insert into `briefcase_folders`
	(`name`, `description`, `parent_id`, `type_id`, `user_id`)
values
	('{$folder_name}', null, null, '{$type_id}', '{$user_id}');
sql;
	    $db->mQuery($sql);
	    $folder_id = $db->last_insert_id();
	}

	return $folder_id;
    }

    /**
     * Generates an url for a given content_id
     * @param string[] $ids The list of briefcase_content identifiers
     * @param mMysql $db The mysql connection
     * @access public
     * @static
     * @return BriefcaseJsUrl[]
     */
    public static function url($ids, $db) {
	require_once('BriefcaseJsUrl.class.php');
	$result = array();
	foreach ($ids as $id) {
	    $id = preg_replace('/^[A-Z]_([0-9]+)$/', '\1', $id);
	    $type = $db->get_value('briefcase_content', 'type_id', 'content_id = ' . $db->real_escape_string($id));
	    if ($type == 5) {
		$item_id = $db->get_value('briefcase_content', 'item_id', 'content_id = ' . $db->real_escape_string($id));
		if ($item_id == null || is_numeric($item_id)) {
		    $type = 2;
		}
		else $type = 1;
	    }

	    $url_obj = new BriefcaseJsUrl();
	    $url_obj->target = BriefcaseJsUrl::TARGET_BLANK;
	    $url_obj->type = $type;

	    if ($type == 1) {
		$url_obj->url = statics::URL('index.php', 'module=article&type=briefcase&id=' . $id);
		$url_obj->method = BriefcaseJsUrl::METHOD_GET;
		$url_obj->post_data = null;
	    }
	    else if ($type == 2) {
		$data = $db->get_value('briefcase_content', 'data', 'content_id = ' . $db->real_escape_string($id));
		$parts = explode("\n", $data);
		$url_obj->url = $parts[0];
		$url_obj->method = BriefcaseJsUrl::METHOD_POST;
		$url_obj->post_data = $parts[1];
	    }

	    $result[] = $url_obj;
	}

	return $result;
    }

}

}
?>