<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3{

class Interval {
    /**
     * The start date (UNIX timestamp)
     * @var int
     * @access public
     */
    public $start_date;

    /**
     * The end date (UNIX timestamp)
     * @var int
     * @access public
     */
    public $end_date;
}
/**
 * Section manager module (manages the horizontal sections of a page)
 * @package tariqa3
 * @author Pascal Havelange, Cosmin Popescu
 * @copyright © EUROPEAN COMMISSION, 2009-2010
 * @license http://ec.europa.eu/idabc/eupl
 */
class formData {
    /**
     * The horizontal orientation type
     * @var string
     * @access const
     */
    const HORIZONTAL = 'horizontal';

    /**
     * The vertical orientation type
     * @var string
     * @access const
     */
    const VERTICAL = 'vertical';

    /**
     * The daily frequency type
     * @var string
     * @access const
     */
    const DAILY = 'daily';

    /**
     * The monthly frequency type
     * @var string
     * @access const
     */
    const MONTHLY = 'monthly';

    /**
     * The yearly frequency type
     * @var string
     * @access const
     */
    const YEARLY = 'yearly';

    /**
     * The custom frequency type
     * @var string
     * @access const
     */
    const CUSTOM = 'custom';

    /**
     * The queries
     * @var string
     * @access public
     */
    public $queries = null;

    /**
     * The start date
     * @var string
     * @access public
     */
    public $start_date = null;

    /**
     * The end date
     * @var string
     * @access public
     */
    public $end_date = null;

    /**
     * The source identifier
     * @var int
     * @access public
     */
    public $source = null;

    /**
     * The frequency
     * @var string
     * @access public
     */
    public $frequency = formData::MONTHLY;

    /**
     * The results orientation
     * @var string
     * @access public
     */
    public $orientation = formData::HORIZONTAL;
}

class Analysis extends SpecialPage {
    /**
     * The form data
     * @var formData
     * @access protected
     */
    protected $formData;

    /**
     * Converts a datetime object to unix timestamp
     * @param DateTime $date The date
     * @access public
     * @static
     * @return int
     */
    public static function timestamp($date) {
	return $date->getTimestamp() + $date->getOffset();
    }

    /**
     * Gets the intervals
     * @param string $start_date The start date
     * @param string $end_date The end date
     * @access protected
     * @return Interval[]
     */
    protected function getIntervals($start_date, $end_date) {
	$start_date .= ' 00:00:00';
	$end_date .= ' 00:00:00';
	$d1 = \DateTime::createFromFormat('Y-m-d h:i:s', $start_date);
	$d2 = \DateTime::createFromFormat('Y-m-d h:i:s', $end_date);

	/* @var $d1 DateTime */
	/* @var $d2 DateTime */
	/* @var $di DateTime */

	$di = $d1;

	$intervals = array();

	while (self::timestamp($di) < self::timestamp($d2)) {
	    $interval = new Interval();
	    $interval->start_date = self::timestamp($di);

	    switch ($this->formData->frequency) {
		case formData::DAILY:
		    $di->add(new \DateInterval('P1D'));
		    break;
		case formData::MONTHLY:
		    $di->add(new \DateInterval('P1M'));
		    break;
		case formData::YEARLY:
		    $di->add(new \DateInterval('P1Y'));
		    break;
	    }

	    $interval->end_date = self::timestamp($di);
	    $intervals[] = $interval;
	}

	return $intervals;
    }

    /**
     * Inits the form data
     * @access protected
     * @return formData
     */
    protected function initFormData() {
	$formData = new formData();

	if (count($_POST) > 0) {
	    $formData->end_date = $_POST['end_date'];
	    $formData->frequency = $_POST['frequency'];
	    $formData->orientation = $_POST['orientation'];
	    $formData->queries = $_POST['queries'];
	    $formData->source = $_POST['source'];
	    $formData->start_date = $_POST['start_date'];
	}

	return $formData;
    }

    /**
     * Constructs the object
     * @param string $page_id The page identifier
     * @param array $config The configuration array
     * @access public
     * @return void
     */
    public function __construct($page_id, $config) {
	parent::__construct($page_id, $config);
    }

    /**
     * Performs the analysis
     * @access protected
     * @return void
     */
    protected function performAnalysis() {
	/*$call_id = 13710;
	$this->info_setBodyOnLoad("startAnalysis({$call_id})");
	return ;*/
	$intervals = $this->getIntervals($this->formData->start_date, $this->formData->end_date);
	$queries = explode('&', $this->formData->queries);

	$sql = <<<sql
   insert into ajax_calls
       (user_id)
   values
       ('{$this->user->user_id}')
sql;

        $this->db->mQuery($sql);
	$call_id = $this->db->last_insert_id();

	$i = 1;

	foreach ($queries as $query) {
	    $q = \MetaNull\Tools\mTools::rawurlencode($query);
	    $base_url_id = 10 * $i++;
	    $j = 0;
	    /* @var $interval Interval */
	    foreach ($intervals as $interval) {
		$url = $this->db->real_escape_string("{$this->config['application']['service_url']}/?action=searchNews&source_id={$this->formData->source}&query={$q}&start_date=" .
			"{$interval->start_date}&end_date={$interval->end_date}&from=1&count=1&multi_ajax_user_id={$this->user->user_id}&specific_data=no_article%3D");

		$url_id = $base_url_id + $j++;

		$sql = <<<sql
   insert into ajax_call_urls
       (call_id, url_id, url, method, use_proxy)
   values
       ({$call_id}, {$url_id}, '{$url}', 'get', 'no')
sql;
		$this->db->mQuery($sql);
	    }
	}

	$_SESSION['queries'] = $queries;
	$_SESSION['intervals'] = $intervals;
	$_SESSION['orientation'] = $this->formData->orientation;

	$sql = "select callMUdfService('{$this->config['modules']['ajax']['multi-download']['host']}', {$this->config['modules']['ajax']['multi-download']['port']}, 'MULTI', {$call_id})";

	$this->db->mQuery($sql);

	$this->info_setBodyOnLoad("startAnalysis({$call_id})");

	//\MetaNull\Tools\mDump::dumpVariable($call_id);
    }

    /**
     * Initialize the module (Connects to the database, check user rights, ...)
     */
    protected function onInitialize() {
	parent::onInitialize();
	$this->formData = $this->initFormData();
	$this->info_setStyleSheet('themes/default/modules/tariqa3/special_pages/Analysis/styles/main.css');
	$this->info_setJavascript('scripts/news_analysis.js');
	$this->info_setBodyOnLoad('initDates()');

	if (count($_POST) > 0) {
	    $this->performAnalysis();
	}
	if (array_key_exists('call_id', $_GET)){
	    $this->generateResult($_GET['call_id']);
	}
    }

    /**
     * Generates the excel result file
     * @param int $call_id The call identifier
     * @access protected
     * @return string
     */
    protected function generateResult($call_id) {
	$call_id = $this->db->real_escape_string($call_id);
	//$sql = "select url_id, call_content from ajax_call_urls where call_id = {$call_id} order by url_id";

	$queries = $_SESSION['queries'];
	$intervals = $_SESSION['intervals'];
	$orientation = $_SESSION['orientation'];

	$output = '';
	$i = 1;

	foreach ($queries as $query){
	    $j = 0;
	    $output .= ($output == ''?'':"\n\n") . $query . "\n";

	    $base_url_id = 1000 * $i++;

	    $header = array();
	    $values = array();

	    /* @var $interval Interval */
	    foreach ($intervals as $interval){
		$url_id = $base_url_id + $j++;
		$content = $this->db->get_value('ajax_call_urls', 'call_content', 'call_id = "' . $call_id . '" and url_id = ' . $url_id);

		$doc = new \DOMDocument('1.0', 'UTF-8');
		$doc->loadXML($content);

		$xp = new \DOMXPath($doc);
		$rs = $xp->query('//count');

		if ($rs->length > 0){
		    $count = $rs->item(0)->nodeValue;
		}

		$header[] = date('d/m/Y', $interval->start_date) . " - " . date('d/m/Y', $interval->end_date);
		$values[] = $count;

	    }
	    
	    if ($orientation == formData::HORIZONTAL){
		foreach ($header as $s){
		    $output .= $s . "\t";
		}
		$output .= "\n";
		foreach ($values as $s){
		    $output .= $s . "\t";
		}
		$output .= "\n";
	    }
	    else {
		for ($k = 0; $k < count($header); $k++){
		    $output .= $header[$k] . "\t" . $values[$k] . "\n";
		}
	    }

	    $output .= "\n";
	}

	$sql = "delete from ajax_calls where call_id = '{$call_id}'";
	//$this->db->mQuery($sql);

	header("Content-Length: " . strlen($output));
	header( "Content-Disposition: attachment; filename=\"analysis.xls\"" );
	header( "Last-Modified: " . date("r") );
	header('Pragma: no-cache');
	header('Pragma: hack');
	header('Expires: ' . date( "r", time()-86400 ));
	header('Cache-Control: no-store, no-cache, must-revalidate, public');     // HTTP/1.1
	header('Cache-Control: pre-check=0, post-check=0, max-age=0');    // HTTP/1.1
	echo $output;
	die();
    }

    /**
     * Renders the page (sets all the template data)
     * @access protected
     * @return void
     */
    protected function renderPage() {
	$this->setTemplate($this->getTemplateFilePath('analysis.html'));
	$sources = statics::ListQuickSearchSources($this->user->get_access_level());
	$this->template->data['sources'] = array();

	/* @var $source QuickSearchSource */
	foreach ($sources as $source) {
	    $this->template->data['sources'][] = array(
		    'id' => $source->source->source_id,
		    'source' => $source->display_title,
		    'selected' => ($this->formData->source == $source->source->source_id?'selected="selected"':''),
	    );
	}

	$this->template->data['queries'] = $this->formData->queries;
	$this->template->data['start_date'] = $this->formData->start_date;
	$this->template->data['end_date'] = $this->formData->end_date;
	$this->template->data['frequencies'] = array(
		array(
			'id' => formData::DAILY,
			'text' => 'Daily',
			'selected' => ($this->formData->frequency == formData::DAILY?'selected="selected"':''),
		),
		array(
			'id' => formData::MONTHLY,
			'text' => 'Monthly',
			'selected' => ($this->formData->frequency == formData::MONTHLY?'selected="selected"':''),
		),
		array(
			'id' => formData::YEARLY,
			'text' => 'Yearly',
			'selected' => ($this->formData->frequency == formData::YEARLY?'selected="selected"':''),
		),
		array(
			'id' => formData::CUSTOM,
			'text' => 'Custom (number of days):',
			'selected' => ($this->formData->frequency == formData::CUSTOM?'selected="selected"':''),
		),
	);
	$this->template->data['orientations'] = array(
		array(
			'id' => formData::HORIZONTAL,
			'text' => 'Horizontal',
			'selected' => ($this->formData->orientation == formData::HORIZONTAL?'selected="selected"':''),
		),
		array(
			'id' => formData::VERTICAL,
			'text' => 'Vertical',
			'selected' => ($this->formData->orientation == formData::VERTICAL?'selected="selected"':''),
		),
	);
    }

}
}
?>
