<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3{


require_once('HttpAuthentication.class.php');
/**
 * Section manager module (manages the horizontal sections of a page)
 * @package tariqa3
 * @author Pascal Havelange, Cosmin Popescu
 * @copyright © EUROPEAN COMMISSION, 2009-2010
 * @license http://ec.europa.eu/idabc/eupl
 */
class RSS extends SpecialPage {
    /**
     * The search data
     * @var string
     * @access protected
     */
    protected $data;

    /**
     * The search title
     * @var string
     * @access protected
     */
    protected $title;

    /**
     * The content identifier
     * @var int
     * @access protected
     */
    protected $content_id;
    
    /**
     * Constructs the object
     * @param string $page_id The page identifier
     * @param array $config The configuration array
     * @access public
     * @return void
     */
    public function __construct($page_id, $config) {
	$auth = new HttpAuthentication();
	parent::__construct($page_id, $config, $auth);
    }

    /**
     * Used for sorting the Tariqa documents by date
     * @param tariqaDocument $d1 The first document
     * @param tariqaDocument $d2 The first document
     * @static
     * @access public
     * @return boolean
     */
    public static function sortDocuments($d1, $d2) {
	if ($d1->date == 0) return 1;
	if ($d2->data == 0) return -1;
	return ($d1->date < $d2->date?1:-1);
    }

    /**
     * Renders the page (sets all the template data)
     * @access protected
     * @return void
     */
    protected function renderPage() {
	$this->setTemplate($this->getTemplateFilePath('rss.html'));
	$content_id = $this->content_id;
	$parts = explode("\n", $this->data);
	$parts2 = explode("?", $parts[0]);
	$get = $parts2[1];
	$post = $parts[1];

	$data = statics::post2array($get);
	$_GET = array();
	$qstr = null;
	foreach ($data as $key => $value){
	    $_GET[$key] = $value;
	    if ($key == 'query') {
		$qstr = $value;
	    }
	}

	$data = statics::post2array($post);
	$_POST = array();
	foreach ($data as $key => $value){
	    $_POST[$key] = \MetaNull\Tools\mTools::rawurldecode($value);
	    if ($key == 'query') {
		$qstr = \MetaNull\Tools\mTools::rawurldecode($value);
	    }
	}

	if (array_key_exists('redirect', $_GET)){
	    $class_name = $_GET['redirect'] . 'Redirect';
	    require_once('tariqa3/tariqa3Redirect.class.php');
	    require_once('tariqa3/redirect/' . $class_name . '.class.php');
	    $class_name = "tariqa3\\" .  $class_name;
	    $class = new $class_name($this->config);
	    $class->doRedirect();
	}

	$s = new Search($this->config);
	$s->user = $this->user;
	$r = $s->results('', true);

	$sql = "insert into ajax_calls(user_id) values('{$this->user->user_id}')";
	$this->db->mQuery($sql);
	$call_id = $this->db->last_insert_id();

	$i = 1;

	/* @var $search multiAjaxSearch */
	foreach ($r as $search){
	    $search->setQuery(\MetaNull\News\unifiedQuerySyntax::removeDatesCondition($search->getQuery()) . " previous(1)");
	    $search->setStartDate(null);
	    $search->setEndDate(null);
	    $search->setFrom(1);
	    $search->setCount(20);

	    $url = $search->getURL() . '&fetch_object=&no_root_node=&content_type=text/plain';

	    $parts = explode('?', $url, 2);
	    $url = $parts[0];
	    $post_fields = $this->db->real_escape_string($parts[1]);
	    $url .= '?multi_ajax_user_id=' . $this->user->user_id;

	    $sql = <<<sql
   insert into ajax_call_urls
       (call_id, url_id, url, post_fields, method, use_proxy)
   values
       ('{$call_id}', '{$i}', '{$url}', '{$post_fields}', 'post', 'no')
sql;
	    $i++;

	    $this->db->mQuery($sql);
	}

	$sql = "select callMUdfService('{$this->config['modules']['ajax']['multi-download']['host']}', {$this->config['modules']['ajax']['multi-download']['port']}, 'MULTI', '{$call_id}') as result";
	$this->db->mQuery($sql);

	do{
	    $n = $this->db->count_rows('ajax_call_urls', 'http_code is null and call_id = ' . $call_id);
	    if ($n > 0) {
		usleep(500000);
	    }
	} while ($n > 0);

	$sql = "select call_content from ajax_call_urls where http_code = 200 and call_id = '{$call_id}'";
	$query = $this->db->mQuery($sql);

	$doc = new \DOMDocument('1.0', 'UTF-8');
	$rss = $doc->createElement('rss');
	$rss->setAttribute("version", '2.0');
	$channel = $doc->createElement('channel');
	
	$node = search\searchEngine::addNode('title', 'Tariqa RSS - ' . $this->title, $doc, false, null);
	$channel->appendChild($node);
	$node = search\searchEngine::addNode('link', $this->config['application']['base'], $doc);
	$channel->appendChild($node);
	
	$documents = array();

	$description = '';

	while ($row = $query->fetch_assoc()){
	    /* @var $r search\tariqaSearchResultSet */
	    $r = unserialize(base64_decode($row['call_content']));
	    $documents = array_merge($documents, $r->documents);
	    $description .= ($description == ''?'':', ') . $r->engine_name;

	    $source = (is_numeric($r->source) && $r->source > 0?$r->source:'null');

	    $sql = <<<sql
   insert into rss_log(user_id, content_id, source_id, engine_id, date)
       values(
	    '{$this->user->user_id}', '{$content_id}', {$source}, '{$r->engine}', now()
       )
sql;

	    $this->db->mQuery($sql);
	}

	$description = 'Feed created using ' . $description;
	if ($qstr != null){
	    $description .= ". Initial query: {$qstr}";
	}

	$node = search\searchEngine::addNode('description', htmlspecialchars($description), $doc);
	$channel->appendChild($node);
	$node = search\searchEngine::addNode('language', 'en-us', $doc);
	$channel->appendChild($node);
	$node = search\searchEngine::addNode('pubDate', date('r'), $doc);
	$channel->appendChild($node);
	$node = search\searchEngine::addNode('lastBuildDate', date('r'), $doc);
	$channel->appendChild($node);
	$node = search\searchEngine::addNode('ttl', '15', $doc);
	$channel->appendChild($node);
	$node = search\searchEngine::addNode('webMaster', $this->config['smtp']['mailbox'], $doc);
	$channel->appendChild($node);

	usort($result->documents, array($this, "sortDocuments"));

	/* @var $document tariqaDocument */
	foreach ($documents as $document){
	    $item = $doc->createElement('item');
	    $node = search\searchEngine::addNode('title', htmlspecialchars($document->title), $doc);
	    $item->appendChild($node);

	    $url = $document->url;
	    if (substr($url, 0, 7) != 'http://'){
		$base = $this->config['application']['base'];
		if (substr($base, -1) != '/') $base .= '/';
		$url = $base . $url;
	    }
	    $node = search\searchEngine::addNode('link', htmlspecialchars($url), $doc);
	    $item->appendChild($node);
	    $node = search\searchEngine::addNode('description', htmlspecialchars($document->summary), $doc, true);
	    $item->appendChild($node);
	    $node = search\searchEngine::addNode('pubDate', date('r', $document->date), $doc, true);
	    $item->appendChild($node);
	    $node = search\searchEngine::addNode('guid', htmlspecialchars($document->id), $doc);
	    $item->appendChild($node);

	    $channel->appendChild($item);
	}

	$rss->appendChild($channel);

	$doc->appendChild($rss);

	$this->template->data['rss_content'] = $doc->saveXML();
    }

    /**
     * Initializes the module
     * @access public
     * @return void
     */
    public function onInitialize() {
	parent::onInitialize();
	statics::load_user_prefs($this->user, $this->db);
	$this->setDefaultLayout('rss.html');

	if (array_key_exists('unique_id', $_GET)){
	    $this->content_id = $this->db->get_value('briefcase_content', 'content_id', 'item_id = "' . $this->db->real_escape_string($_GET['unique_id']) .
		'" and user_id = "' . $this->user->user_id . '"');
	}
	else {
	    $this->content_id = $_GET['content_id'];
	}

	$this->data = $this->db->get_value('briefcase_content', 'data', 'content_id = ' . $this->content_id . ' and user_id = \'' . $this->user->user_id . '\'');
	if ($this->data == null || $this->data == ''){
	    throw new \Exception('Search not found');
	}
	$this->title = $this->db->get_value('briefcase_content', 'name', 'content_id = ' . $this->content_id);
    }

    /**
     * Gets the applications headers set by the module
     * @access public
     * @return array
     */
    public function getHeaders() {
	return array("Content-type: text/xml; charset=utf-8");
    }

    /**
     * Gets the default template file
     * @access public
     * @return string|null
     */
    public function getDefaultTemplateFile() {
	return "rss.html";
    }

}
}
?>
