<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3 {

	require_once('ThemesListSection.class.php');
	require_once('ThemeTextsSection.class.php');
	require_once('ThemeTopicsSection.class.php');
	require_once('UploadSection.class.php');
	require_once('tariqa3/modules/sharing/Sharing.class.php');

/**
 * Theme module
 * @package tariqa3
 * @author Pascal Havelange, Cosmin Popescu
	 * @copyright © EUROPEAN COMMISSION, 2009-2010
	 * @license http://ec.europa.eu/idabc/eupl
 */
class Themes extends tariqa3ModuleSectionManager {

	/**
	 * The listing type
	 * @var int
	 
	 */
	const LISTING = 0;

	/**
	 * The theme display type
	 * @var int
	 
	 */
	const THEME_DISPLAY = 1;

	/**
	 * The theme to display
	 * @var Theme
	 * @access private
	 */
	private $theme = null;

	/**
	 * The type of the rendering (one theme page or the list of the themes)
	 * @var int
	 * @access private
	 */
	private $type = 0;

	/**
	 * The list of queries
	 * @var Query[][]
	 * @access private
	 */
	private $queries;

	/**
	 * The list of tabs
	 * @var Flavour[]
	 * @access private
	 */
	private $flavours;

	/**
	 * Construct the Module object
	 * @param array $config The multidimentionnal array containing the application's configuration
	 */
	public function __construct( $config ) {
		parent::__construct($config);
	}

	/**
	 * Renders the listing of the themes
	 * @param mTemplate $tpl The template of the page
	 * @access protected
	 * @return string
	 */
	protected function listThemes($tpl) {
		$this->info_setJavascript(
			array(
				'scripts/jquery.cookie.js',
				'scripts/jquery.treeview.min.js',
			)
		);

		$this->info_setStylesheet(
			array(
				$this->getThemeFileUrl( 'styles/jquery/tree/jquery.treeview.css' ),
			)
		);

		$this->info_setBodyOnLoad('initJQueryUI()');

		$list = new ThemesListSection($this->config, $this->base_folder, 'themes_list', $this->translationTable);
		$list->db = $this->db;
		$this->addSection($list);
		$tpl->data['themes_html'] = $this->renderSections();

		return $tpl->transform();
	}

	/**
	 * Renders the theme page
	 * @param mTemplate $tpl The template of the page
	 * @access protected
	 * @return string
	 */
	protected function displayTheme($tpl) {
		//The prefix used to retrieve the user preferences regarding the selected theme

		$propertiesSection = 'theme_page/' . $this->theme->theme_id . '/';

		/*$topics = new ThemeTopicsSection($this->config, $this->base_folder, 'theme_topics', $this->theme, $this->translationTable);
		$this->addSection($topics);*/

		$texts = new ThemeTextsSection($this->config, $this->base_folder, 'text_topics', $this->theme, $this->translationTable);
		$this->addSection($texts);

		$news = new NewsSection($this->config, $this->base_folder, 'news_tabs', $this->translationTable, $this->flavours, $this->queries, $propertiesSection);
		$this->addSection($news);

		$upload = new UploadSection($this->config, $this->base_folder, 'files_upload', $this->translationTable, UploadSection::THEME_PAGE, 'files_tree_test', $this->theme->theme_id);
		$this->addSection($upload);

		$tpl->data['theme_id'] = $this->theme->theme_id;
		$tpl->data['theme_name'] = $this->theme->title;
		
		$tpl->data['sections_html'] = $this->renderSections();

		$sharing = new Sharing($this->config, $this->translationTable);
		$tpl->data['sharing_form'] = $sharing->run();
		$this->setMoreInfos($sharing->getInfo());

		return $tpl->transform();
	}

	/**
	 * Render the module
	 * @return string
	 */
	public function getPageContent() {
		$tpl = new \MetaNull\Application\MTemplate( 'm' );
		$tpl->data = $this->translationTable;

		$tpl->data['has_links'] = $this->theme->theme_id == 13;

		$this->info_setJavascript(
			array(
				'scripts/themes.js',
			)
		);

		switch ($this->type){
			case self::THEME_DISPLAY:
				$tpl->loadTemplate($this->getTemplateFilePath( 'theme_page.html' ));
				return $this->displayTheme($tpl);
				break;
			case self::LISTING:
				$tpl->loadTemplate( $this->getTemplateFilePath( 'listing.html' ));
				return $this->listThemes($tpl);
				break;
		}

		return null;
	}

	/**
	 * Gets the default flavour for the latest news queries
	 * @param array $translationTable The translation matrix
	 * @access public
	 * @static
	 * @return Flavour
	 */
	public static function getDefaultFlavour($translationTable) {
		$flavour = new \Flavour();
		$flavour->name = $translationTable['module/main_tab_title'];
		$flavour->flavour_id = 0;

		return $flavour;
	}

	/**
	 * Returns true if the current user can edit the theme text
	 * @param tariqaUser The user
	 * @param int $theme_id The theme identifier
	 * @access public
	 * @static
	 * @return boolean
	 */
	public static function canEditTheme($user, $theme_id) {
		$users = statics::ListThemeUsers($theme_id);
		foreach ($users->user_id as $user_id){
			if ($user_id == $user->user_id){
				return true;
			}
		}

		return false;
	}

	/**
	 * Gets the latest news queries for a theme
	 * @param Theme $theme The theme
	 * @param array $translationTable The translation matrix
	 * @param tariqaUser $user The current user
	 * @param Flavour $flavour The flavour of the query [OPTIONAL]
	 * @access public
	 * @static
	 * @return Query[]
	 */
	public static function listLatestNewsQueries($theme, $translationTable, $user, $flavour = null) {
		$queries = array();
		if ($theme->query_id != null){
			$query = statics::getQuery($theme->query_id);
			$query->block_display_order = 1;
			$queries[] = $query;
		}
		$queries = array_merge($queries, statics::listThemeQueries($theme->theme_id, $user->get_access_level()));

		if ($flavour == null){
			$flavour = self::getDefaultFlavour($translationTable);
		}
		
		$result = array();

		$i = 1;

		foreach ($queries as $query){
			$query->flavour = $flavour;
			$query->block_label = $query->title;
			$query->block_display_order = $i++;
			$result[] = $query;
		}

		return $result;
	}

	/**
	 * Gets the queries of a topic
	 * @param ThemeTopic $topic The theme topic
	 * @access public
	 * @static
	 * @return Query[]
	 */
	public static function listTopicQueries($topic) {
		$flavour = new \Flavour();
		$flavour->flavour_id = $topic->topic_id;
		$flavour->name = $topic->title;

		$i = 1;

		$queries = array();

		/* @var $query TopicQuery */
		foreach ($topic->queries as $query){
			$q = $query->query;
			$q->flavour = $flavour;
			$q->block_label = $query->title;
			$q->block_display_order = $i++;

			$queries[] = $q;
		}

		return $queries;
	}

	/**
	* Initializes the module
	* @access public
	* @return void
	*/
	public function onInitialize(){
		parent::onInitialize();
		if (array_key_exists('theme_id', $_GET)){
			$this->type = self::THEME_DISPLAY;
			$this->theme = statics::get_theme($_GET['theme_id']);
			$this->queries = array();

			$this->flavours = array();
			$flavour = self::getDefaultFlavour($this->translationTable);
			$this->flavours[] = $flavour;

			$queries = self::listLatestNewsQueries($this->theme, $this->translationTable, $this->user, $flavour);

			/* @var $query Query */
			foreach ($queries as $query){
				$this->queries[$flavour->flavour_id][] = $query;
			}

			$topics = statics::ListThemeTopics($this->theme->theme_id, $this->user->get_access_level());

			/* @var $topic ThemeTopic */
			foreach ($topics as $topic){
				$queries = self::listTopicQueries($topic);

				/* @var $query TopicQuery */
				foreach ($queries as $query){
					$this->queries[$topic->topic_id][] = $query;
				}

				if (count($queries) > 0){
					$this->flavours[] = $query->flavour;
				}
			}

			//\MetaNull\Tools\mDump::dumpVariable($this->queries);
		}
		else {
			$this->type = self::LISTING;
		}
	}

	/**
	 * Process all requests (this is the default module)
	 */
	public function canProcessRequest() {
		return array_key_exists('module', $_GET) && $_GET['module'] == $this->getName();
	}

	/**
	 * Returns the name of the class (what it should appear in the menu
	 * @access public
	 * @return string
	 */
	public function getName() {
		return 'themes';
	}

	/**
	 * Returns the title of the page
	 * @access public
	 * @return string
	 */
	public function getTitle() {
		return 'Tariqa 3 Theme page';
	}

	/**
	 * Returns the description of the page
	 * @access public
	 * @return string
	 */
	public function getDescription() {
		return 'The theme page';
	}

	/**
	 * Gets the link of the module
	 * @access public
	 * @return string
	 */
	public function getLink() {
		return statics::URL('index.php', 'module=' . $this->getName());
	}

	/**
	 * Return the items of the current breadcrumb path
	 * @return tariqa3ModuleDescriptor[]
	 */
	public function getBreadCrumb() {
		$breadCrumb = array();
		$breadCrumb[] = new tariqa3ModuleDescriptor($this);
		if ($this->theme != null){
			$b = new tariqa3ModuleDescriptor();
			$b->label = $this->theme->title;
			$b->link = statics::URL('index.php', 'module=themes&theme_id=' . $this->theme->theme_id);
			$breadCrumb[] = $b;
		}
		return $breadCrumb;
	}
}

}

?>