<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

 /**
 * Tarîqa 3.0 - Core components
 * @author Pascal Havelange, Cosmin Popescu
 * @copyright © EUROPEAN COMMISSION, 2009-2010
 *
 * @license http://ec.europa.eu/idabc/eupl
 */
namespace tariqa3{
	/**
	 * Helper class to generate javascript code for a multi ajax call (see multi_ajax.js)
	 */
	class multiAjaxCall{
		/**
		 * The list of multi ajax url's
		 * @var multiAjaxURL[]
		 * @access private
		 */
		private $multiAjaxURL = array();

		/**
		 * If true, send also the user name through get to the multi AJAX mechanism
		 * @var boolean
		 * @access private
		 */
		private $send_user = false;

		/**
		 * The javascript code to be executed before the URL's are sent to the server
		 * @var string
		 * @access private
		 */
		private $onBegin;

		/**
		 * The javascript code to be executed after the URL's are sent to the server
		 * @var string
		 * @access private
		 */
		private $onEnd;

		/**
		 * The name of the javascript function to be called to process each result retrieved from the server
		 * @var string
		 * @access private
		 */
		private $processResults;

		/**
		 * Constructs the object
		 * @param boolean $send_user If true, send also the user name through get to the multi AJAX mechanism [OPTIONAL]
		 * @access public
		 * @return void
		 */
		public function __construct($send_user = false) {
			$this->send_user = $send_user;
		}

		/**
		 * Retrieves the list of ursl
		 * @access public
		 * @return multiAjaxURL[]
		 */
		public function getURLList() {
			return $this->multiAjaxURL;
		}

		/**
		 * Adds a multi ajax URL
		 * @param multiAjaxURL $call_url The multi AJAX call URL
		 * @access public
		 * @return void
		 */
		public function addURL($call_url) {
			$this->multiAjaxURL[] = $call_url;
		}

		/**
		 * Sets the javascript code to be called before the URL's are sent to the server
		 * @param string $onBegin The code
		 * @access public
		 * @return void
		 */
		public function setOnBegin($onBegin) {
			$this->onBegin = $onBegin;
		}

		/**
		 * Sets the javascript code to be called after all the URL's are processed by the server
		 * @param string $onEnd The code
		 * @access public
		 * @return void
		 */
		public function setOnEnd($onEnd) {
			$this->onEnd = $onEnd;
		}

		/**
		 * Sets the name of the function to be called to process each result retrieved from the server
		 * @param string $processResult The javascript function name
		 * @access public
		 * @return void
		 */
		public function setProcessResult($processResult) {
			$this->processResults = $processResult;
		}

		/**
		 * Generates the javascript code
		 * @access public
		 * @return string
		 */
		public function generate_js() {
			if (count($this->multiAjaxURL) == 0) return '';
			if ($this->processResults == '') $this->processResults = 'function(response){}';
			$set_user = ($this->send_user?'true':'false');
			$result = <<<js
	   var urls = new Array();

js;
			foreach ($this->multiAjaxURL as $call_url){
				$result .= $call_url->generate_js();

				$result .= <<<js
	   urls.push({$call_url->getName()});

js;
			}

			$result .= <<<js
	   sendURLS(urls, {$this->processResults}, function(){{$this->onBegin}}, function(){{$this->onEnd}}, {$set_user});

js;

			return $result;
		}
	}
}
?>
