<?php

/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 * 	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 * 	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3 {

/**
 * Class used to represent the parameters for javascript function js_open
 * @author Cosmin Popescu, Pascal Havelange
 * @copyright © EUROPEAN COMMISSION, 2010
 * @package tariqa3
 * @license http://ec.europa.eu/idabc/eupl
 */
class briefcaseRedirect extends tariqa3Redirect {
    /**
     * The database connection
     * @var mMysql
     * @access protected
     */
    protected $db;

    /**
     * The briefcase content identifier
     * @var int
     * @access protected
     */
    protected $content_id;

    /**
     * The briefcase js url
     * @var BriefcaseJsUrl
     * @access protected
     */
    protected $url;

    /**
     * The tariqa user
     * @var tariqaUser
     * @access protected
     */
    protected $user;

    /**
     * Constructs the object
     * @param array $config The application configuration array
     * @access public
     * @return void
     */
    public function __construct($config) {
	parent::__construct($config);
    }

    /**
     * Initializes the module
     * @access public
     * @return void
     */
    public function initialize() {
	$this->db = statics::open_db_connection($this->config['database']);

	$auth = new tariqaAuthentication($this->config['application']['name'], $this->config['application']['url'], $this->config['security']['ssl-certificate']);

	$this->user = $auth->tariqaStartSession();
	
	$this->content_id = null;
	if (array_key_exists('unique_id', $_GET)){
	    $this->content_id = $this->db->get_value('briefcase_content', 'content_id', 'item_id = "' . $this->db->real_escape_string($_GET['unique_id']) .
		'" and user_id = "' . $this->user->user_id . '"');
	}

	if (array_key_exists('content_id', $_GET)){
	    $this->content_id = $_GET['content_id'];
	}

	if ($this->content_id == null || $this->content_id == ''){
	    throw new \MetaNull\Authentication\insufficientPrivilegesException('You don\'t have access to this item. This can happen if you are logged in with the EEAS account instead of the EC account or the other way around. If not, please contact Tariqa Team. ');
	}

	require_once('tariqa3/modules/briefcase/Briefcase.class.php');
	$ids = array('I_' . $this->content_id);
	$_url = Briefcase::url($ids, $this->db);

	$this->url = $_url[0];
    }

    /**
     * Gets the URL
     * @access public
     * @return string
     */
    public function getURL() {
	return $this->url->url;
    }

    /**
     * Gets the POST data
     * @access public
     * @return string
     */
    public function getPostData() {
	$post_data = null;
	if ($this->url->post_data != null){
	    $post_data = $this->url->post_data;
	    /*$data = statics::post2array($this->url->post_data);
	    foreach ($data as $key => $value){
		$post_data .= ($post_data == null?'':'&') . $key  . '=' . \MetaNull\Tools\mTools::rawurlencode($value);
	    }*/
	}
	return $post_data;
    }
}

}
?>