<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3\search{
/**
 * Base class for fetching the news results from the Google engine
 * @author Cosmin Popescu
 *
 */
class GoogleEngine extends searchEngine {

    /**
     * Constructs the object
     * @param array $newsConfig The news configuration array
     * @access public
     * @return void
     */
    public function __construct($newsConfig) {
	parent::__construct($newsConfig);
    }

    /**
     * Sets the google type search
     * @param string $engine The engine identifier
     * @access private
     * @return string
     */
    private function getGoogleType($engine) {
	switch($engine) {
	    case "GoogleBlogs": return "blogs";
	    case "GoogleImages": return "images";
	    case "GoogleNews": return "news";
	    case "GoogleVideo": return "video";
	    case "GoogleWeb": return "web";
	    case "Google": return "web";
	}
    }

    /**
     * Fetches a list of articles
     * @param newsQuery $query The query
     * @access public
     * @return tariqaSearchResultSet
     */
    public function listArticles($query) {
	$queryObj = new \GoogleQuery();
	$queryObj->data = $this->getGoogleType($query->engine_id);
	$queryObj->query = $query->query;
	//$queryObj->start = 5;
	if ($query->source_id != null) {
	    $source = \tariqa3\statics::getSource($query->source_id);
	    $queryObj->source = $source->source_data;
	}

	if ($query->specific_data != null) {
	    $data = \tariqa3\statics::post2array(\MetaNull\Tools\mTools::rawurldecode($query->specific_data));
	    foreach ($data as $key => $value) {
		if ($key != 'source_name' && $key != 'no_article') {
		    $queryObj->query .= ' ' . $key . "=" . $value;
		}
	    }
	}

	$p = new \Pair('userip', $_SERVER['REMOTE_ADDR']);

	$queryObj->specific_options = array($p);

	$results = \tariqa3\statics::$tariqaClient->googleSearch(\tariqa3\statics::$tariqaToken, $queryObj);

	if ($results->responseDetails != null) {
	    error_log($results->responseDetails);
	    throw new \Exception("Google Engine error. Please see the log for details");
	}
	if ($query->first !== null && $query->count !== null) {
	    $results = \tariqa3\statics::$tariqaClient->googleFetch(
		    \tariqa3\statics::$tariqaToken,
		    $results,
		    $query->first - 1,
		    $query->count
	    );
	    //\MetaNull\Tools\mDump::dumpVariable($results);
	}

	$result = new tariqaSearchResultSet();

	$result->query = $query->query;
	$engine = \tariqa3\statics::getEngine($query->engine_id);
	$result->engine_name = $engine->name;
	$result->engine = $query->engine_id;
	$result->source = $query->source_id;
	$result->from = $query->first;

	$engine = \tariqa3\statics::getEngine($query->engine_id);
	$result->logo = $engine->logo_url;
	$result->provider_url = $engine->doc_url;

	$result->count = ($results->estimatedResultCount != null?$results->estimatedResultCount:0);
	$result->results_per_page = $query->count !== null?$query->count:count($results->searchResults);

	$result->documents = array();

	/* @var $article GoogleSearchResult */
	foreach ($results->searchResults as $article) {
	    $document = new tariqaDocument();

	    $a = new \GoogleSearchResult();
	    $a->GsearchResultClass = $article->GsearchResultClass;
	    $a->content = $article->content;
	    $a->specific_properties = $article->specific_properties;
	    $a->title = $article->title;
	    $a->titleNoFormatting = $article->titleNoFormatting;
	    switch ($query->engine_id) {
		case 'GoogleBlogs':
		    foreach ($article->specific_properties as $prop) {
			if ($prop->key == 'postUrl') {
			    $a->unescapedUrl = $prop->value;
			    $a->url = $prop->value;
			    break;
			}
		    }
		    break;
		default:
		    $a->unescapedUrl = $article->unescapedUrl;
		    $a->url = $article->url;
		    break;
	    }
	    $article = $a;

	    $document->title = $article->titleNoFormatting;
	    $document->id = $query->engine_id . ':' .
		    $query->source_id . ':' .
		    urlencode($article->unescapedUrl);
	    $document->url = $this->link($query->engine_id . '::' . urlencode($article->unescapedUrl));
	    $document->js_link = $this->js_link(
		    $query->engine_id . '::' . urlencode($article->unescapedUrl),
		    $article->titleNoFormatting
	    );

	    $date_value = 0;
	    if ($query->engine_id == "GoogleNews" || $query->engine_id == "GoogleBlogs") {
		foreach ($article->specific_properties as $prop) {
		    if ($prop->key == "publishedDate") {
			$date_value = $prop->value;
			break;
		    }
		}
	    }
	    if ($query->engine_id == "GoogleVideo") {
		foreach ($article->specific_properties as $prop) {
		    if ($prop->key == "published") {
			$date_value = $prop->value;
			break;
		    }
		}
	    }
	    $document->date = $date_value;

	    $document->summary = $article->content;

	    $source = 'Google web';
	    if ($query->engine_id == 'GoogleNews' || $query->engine_id == 'GoogleVideo') {
		$source = $article->publisher;
	    }
	    if ($query->engine_id == 'GoogleBlogs') {
		$source = $article->author;
	    }
	    if ($query->engine_id == 'GoogleWeb' || $query->engine_id == 'Google') {
		$source = $article->unescapedUrl;
	    }
	    $document->publisher = $source;

	    $result->documents[] = $document;
	}

	return $result;
    }

    /**
     * Gets a specific article
     * @param string $article_id The article identifier
     * @access public
     * @abstract
     * @return tariqaFullDocument
     */
    public function getArticle($article_id) {
	$parts = explode(':', $article_id, 3);
	if (count($parts) != 3) {
	    throw new \Exception('Document identifier not well formed');
	}

	$_article_id = null;

	if ($parts[0] != 'RSS') {
	    $document = \tariqa3\statics::$tariqaClient->googleGetDocument(
		    \tariqa3\statics::$tariqaToken, \MetaNull\Tools\mTools::rawurldecode($parts[2])
	    );
	}
	else {
	    $url = \MetaNull\Tools\mTools::rawurldecode($parts[2]);
	    $document = \tariqa3\statics::$tariqaClient->fetchUrl(\tariqa3\statics::$tariqaToken, new \WebRequest($url));
	    /*$config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
	    $db = \tariqa3\statics::open_db_connection($config['database']);
	    $body = $db->real_escape_string($document->body);
	    $_article_id = $db->get_value('external_articles', 'article_id', 'url = "' . $url . '"');
	    if ($_article_id != null){
		$sql = "update external_articles set content = '{$body}' where article_id = {$_article_id}";
		$db->mQuery($sql);
	    }
	    else {
		$sql = "insert into external_articles(url, content) values('{$url}', '{$body}')";
		$db->mQuery($sql);
		$_article_id = $db->last_insert_id();
	    }*/
	}

	$result = new tariqaFullDocument();
	$result->id = $article_id;
	$result->engine = $parts[0];
	$result->source = $parts[1];
	$result->document_id = ($_article_id == null?$parts[2]:\tariqa3\statics::URL('external_article.php', 'id=' . $article_id));
	$result->title = '';

	$result->date = 0;
	$result->publisher = '';

	if ($parts[0] != 'RSS') {
	    $base64 = base64_decode($document);
	    $result->body = ($base64 !== false?$base64:$document);
	}
	else {
	    $body = $document->body;
	    
	    $body = preg_replace('/<script[^>]*>.*?<\/script>/si', '', $body);
	    $body = preg_replace('/<script[^>]*>/si', '', $body);
	    preg_match('/<head[^>]*>(.*?)<\/head>/si', $body, $matches);
	    if (count($matches) == 2) {
		$result->html_headers = $matches[1];
		$body = preg_replace('/<head[^>]*>.*?<\/head>/si', '', $body);
	    }
	    $body = preg_replace('/<html[^>]*>/', '', $body);
	    $body = str_replace('</html>', '', $body);
	    $body = preg_replace('/<body[^>]*>/si', '', $body);
	    $body = str_replace('</body>', '', $body);

	    $result->body = '<div style="color: red; font-size: 12px;"><strong>Warning: The display of this article might cause problems, as the article is from an external site.</strong></div>' . $body;
	}

	return $result;
    }

    /**
     * Gets the multi ajax search object
     * @param string $query The query string
     * @param int $from The first result to display
     * @param int $count The number of results to display
     * @param DateTime $startDate The start date [OPTIONAL]
     * @param DateTime $endDate The end date [OPTIONAL]
     * @access public
     * @return multiAjaxSearch
     */
    public function multiAjaxSearch($query, $from, $count, $startDate = null, $endDate = null){
	$app_config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
	$defaults = $this->newsConfig['default'];

	if ($_POST['google_exact_words'] != '') {
	    $query .= ' "' . $_POST['google_exact_words'] . '" ';
	}
	if ($_POST['google_or_words1'] != '') {
	    $query .= ($query == ''?'':' OR ') . $_POST['google_or_words1'];
	}
	if ($_POST['google_or_words2'] != '') {
	    $query .= ($query == ''?'':' OR ') . $_POST['google_or_words2'];
	}
	if ($_POST['google_or_words3'] != '') {
	    $query .= ($query == ''?'':' OR ') . $_POST['google_or_words3'];
	}
	if ($_POST['google_no_words'] != '') {
	    $words = explode(' ', $_POST['google_no_words']);
	    foreach ($words as $word) {
		$query .= ' -' . $word;
	    }
	}

	$startDate = null;
	$endDate = null;

	$search = new \tariqa3\multiAjaxSearch($query, $defaults[strtolower($_POST['engine'])]['source_id'], $app_config['application']['service_url'],
	    'searchResult', false, null, null, null, null, \tariqa3\multiAjaxSearch::ORIGINAL_SYNTAX);

	$source = \tariqa3\statics::getSource($defaults[strtolower($_POST['engine'])]['source_id']);

	if ($source->source_data != null){
	    $search->setSpecificData($source->source_data);
	}

	return $search;
			    /*$specific_data = '';
							if ($_POST['google_exact_words'] != ''){
								$specific_data .= ($specific_data == ''?'':'&') . 'as_epq=' . \MetaNull\Tools\mTools::rawurlencode($_POST['google_exact_words']);
							}
							$or_words = '';
							if ($_POST['google_or_words1'] != ''){
								$or_words .= ($or_words == ''?'':'+') . \MetaNull\Tools\mTools::rawurlencode($_POST['google_or_words1']);
							}
							if ($_POST['google_or_words2'] != ''){
								$or_words .= ($or_words == ''?'':'+') . \MetaNull\Tools\mTools::rawurlencode($_POST['google_or_words2']);
							}
							if ($_POST['google_or_words3'] != ''){
								$or_words .= ($or_words == ''?'':'+') . \MetaNull\Tools\mTools::rawurlencode($_POST['google_or_words3']);
							}
							if ($or_words != ''){
								$specific_data .= ($specific_data == ''?'':'&') . 'as_oq=' . $or_words;
							}
							if ($_POST['google_no_words'] != ''){
								$specific_data .= ($specific_data == ''?'':'&') . 'as_eq=' . \MetaNull\Tools\mTools::rawurlencode($_POST['google_no_words']);
							}
							if ($_POST['google_language'] != ''){
								$specific_data .= ($specific_data == ''?'':'&') . 'lr=' . \MetaNull\Tools\mTools::rawurlencode($_POST['google_language']);
							}
							if ($_POST['google_file_type'] != ''){
								$specific_data .= ($specific_data == ''?'':'&') . 'as_filetype=' . \MetaNull\Tools\mTools::rawurlencode($_POST['google_file_type']);
							}
							if ($_POST['google_site'] != ''){
								$specific_data .= ($specific_data == ''?'':'&') . 'as_sitesearch=' . $_POST['google_site'];
							}
							if ($_POST['google_date'] != ''){
								$specific_data .= ($specific_data == ''?'':'&') . 'as_qdr=' . \MetaNull\Tools\mTools::rawurlencode($_POST['google_date']);
							}
							if ($_POST['google_usage'] != ''){
								$specific_data .= ($specific_data == ''?'':'&') . 'as_rights=' . $_POST['google_usage'];
							}
							if ($_POST['google_keywords'] != ''){
								$specific_data .= ($specific_data == ''?'':'&') . 'as_occt=' . $_POST['google_keywords'];
							}
							if ($_POST['google_regions'] != ''){
								$specific_data .= ($specific_data == ''?'':'&') . 'cr=' . \MetaNull\Tools\mTools::rawurlencode($_POST['google_regions']);
							}
							if ($_POST['google_range1'] != ''){
								$specific_data .= ($specific_data == ''?'':'&') . 'as_nlo=' . \MetaNull\Tools\mTools::rawurlencode($_POST['google_range1']);
							}
							if ($_POST['google_range2'] != ''){
								$specific_data .= ($specific_data == ''?'':'&') . 'as_nhi=' . \MetaNull\Tools\mTools::rawurlencode($_POST['google_range2']);
							}
							$specific_data .= ($specific_data == ''?'':'&') . 'safe=' . $_POST['google_safe_search'];

							if ($specific_data != ''){
								$search->setSpecificData(\MetaNull\Tools\mTools::rawurlencode($specific_data));
							}*/
    }
    
    /**
     * Gets the POST data used for saving a search in the briefcase
     * @param string $query_txt The query string text
     * @param Query $query The query
     * @param int $start_date The start date (unix timestamp) [OPTIONAL]
     * @param int $end_date The end date (unix timestamp) [OPTIONAL]
     * @param array $additional_parameters Additional parameters [OPTIONAL]
     * @access public
     * @return string
     */
    public function getSavePost($query_txt, $query, $start_date = null, $end_date = null, $additional_parameters = array()){
	$c = null;
	if ($start_date == null || $end_date == null){
	    $c = \MetaNull\News\unifiedQuerySyntax::getDatesCondition(rawurldecode($query_txt));
	}

	if ($c == null || !array_key_exists('string', $c)) {
	    $query_txt .= ' ' . $query->time_range;
	    $start_date = '';
	    $end_date = '';
	}

	$selected = ($query->source->engine_id == 'GoogleWeb' || $query->source->engine_id == 'Google'?2:
		($query->source->engine_id == 'GoogleNews'?3:
		($query->source->engine_id == 'GoogleBlogs'?4:
		($query->source->engine_id == 'GoogleImages'?5:-1))));
	$engine = $query->source->engine_id;
	if ($engine == 'Google') $engine = 'GoogleWeb';
	$post_data = "selected={$selected}&engine={$engine}&query={$query_txt}&" .
		"&results_per_page={$this->newsConfig['search']['default']['results-per-page']}";

	return $post_data;
    }
}
}
?>