<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3\search{
/**
 * Base class for fetching the news results from an engine
 * @author Cosmin Popescu
 *
 */
class LexisNexisEngine extends searchEngine {

    /**
     * Constructs the object
     * @param array $newsConfig The news configuration array
     * @access public
     * @return void
     */
    public function __construct($newsConfig) {
	parent::__construct($newsConfig);
    }

    /**
     * Fetches a list of articles
     * @param newsQuery $query The query
     * @access public
     * @return tariqaSearchResultSet
     */
    public function listArticles($query) {
	$source = \tariqa3\statics::getSource($query->source_id);
	$source_arr = array();

	$sort_order = \LexisNexisQuery::SO_IMPLIED;

	$parts = explode(";", $source->source_data);
	foreach ($parts as $s) {
	    $source_arr[] = (int) $s;
	}

	$retrieve_articles = true;

	if ($query->specific_data != null) {
	    $data = \tariqa3\statics::post2array(\MetaNull\Tools\mTools::rawurldecode($query->specific_data));
	    if (array_key_exists('sources', $data)) {
		$source_arr = array();
		$sources = explode(';', $data['sources']);

		foreach ($sources as $source) {
		    $source_arr[] = (int) $source;
		}
	    }
	    if (array_key_exists('sort_by', $data)) {
		$sort_order = $data['sort_by'];
	    }
	    if (array_key_exists('no_article', $data)) {
		$retrieve_articles = false;
	    }
	}

	$queryObj = new \LexisNexisQuery(
		$query->query, $source_arr, $sort_order, $query->start_date, $query->end_date
	);

	$results = \tariqa3\statics::$tariqaClient->LexisNexisSearch(\tariqa3\statics::$tariqaToken, $queryObj);

	$result = new tariqaSearchResultSet();

	$result->query = $query->query;
	$result->engine = $query->engine_id;
	$engine = \tariqa3\statics::getEngine($query->engine_id);
	$result->engine_name = $engine->name;
	$result->logo = $engine->logo_url;
	$result->provider_url = $engine->doc_url;
	$result->source = $query->source_id;
	$result->from = $query->first;
	$result->count = $results->documentsFound;

	if (!$retrieve_articles) {
	    $result->documents = array();
	    return $result;
	}

	if ($results->documentsFound > 0) {
	    $first = 1;
	    if ($query->first != null) $first = $query->first;
	    $end = $this->newsConfig['default']['results-per-page'];
	    if ($query->count != null) $end = $first + $query->count - 1;
	    if ($results->documentsFound <= $end) $end = $results->documentsFound;
	    $rs = \tariqa3\statics::$tariqaClient->LexisNexisGetDocuments(
		    \tariqa3\statics::$tariqaToken, $results->searchId, $first, $end
	    );

	    $result->results_per_page = $query->count !== null?$query->count:count($rs);
	    $result->documents = array();

	    /* @var $article LexisNexisDocument */
	    foreach ($rs as $article) {
		$document = new tariqaDocument();
		$document->title = ($article->headline != null?$article->headline:'N/A');
		$document->id = $query->engine_id . ':' .
			$query->source_id . ':' .
			urlencode($article->id);
		$document->url = $this->link('LexisNexis:' . $query->source_id . ':' . urlencode($article->id));
		$document->js_link = $this->js_link(
			'LexisNexis:' . $query->source_id . ':' . urlencode($article->id),
			$article->headline
		);

		$document->date = $article->date;

		$document->summary = $article->lead;
		$document->publisher = $article->publisher;

		$result->documents[] = $document;
	    }
	}

	return $result;
    }

    /**
     * Gets a specific article
     * @param string $article_id The article identifier
     * @access public
     * @abstract
     * @return tariqaFullDocument
     */
    public function getArticle($article_id) {
	$parts = explode(':', $article_id, 3);
	if (count($parts) != 3) {
	    throw new \Exception('Document identifier not well formed');
	}

	$lexisnexisdoc = \tariqa3\statics::$tariqaClient->LexisNexisGetFullDocument(\tariqa3\statics::$tariqaToken, $parts[2]);

	$result = new tariqaFullDocument();
	$result->id = $article_id;
	$result->engine = $parts[0];
	$result->source = $parts[1];
	$result->document_id = $lexisnexisdoc->id;
	$result->title = $lexisnexisdoc->headline;
	$result->date = $lexisnexisdoc->date;
	$result->publisher = $lexisnexisdoc->publisher;

	$body = '';
	foreach ($lexisnexisdoc->content as $paragraph) $body .= "<p>" . $paragraph . "</p>";
	$result->body = $body;

	return $result;
    }

    /**
     * Gets the multi ajax search object
     * @param string $query The query string
     * @param int $from The first result to display
     * @param int $count The number of results to display
     * @param DateTime $startDate The start date [OPTIONAL]
     * @param DateTime $endDate The end date [OPTIONAL]
     * @access public
     * @return multiAjaxSearch
     */
    public function multiAjaxSearch($query, $from, $count, $startDate = null, $endDate = null){
	$app_config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
	$defaults = $this->newsConfig['default'];
	$search = new \tariqa3\multiAjaxSearch($query, $defaults['lexis']['tariqa_source_id'], $app_config['application']['service_url'],
	    'searchResult', false, ($startDate == null?null:$startDate->getTimestamp() + $startDate->getOffset()),
	    ($endDate == null?null:$endDate->getTimestamp() + $endDate->getOffset()), $from, $count, \tariqa3\multiAjaxSearch::ORIGINAL_SYNTAX);
	$data = 'sources=' . $_POST['selected_sources'] . '&sort_by=' . $_POST['sort_by'];
	$search->setSpecificData(rawurlencode($data));

	return $search;
    }

    /**
     * Gets the POST data used for saving a search in the briefcase
     * @param string $query_txt The query string text
     * @param Query $query The query
     * @param int $start_date The start date (unix timestamp) [OPTIONAL]
     * @param int $end_date The end date (unix timestamp) [OPTIONAL]
     * @param array $additional_parameters Additional parameters [OPTIONAL]
     * @access public
     * @return string
     */
    public function getSavePost($query_txt, $query, $start_date = null, $end_date = null, $additional_parameters = array()){
	$c = null;
	if ($start_date == null || $end_date == null){
	    $c = \MetaNull\News\unifiedQuerySyntax::getDatesCondition(rawurldecode($query_txt));
	}
	if ($c == null || !array_key_exists('string', $c)) {
	    $query_txt .= ' ' . $query->time_range;
	    $start_date = '';
	    $end_date = '';
	}
	$sources_names = \MetaNull\Tools\mTools::rawurlencode($query->source->description);
	$post_data = "selected=0&engine=LexisNexis&query={$query_txt}&start_date={$start_date}&end_date={$end_date}" .
		"&results_per_page={$this->newsConfig['search']['default']['results-per-page']}&sort_by=Implied&sources_select=" .
		"&selected_sources={$query->source->source_data}&selected_sources_names={$sources_names}";

	return $post_data;
    }
}
}
?>