<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3\search{
/**
 * Base class for fetching the news results from the OxfordAnalytica engine
 * @author Cosmin Popescu
 *
 */
class OdinEngine extends searchEngine {

    /**
     * Constructs the object
     * @param array $newsConfig The news configuration array
     * @access public
     * @return void
     */
    public function __construct($newsConfig) {
	parent::__construct($newsConfig);
    }

    /**
     * Fetches a list of articles
     * @param newsQuery $query The query
     * @access public
     * @return tariqaSearchResultSet
     */
    public function listArticles($query) {
	$query = array();
	$query[] = new \Pair('query', 'romania');
	$query[] = new \Pair('date_type', 'range');
	$query[] = new \Pair('range', 'null');
	$query[] = new \Pair('start_date', '');
	$query[] = new \Pair('end_date', '');
	$query[] = new \Pair('from_field_name', 'start_date');
	$query[] = new \Pair('to_field_name', 'end_date');
	$query[] = new \Pair('range_field_name', 'range');
	$query[] = new \Pair('date_type_field_name', 'date_type');
	$query[] = new \Pair('results_per_page', '20');
	$query[] = new \Pair('source_3', 'on');
	$request = new \WebRequest('https://webgate.ec.europa.eu/tariqa/index.php?module=search&type=3&search_type=1', $query, false, \WebRequest::HTTP_POST, true);
	$doc = \tariqa3\statics::$tariqaClient->fetchurl(\tariqa3\statics::$tariqaToken, $request);
	\MetaNull\Tools\mDump::dumpVariable($doc);
	return new tariqaSearchResultSet();

	$query = array();
	$query[] = new \Pair('user', 'niemeaa');
	$query[] = new \Pair('password', 'tariqaPRO09');
	$query[] = new \Pair('authmethod', 'default');
	$query[] = new \Pair('url', '/');
	$request = new \WebRequest('https://odin.consilium.europa.eu/login_post.yaws', $query, false, \WebRequest::HTTP_POST, true);
	\MetaNull\Tools\mDump::dumpVariable($request);
	$doc = \tariqa3\statics::$tariqaClient->fetchurl(\tariqa3\statics::$tariqaToken, $request);
	\MetaNull\Tools\mDump::dumpVariable($doc);
	return new tariqaSearchResultSet();
    }

    /**
     * Gets a specific article
     * @param string $article_id The article identifier
     * @access public
     * @abstract
     * @return tariqaFullDocument
     */
    public function getArticle($article_id) {
	$parts = explode(':', $article_id, 3);
	if (count($parts) != 3) {
	    throw new \Exception('Document identifier not well formed');
	}

	if (preg_match('/^DB[\d]+$/', $parts[2])){
	    $page = '/display.aspx?ItemID=' . $parts[2];
	}
	else {
	    if (strpos($parts[2], '?') === false){
		$page = '/display.aspx?' . $parts[2];
	    }
	    else {
		$page = str_replace('?', '&', $parts[2]);
	    }
	}

	$oxandoc = \tariqa3\statics::$tariqaClient->oxanFetchUrl(\tariqa3\statics::$tariqaToken, $page);

	$options = array(
		"drop-proprietary-attributes" => true,
		"doctype" => "omit",
		"clean" => true,
		"output-xhtml" => true,
	);
	$tidy = tidy_parse_string( $oxandoc->body, $options, "utf8" );
	$tidy->cleanRepair();
	$body = (string)$tidy;
	$body = \preg_replace('/xmlns="[^"]*"/', "", $body);
	$doc = new \DOMDocument('1.0', 'UTF-8');
	$doc->loadXML($body);

	$result = new tariqaFullDocument();
	$result->id = $article_id;
	$result->engine = $parts[0];
	$result->source = $parts[1];
	$result->document_id = $parts[2];

	$result->date = strtotime($oxandoc->date);
	$result->publisher = null;
	$result->body = $oxandoc->body;

	$result->body = preg_replace('/<img([^s|s^r|sr^c]*)src[ |\t|\n|\r]*=[ |\t|\n|\r]*"([^"]*)"([^>]*)>/', '<img\1src="' . self::OXAN_URL . '\2"\3>', $result->body);
	//$result->body = preg_replace('/<a([^h|h^r|hr^e|hre^f]*)href[ |\t|\n|\r]*=[ |\t|\n|\r]*"([^"]*)"([^>]*)>/', '<a\1href="' . self::OXAN_URL . '\2"\3>', $result->body);

	$result->title = $oxandoc->headline;

	if ($oxandoc->headline == '' || $oxandoc->headline == null) {
	    $xp = new \DOMXPath($doc);
	    $rs = $xp->query("//p[@class='subject']");
	    if ($rs->length > 0) {
		$result->title = $rs->item(0)->nodeValue;
	    }
	}

	//\MetaNull\Tools\mDump::dumpVariable($result);

	return $result;
    }

}
}
?>