<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3\search{
/**
 * Base class for fetching the news results from the Virage engine
 * @author Cosmin Popescu
 *
 */
class VirageEngine extends searchEngine {
    /**
     * Constructs the object
     * @param array $newsConfig The news configuration array
     * @access public
     * @return void
     */
    public function __construct($newsConfig) {
	parent::__construct($newsConfig);
    }

    /**
     * Gets the document summary
     * @param VirageDocument $article The Virage document
     * @param string $app_path The path to the application
     * @param string $img_url The image URL
     * @param string $img_onclick The onclick part of the images
     * @access protected
     * @return string
     */
    protected function getDocumentSummary($article, $path, $img_url, $img_onclick) {
	if (substr($path, -1) != '/' && $path != '') $path .= '/';
	/*$content = '';
	foreach ($article->softSoundWords as $word){
	    $content .= ($content == ''?'':' ') . $word;
	}*/

	//$c = preg_replace('/<SIL>|<span[^>]*>[^<]*<\/span>/', '', $article->documentContent);

	//$content = preg_replace('/<[^>]*>/', '', $article->documentContent);
	$f = fopen("d:/webserver/temp/virage_images_" . $article->document_id, "wt");
	fwrite($f, base64_encode(serialize($article->images)));
	fclose($f);

	$summary = '';

	preg_match_all('/([a-zA-Z]+[\s,\t\n\r\-]+){0,4}<font color=red>([^>]*)<\/font>[\s,\t\n\r\-]+([a-zA-Z]+[\s,\t\n\r\-]+){0,4}/i', $article->documentContent, $matches);

	$n = 0;

	$ii = 0;

	if (count($matches) > 1){
	    foreach ($matches[0] as $key => $context){
		while ( $n < count($article->softSoundWords) && $article->softSoundWords[$n] != $matches[2][$key]) $n++;
		if ($n < count($article->softSoundWords)){
		    while ($ii < count($article->images->smallImageMSegTime) - 1 && $article->images->smallImageMSegTime[$ii + 1] < $article->softSoundMsecTime[$n]){
			$ii++;
		    }

		    $summary .= ($summary == ''?'':' ... ') . preg_replace('/<font color=red>([^<]*)<\/font>/',
			'<a href="#" onclick="moveToThumbnail(' . $article->images->smallImageMSegTime[$ii] . ', ' . $article->document_id . '); return false;"><strong>\1</strong></a>', $context);
		}
		else {
		    $summary .= ($summary == ''?'':' ... ') . preg_replace('/<font color=red>([^<]*)<\/font>/',
			'<strong>\1</strong>', $context);
		}
	    }
	}

	$tpl = new \MetaNull\Application\MTemplate('m');
	$tpl->loadTemplate($path . 'themes/default/modules/tariqa3/Search/virage.html');

	$tpl->data['images'] = array();
	$tpl->data['doc_id'] = $article->document_id;

	foreach ($article->images->smallImageContent as $key => $content){
	    $tpl->data['images'][] = array(
		'time' => $article->images->smallImageMSegTime[$key],
		'href' => str_replace('@time@', $article->images->smallImageMSegTime[$key], $img_url),
		'onclick' => str_replace('@time@', $article->images->smallImageMSegTime[$key], $img_onclick),
		'idx' => $key,
	    );
	}

	$tpl->data['summary'] = $summary;

	$i = 0;

	$summary = '';

	$headlines = array();

	foreach ($article->ocrWords as $key => $word){
	    if (preg_match('/<font color=red>/', $word)){
		$headlines[] = array(
		    'headline' => str_replace('º', '', $word),
		    'time' => $article->ocrMsecTime[$key],
		);
	    }
	}

	$final_headlines = array();

	$current = $headlines[0];

	for ($j = 1; $j < count($headlines); $j++){
	    $w = similar_text(preg_replace('/<[^>]*>/', '', $current['headline']), preg_replace('/<[^>]*>/', '', $headlines[$j]['headline']), $percent);
	    if ($percent >= 70){
		if (preg_match_all('/<[^\/][^>]*>/', $current['headline']) < preg_match_all('/<[^\/][^>]*>/', $headlines[$j]['headline'])){
		    $current = $headlines[$j];
		}
	    }
	    else {
		$final_headlines[] = $current;
		$current = $headlines[$j];
	    }
	}

	$final_headlines[] = $current;

	$i = 0;

	foreach ($final_headlines as $headline){
	    if ($i < count($article->images->smallImageMSegTime)){
		while ($i < count($article->images->smallImageMSegTime) - 1 && $article->images->smallImageMSegTime[$i + 1] < $headline['time']){
		    $i++;
		}

		$summary .= ($summary == ''?'':'<br/>') . preg_replace('/<font color=red>([^<]*)<\/font>/',
		    '<a href="#" onclick="moveToThumbnail(' . $article->images->smallImageMSegTime[$i] . ', ' . $article->document_id . '); return false;"><strong>\1</strong></a>', $headline['headline']);
	    }
	    else {
		$summary .= ($summary == ''?'':'<br/>') . preg_replace('/<font color=red>([^<]*)<\/font>/',
		    '<strong>\1</strong>', $headline['headline']);
	    }
	}

	$tpl->data['ocr_summary'] = $summary;

	return '<div style="display: none;" id="scrollToNotLoaded"></div>' . $tpl->transform();
    }

    /**
     * Gets the documents summary for testing purposes
     * @param VirageDocument $article The Virage document
     * @access protected
     * @return string
     */
    protected function getDocumentSummaryTest($article) {
	$_summary = $article->documentContent . "<br/><br/>" . $article->getOCRWords();
	$summary = '';
	foreach ($article->ocrMsecTime as $key => $time){
	    $input = $time;
	    $uSec = $input % 1000;
	    $input = floor($input / 1000);

	    $seconds = $input % 60;
	    $input = floor($input / 60);

	    $minutes = $input % 60;
	    $input = floor($input / 60);

	    $summary .= $minutes . ':' . $seconds  . ' - ' . $article->ocrWords[$key] . '<br/>';
	}
	$_summary = $summary;

	$last_time = 0;

	foreach ($article->softSoundWords as $key => $word){
	    $pre = ''; $post = '';
	    if ($article->softSoundWeights[$key] <= 25){
		$pre = '<span style="color: red">';
		$post = '</span>';
	    }

	    $silence = preg_replace('/<[^>]*>/', '', $word) == '...';

	    //error_log($last_time . ' last time. ' . $article->softSoundMsecTime[$key] . ' : ' . $article->softSoundWeights[$key] . ' -> ' . $pre . $word . $post);
	    if ((!$silence && ($article->softSoundMsecTime[$key] - $last_time > 1500) && $last_time != 0)) {
		$_summary .= '<br/><br/>';
	    }

	    if ($word != '<SIL>' && $word != '<s>'){
		$_summary .= $pre . $word . $post . ' ';
	    }

	    if (!$silence){
		$last_time = $article->softSoundMsecTime[$key];
	    }
	}

	return $_summary;
    }

    /**
     * Fetches a list of articles
     * @param newsQuery $query The query
     * @access public
     * @return tariqaSearchResultSet
     */
    public function listArticles($query) {
	$queryObj = new \VirageSearchQuery();
	$queryObj->query = $query->query;
	if ($queryObj->query == '') $query = '*';
	$queryObj->minDate = $query->start_date;
	$queryObj->maxDate = $query->end_date;
	if ($query->count != null) $queryObj->maxResults = $query->count;

	$queryObj->stemming = true;
	if ($query->specific_data != null) {
	    $data = \tariqa3\statics::post2array(\MetaNull\Tools\mTools::rawurldecode($query->specific_data));

	    if (array_key_exists('sort_by', $data)) $queryObj->sort = $data['sort_by'];
	    if (array_key_exists('sort_order', $data)) $queryObj->sortOrder = $data['sort_order'];
	    if (array_key_exists('file', $data)) $queryObj->fileName = $data['file'];
	    if (array_key_exists('url', $data)) $queryObj->url = $data['url'];
	    if (array_key_exists('stem', $data) && $data['stem'] == 'no') $queryObj->stemming = false;
	}

	$results = \tariqa3\statics::$tariqaClient->VirageSearch2(\tariqa3\statics::$tariqaToken, $queryObj, true);

	$result = new tariqaSearchResultSet();

	$result->query = $query->query;
	$engine = \tariqa3\statics::getEngine($query->engine_id);
	$result->engine_name = $engine->name;
	$result->engine = $query->engine_id;
	$result->source = $query->source_id;
	$result->from = $query->first;

	$result->count = $results->resultsFound;
	$result->results_per_page = $query->count !== null?$query->count:count($results->documents);

	$result->documents = array();

	/* @var $article VirageDocument */
	foreach ($results->documents as $article) {
	    $document = new tariqaDocument();

	    $document->title = $article->title;
	    $document->id = $query->engine_id . ':' .
		    $query->source_id . ':' .
		    urlencode($article->document_id);
	    $document->url = $this->link('Virage::' . urlencode($article->document_id . '&' . $article->links));
	    $document->js_link = $this->js_link('Virage::' . urlencode($article->document_id . '&' . $article->links), $article->title);

	    $document->date = strtotime($article->date);

	    $document->summary = $this->getDocumentSummary($article, TARIQA3_REL_PATH, $document->url . '&start=@time@', '');

	    $document->publisher = null;

	    $result->documents[] = $document;
	}

	return $result;
    }

    /**
     * Gets a specific article
     * @param string $article_id The article identifier
     * @access public
     * @abstract
     * @return tariqaFullDocument
     */
    public function getArticle($article_id) {
	$parts = explode(':', $article_id, 3);
	if (count($parts) != 3) {
	    throw new \Exception('Document identifier not well formed');
	}

	$viragedoc = \tariqa3\statics::$tariqaClient->VirageGetDocument(\tariqa3\statics::$tariqaToken, $parts[2], true);

	$result = new tariqaFullDocument();
	$result->id = $article_id;
	$result->engine = $parts[0];
	$result->source = $parts[1];
	$result->document_id = $viragedoc->document_id;

	$result->title = $viragedoc->title;

	$result->date = strtotime($viragedoc->date);
	if (strpos($viragedoc->fileName, '/') === false) $viragedoc->fileName = '/' . $viragedoc->fileName;
	$pattern = '.*/([^/\?]*)[\?]*(.*)$';
	$query_string = ereg_replace($pattern, '\2', $viragedoc->fileName);
	$file_name = $this->newsConfig['virage']['movie-url'] . '/' .
		ereg_replace($pattern, '\1', $viragedoc->fileName) .
		($query_string != ''?'?' . $query_string : '');
	$result->publisher = $file_name;
	//$result->body = $viragedoc->documentContent;

	$tpl = new \MetaNull\Application\MTemplate('m');
	$tpl->loadTemplate('themes/default/modules/tariqa3/Article/virage.html');

	$start = 0;
	if (array_key_exists('start', $_GET)){
	    $start = round($_GET['start'] / 1000);
	}

	preg_match('/archive\/([^\/\?]*)[\?]*.*$/', $result->publisher, $matches);

	if (count($matches) == 2){
	    $result->publisher = 'asx/' . $start . '/' . $matches[1] . '.asx';
	}

	$tpl->data['url'] = $result->publisher;
	$tpl->data['summary'] = $this->getDocumentSummary($viragedoc, '', '#', 'moveTime(@time@); return false;');

	$result->body = $tpl->transform();

	return $result;
    }

    /**
     * Gets the multi ajax search object
     * @param string $query The query string
     * @param int $from The first result to display
     * @param int $count The number of results to display
     * @param DateTime $startDate The start date [OPTIONAL]
     * @param DateTime $endDate The end date [OPTIONAL]
     * @access public
     * @return multiAjaxSearch
     */
    public function multiAjaxSearch($query, $from, $count, $startDate = null, $endDate = null){
	$app_config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
	$defaults = $this->newsConfig['default'];
	$search = new \tariqa3\multiAjaxSearch($query, $defaults['virage']['source_id'], $app_config['application']['service_url'],
	    'searchResult', false, ($startDate == null?null:$startDate->getTimestamp() + $startDate->getOffset()),
	    ($endDate == null?null:$endDate->getTimestamp() + $endDate->getOffset()), $from, $count, \tariqa3\multiAjaxSearch::ORIGINAL_SYNTAX);
	$data = 'sort_by=' . $_POST['sort_by'] . '&' . 'sort_order=' . $_POST['sort_order'];

	if ($_POST['file'] != '') {
	    $data .= '&file=' . rawurlencode($_POST['file']);
	}

	if ($_POST['url'] != '') {
	    $data .= '&url=' . rawurlencode($_POST['url']);
	}

	if ($_POST['use_stem'] == 'no') {
	    $data .= '&stem=no';
	}

	$search->setSpecificData(rawurlencode($data));

	return $search;
    }

    /**
     * Gets the POST data used for saving a search in the briefcase
     * @param string $query_txt The query string text
     * @param Query $query The query
     * @param int $start_date The start date (unix timestamp) [OPTIONAL]
     * @param int $end_date The end date (unix timestamp) [OPTIONAL]
     * @param array $additional_parameters Additional parameters [OPTIONAL]
     * @access public
     * @return string
     */
    public function getSavePost($query_txt, $query, $start_date = null, $end_date = null, $additional_parameters = array()){
	return '';
    }
}
}
?>