<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace tariqa3{
	/**
	 * Tarîqa 3.0 Application's base module (takes care of the general layout)
	 * @package tariqa3
	 * @author Pascal Havelange
	 * @copyright © EUROPEAN COMMISSION, 2010
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	abstract class tariqa3Module extends baseModule_RELEX_TARIQANG {

		/**
		 * Array of tariqa3ModuleDescriptor objects, containing the full list of tariqa3Modules in the application
		 * @var \tariqa3\tariqa3ModuleDescriptor[]
		 */
		public $moduleDescriptors;

		/**
		 * The default layout
		 * @var string
		 * @access private
		 */
		protected $layout = 'layout.html';

		/**
		 * Connection to the main Tarîqa 3.0 database	[SET BY THE APPLICATION]
		 * @var \MetaNull\Tools\mMysql
		 */
		public $db;

		/**
		 * The current language id
		 * @var string
		 */
		public $currentLanguage;
		/**
		 * The default language's id as set in the configuration file 	[SET BY THE APPLICATION]
		 * @var string
		 */
		public $defaultLanguage;
		/**
		 * The list of languages' ids set in the configuration 	[SET BY THE APPLICATION]
		 * @var string
		 */
		public $languageList;

		//Code added for MULTI AJAX calls
		/**
		 * The list of multi AJAX calls
		 * @var multiAjaxCall[]
		 * @access private
		 */
		private $multiAjaxCalls = array();

		/**
		* Construct the Module object
		* @param array $config The multidimentionnal array containing the application's configuration
		* @param boolean $set_infos If false, do not set the stylesheets and javascripts [OPTIONAL]
		* @param iCustomAuthentication $custom_authentication If true, then the ECAS authentication is skipped [OPTIONAL]
		*/
		public function __construct( $config, $set_infos = true, $custom_authentication = null ) {
		    if ($custom_authentication != null && $this->canProcessRequest()){
			$this->require_auth = false;

			$this->db = statics::open_db_connection($config['database']);

			$this->user = $custom_authentication->startSession($config);
			if ($this->user === false){
			    throw new \MetaNull\Authentication\authenticationException('Login failed');
			}

		    }
			parent::__construct( $config );
			if ($set_infos){
				$this->base_folder = Application::MODULES_BASE_FOLDER . '/' . preg_replace( "/[\\/\\\\]/", '/', get_class($this));
				$this->_isMenuable = true;
				// Set some basic info
				// $this->info_setTitle( $this->config['application']['name'] . ' ' . $this->config['application']['version'] );
				// $this->info_setDescription( $this->config['application']['name'] . ' ' . $this->config['application']['version'] );
				$this->info_setTitle( $this->getTitle() );
				$this->info_setDescription( $this->getDescription() );
				$this->info_setContentType( 'text/html' );
				$this->info_setCopyright( iconv( 'ISO-8859-1', 'UTF-8//TRANSLIT', $this->config['application']['copyright'] ));
				$this->info_setAuthor( $this->config['application']['author'] );
				$this->info_setLastUpdated();

				$this->info_setStylesheet(
					array(
						$this->getThemeFileUrl( 'styles/tariqa3.css' ),
						$this->getThemeFileUrl( 'styles/screen/layout.css' ),
						$this->getThemeFileUrl( 'styles/screen/text.css' ),
						$this->getThemeFileUrl( 'styles/print/layout.css' ),
						$this->getThemeFileUrl( 'styles/print/text.css' ),
						$this->getThemeFileUrl( 'styles/handheld/layout.css' ),
						$this->getThemeFileUrl( 'styles/handheld/text.css' ),

						$this->getTemplateFileUrl( 'styles/main.css' ),
					)
				);
				$this->info_setJavascript(
					array(
						'scripts/commons.js',
						'scripts/multi_ajax.js', 
						'scripts/xpath.js',
					)
				);

				if ($this->config['jquery']['use-it']){
				    $this->info_setJavascript(
					array(
					    'scripts/jquery-'.$this->config['jquery']['version'].'.js',
					    'scripts/jquery-ui-'.$this->config['jquery']['ui-js-version'].'.js',
					)
				    );

				    $this->info_setStylesheet(
					array(
					    $this->getThemeFileUrl( 'styles/jquery/' . $this->config['jquery']['theme'] . '/jquery-ui-'.$this->config['jquery']['ui-css-version'].'.css' ),
					)
				    );
				}
				
				$inline_js = <<<js
	var TARIQA_URL = '{$this->config['application']['url']}';
	var TARIQA_SERVICE_URL = '{$this->config['application']['service_url']}';
js;
				$this->info_setInlineJavascript($inline_js);

			}
		}

		//Code added for MULTI AJAX calls
		/**
		 * Adds a multi AJAX call to the page
		 * @param multiAjaxCall $call The multi ajax call
		 * @access public
		 * @return return
		 */
		public function addMultiAjaxCall($call) {
			$this->multiAjaxCalls[] = $call;
		}
		
		/**
		 * Gets the infos from a module and integrates them into the current module
		 * @param array $infos The module
		 * @access protected
		 * @return void
		 */
		protected function setMoreInfos($infos) {
			foreach ($this->infos as $key => $value){
				if (array_key_exists($key, $infos)){
					if ($key != 'onload'){
						if (is_array($value)){
							$this->infos[$key] = array_merge($this->infos[$key], $infos[$key]);
						}
					}
					else {
						$this->infos[$key] .= '; ' . $infos[$key];
					}
				}
			}

			foreach ($infos as $key => $value){
				if (!array_key_exists($key, $this->infos)){
					$this->infos[$key] = $value;
				}
			}

		}

		/**
		 * Generates the javascript code and inserts it into the HTML body to perform a multi AJAX search
		 * @param multiAjaxSearch[] $searches The multi AJAX searches to be performed
		 * @param string $onBegin The javascript code to be called before the search is performed
		 * @param string $onEnd The javascript code to be called after the search is performed
                 * @param boolean $refresh If true, then refresh the news [OPTIONAL]
		 * @access protected
		 * @return void
		 */
		protected function performMultiAjaxSearch($searches, $onBegin, $onEnd, $refresh = false) {
				$js_code = <<<js
   var SEARCHES = new Array();

js;

			/*@var $search multiAjaxSearch*/
			foreach ($searches as $search){
				$js_code .= $search->generate_js($refresh);
				$js_code .= <<<js
   SEARCHES.push({$search->getName()});
   
js;
			}

			$js_code .= <<<js
   performMultiAjaxSearch(SEARCHES, function(){{$onBegin}}, function(){{$onEnd}});

js;

			$js_code = <<<js
function performMultiAjaxSearchOnLoad(){
	{$js_code}
}

js;
			$this->info_setInlineJavascript($js_code);
			$this->info_setBodyOnLoad('performMultiAjaxSearchOnLoad()');
		}

		/**
		* Release resources, closes the database connection
		*/
		protected function onDestroy() {
			parent::onDestroy();
		}
		/**
		* Initialize the module (Connects to the database, check user rights, ...)
		*/
		protected function onInitialize() {
			parent::onInitialize();
		}
		/**
		* Informs the application wether this module have updated the configuration data
		* @return bool
		* @access public
		*/
		public function hasUpdatedConfiguration() {
			return false;
		}

		/**
		 * Sets the code for multi AJAX calls
		 * @access protected
		 * @return void
		 */
		protected function setMultiAjax() {
			//Code added for MULTI AJAX calls
			if (count($this->multiAjaxCalls) != 0){
				$js_code = '';
				foreach ($this->multiAjaxCalls as $call){
					$js_code .= <<<js
   {$call->generate_js()};

js;
				}

				$inline_multi_ajax = <<<js
	function pushMultiAjaxOnLoad(){
		{$js_code}
	}
js;
				$this->info_setInlineJavascript($inline_multi_ajax);
				$this->info_setBodyOnLoad('pushMultiAjaxOnLoad()');
			}

		}

		/**
		 * Gets the breaking news query (if it exists)
		 * @access protected
		 * @return Query
		 */
		protected function getBreakingNewsQuery() {
			if (array_key_exists('country_id', $_GET)){
				$queries = statics::listCountryQueries($_GET['country_id'], $this->user->get_access_level());
				/* @var $query Query */
				foreach ($queries as $query){
					if ($query->block_display_order == 0){
						return $query;
					}
				}
			}

			return null;
		}

		/**
		 * Sets the briefcase select folder form
		 * @param int $type_id The type identifier
		 * @access protected
		 * @return string
		 */
		protected function briefcaseSelectFolder($type_id) {
		    require_once($this->config['modules']['base'] . '/briefcase/Briefcase.class.php');
		    return Briefcase::selectFolderForm(null, $type_id, 0, $this->user, $this->db, $this->translationTable);
		}

		/**
		* Render the module
		* @return string
		*/
		protected function onExecute() {
			$template = new \MetaNull\Application\MTemplate( 'm' );
			$template->loadTemplate( $this->getThemeFilePath( $this->layout ));
			$template->data = $this->translationTable;

			// Additional template data concerning connected user
			$template->data['welcome'] = $this->translate('welcome');
			$template->data['logout'] = $this->translate('logout');
			$this->info_setJavascript('scripts/constants/' . $this->currentLanguage . '.js');
			foreach( $this->user->ldap_attributes as $k => $v ) {
				$template->data['currentUser/'.$k] = $v;
			}
			if( 'ECAS' == $template->data['currentUser/givenname'] ) {
				$template->data['currentUser/WelcomeMessage']  = $this->translate('loggedInAs') . '&nbsp;' . $this->user->user_id;
				if( $this->user->isMemberOf( 'RELEX_TARIQARX' )) {
					$template->data['currentUser/WelcomeMessage'] .= ' (RELEX)';
				} else
				if( $this->user->isMemberOf( 'RELEX_TARIQAEC' )) {
					$template->data['currentUser/WelcomeMessage'] .= ' (EUROPEAN COMMISSION)';
				} else
				if( $this->user->isMemberOf( 'RELEX_TARIQAEM' )) {
					$template->data['currentUser/WelcomeMessage'] .= ' (MEMBER STATE)';
				} else
				if( $this->user->isMemberOf( 'RELEX_TARIQANG' )) {
					$template->data['currentUser/WelcomeMessage'] .= ' (NGO)';
				}
			}else {
				$template->data['currentUser/WelcomeMessage'] = $this->translate('welcome') . '&nbsp;' . $template->data['currentUser/givenname'];
			}
			

			$template->data['module-result'] = $this->getPageContent();
			$template->data['mainMenu'] = array();
			$selected = 0;
			$i = 0;
                        $videos = statics::archiveRecords();
                        //$videos = 0;
			foreach( $this->moduleDescriptors as $midx => $module ) {
                                if ($module->keyName == 'archive' && $videos == 0){
                                    continue;
                                }
				if ($module->keyName == $this->getName()) $selected = $i;
				//$module->active = ($module->keyName == $this->getName()) ? 'active' : '';
				if ($module->keyName != 'newswires' || ($this->user->get_access_level() != tariqaUser::ACCESS_MS && $this->user->get_access_level() != tariqaUser::ACCESS_NG)){
                                    $menuData = (array)$module;
                                    $menuData['has_close'] = false;
                                    $template->data['mainMenu'][] = $menuData;
				}
				$i++;
			}

                        $prefered_countries = $this->user->get_preference('general/countries');
                        if ($prefered_countries != null && $this->getName() != 'article' && !isset($this->page_id)){
                            foreach ($prefered_countries as $country){
                                $_country = statics::get_country($country);
                                if ($this->getName() == 'countries' && array_key_exists('country_id', $_GET) && $_GET['country_id'] == $country) $selected = $i;
                                $menuData = array(
                                    'id' => 'prefered_country_' . $country,
                                    'label' => $_country->name,
                                    'link' => statics::URL('index.php', 'module=countries&country_id=' . $country),
                                    'title' => 'Prefered country: ' . $_country->name,
                                    'has_close' => true
                                );

                                $template->data['mainMenu'][] = $menuData;
                                $i++;
                            }
                        }

                        $prefered_themes = $this->user->get_preference('general/themes');
                        if ($prefered_themes != null && $this->getName() != 'article' && !isset($this->page_id)) {
                            foreach ($prefered_themes as $theme){
                                $_theme = statics::get_theme($theme);
                                if ($this->getName() == 'themes' && array_key_exists('theme_id', $_GET) && $_GET['theme_id'] == $theme) $selected = $i;
                                $menuData = array(
                                    'id' => 'prefered_theme_' . $theme,
                                    'label' => $_theme->title,
                                    'link' => statics::URL('index.php', 'module=themes&theme_id=' . $theme),
                                    'title' => 'Prefered theme: ' . $_theme->title,
                                    'has_close' => true
                                );

                                $template->data['mainMenu'][] = $menuData;
                                $i++;
                            }
                        }

                        $template->data['contribute_dialog'] = '';
                        
                        if (!array_key_exists('first_time', $_COOKIE)){
                            $tpl = new \MetaNull\Application\MTemplate('m');
                            $tpl->loadTemplate($this->getThemePath() . '/contribute.html');
                            $tpl->data = $this->translationTable;

                            $this->info_setBodyOnLoad('initContributeToBeta()');

                            $template->data['contribute_dialog'] = $tpl->transform();
                        }
                        \setcookie("first_time", true, time() + 60 * 60 * 12);

			$template->data['breadCrumb'] = array();
			$breadCrumb = $this->getBreadCrumb();
			if ($this->getName() == 'article'){
				if (array_key_exists('breadCrumb', $_SESSION)){
					$bc = array();

					/* @var $b tariqa3ModuleDescriptor */
					foreach ($_SESSION['breadCrumb'] as $b){
						if ($b->link == $breadCrumb[count($breadCrumb) - 1]->link){
							break;
						}
						$bc[] = $b;
					}
					$breadCrumb = array_merge($bc, $breadCrumb);
				}
			}

			if (preg_match('/[1|on|true]/', $this->config['application']['enable-share'])){
			    $this->info_setBodyOnLoad('SHARE_ENABLED = true;');
			}

                        $this->info_setBodyOnLoad('initTariqaMyAlert()');

			/*if (count($breadCrumb) >= 2){
				if ($breadCrumb[count($breadCrumb) - 1]->link == $breadCrumb[count($breadCrumb) - 2]->link){
					unset ($breadCrumb[count($breadCrumb) - 1]);
				}
			}*/

                        $i = 0;
                        $n = count($breadCrumb);
			
			foreach( $breadCrumb as $cidx => $crumb ) {
				$crumb->active = ($cidx == count($breadCrumb) - 1) ? 'ui-state-highlight' : 'ui-state-default';
                                $item = (array)$crumb;
                                $item['has_next'] = $i++ < $n - 1;
				$template->data['breadCrumb'][] = $item;
			}

			$_SESSION['breadCrumb'] = $breadCrumb;

			$timezones = $this->user->get_preference('general/timezones');
			if ($timezones == null){
				$template->data['display_timezones'] = false;
			}
			else {
				$template->data['display_timezones'] = true;
				$template->data['timezones'] = array();
				$timezones_js = '';
				foreach ($timezones as $zone){
					$id = 'timezone_' . str_replace('/', '1', $zone);
					$d = new \DateTime();
					$d->setTimezone(new \DateTimeZone($zone));
					$name = str_replace('_', ' ', $zone);
					$name = preg_replace('/^.*\/([^\/]*)$/', '\1', $name);
					$template->data['timezones'][] = array(
						'name' => $name,
						'id' => $id,
						'time' => $d->format('H:i'),
					);

					$timezones_js .= ($timezones_js == ''?'':', ') . '"' . $id . '"';
				}

				$timezones_js = '[' . $timezones_js . ']';

				$this->info_setInlineJavascript('var ZONES = ' . $timezones_js . ';');
				$sec = date("s");
				$sec = 60 - $sec;

				$this->info_setBodyOnLoad('startTimers(ZONES, ' . $sec . ')');
			}

			$query_string = preg_replace('/\&' . $this->config['application']['language-variable-name'] . '=[^\&]*/i', '', $_SERVER['QUERY_STRING']);

			$template->data['newstickers'] = array();
                        /*$template->data['ie_back_pos'] = '';
                        if (statics::_isIE()){
                            $template->data['ie_back_pos'] = 'background-position: 0px -2px;';
                        }*/

			$newstickers = $this->user->get_preference('general/newstickers');
			$bn = $this->getBreakingNewsQuery();

			if ($bn != null){
				$data = "title=" . $this->translate('breakingnews_title') . '&speed=1&query_id=' . $bn->query_id;
				$newstickers[] = $data;
			}

			$call = new multiAjaxCall();

			if ($newstickers != null){
				foreach ($newstickers as $i => $value){
					$data = statics::post2array($value);

					if (array_key_exists('url', $data)){
						$q = 'url=' . \MetaNull\Tools\mTools::rawurlencode($data['url']);
					}
					else if (array_key_exists('query_id', $data)){
						$q = 'query_id=' . $data['query_id'];
					}

					$url = new multiAjaxURL(statics::URL($this->config['application']['service_url'], 'action=loadNewstickers&' . $q . '&i=' . $i), 'get', false);
					$call->addURL($url);

					$title = \MetaNull\Tools\mTools::rawurldecode($data['title']);
					if (strlen($title) > 20) $title = substr($title, 0, 20) . '...';
					$template->data['newstickers'][] = array(
						'title' => $title,
						'i' => $i,
						'speed' => $data['speed'], 
					);
				}
			}
			
			if (count($call->getURLList()) != 0){
				$call->setProcessResult('newstickerLoaded');
				$js_code = <<<js
function loadNewstickers(){
	{$call->generate_js()};
}

js;

				$this->info_setInlineJavascript($js_code);
				$this->info_setBodyOnLoad('loadNewstickers()');
			}

			$template->data['pref_label'] = $this->translate('langswitch/pref');
			$template->data['pref_picture'] = $this->getThemeFileUrl('images/settings.png');
			$template->data['pref_onclick'] = 'openPreferences()';
			$template->data['width_ie_sucks'] = (statics::_isIE()?'145':'130');

                        if (count($_POST) == 0){
                            $template->data['appSiteOptions'] = array(
                                    array( "languages" =>
                                            array(
                                                    array( 'url' => statics::URL('index.php', $query_string . '&' . $this->config['application']['language-variable-name'] . '=en'), 'label' => $this->translate('langswitch/en'), 'picture' => $this->getThemeFileUrl('images/countries/gb.png'), 'onclick' => ''),
                                                    //array( 'url' => statics::URL('index.php', $query_string . '&' . $this->config['application']['language-variable-name'] . '=fr'), 'label' => $this->translate('langswitch/fr'), 'picture' => $this->getThemeFileUrl('images/countries/fr.png'), 'onclick' => ''),
                                                    //array( 'url' => statics::URL('index.php', $query_string . '&' . $this->config['application']['language-variable-name'] . '=it'), 'label' => $this->translate('langswitch/it'), 'picture' => $this->getThemeFileUrl('images/countries/it.png'), 'onclick' => ''),
                                                    /*array( 'url' => '#',
                                                            'label' => $this->translate('langswitch/pref'),
                                                            'picture' => $this->getThemeFileUrl('images/settings.png'),
                                                            'onclick' => 'openPreferences()',
                                                    )*/
                                            ),
                                    ),
                            );
                        }
                        else {
                            $post_params = '';
                            foreach ($_POST as $key => $value){
                                $post_params .= ($post_params == '' ? '' : '&') . $key . '=' . $value;
                            }
                            $template->data['appSiteOptions'] = array(
                                    array( "languages" =>
                                            array(
                                                    array( 'url' => '#',
                                                            'label' => $this->translate('langswitch/en'),
                                                            'picture' => $this->getThemeFileUrl('images/countries/gb.png'),
                                                            'onclick' => "js_open('index.php?{$query_string}&{$this->config['application']['language-variable-name']}=en', '_self', 'post', '{$post_params}')"
                                                         ), 
                                                    /*array( 'url' => '#',
                                                            'label' => $this->translate('langswitch/fr'),
                                                            'picture' => $this->getThemeFileUrl('images/countries/fr.png'),
                                                            'onclick' => "js_open('index.php?{$query_string}&{$this->config['application']['language-variable-name']}=fr', '_self', 'post', '{$post_params}')"
                                                         ),
                                                    array( 'url' => '#',
                                                            'label' => $this->translate('langswitch/it'),
                                                            'picture' => $this->getThemeFileUrl('images/countries/it.png'),
                                                            'onclick' => "js_open('index.php?{$query_string}&{$this->config['application']['language-variable-name']}=it', '_self', 'post', '{$post_params}')"
                                                         ),
                                                    array( 'url' => '#',
                                                            'label' => $this->translate('langswitch/pref'),
                                                            'picture' => $this->getThemeFileUrl('images/settings.png'),
                                                            'onclick' => 'openPreferences()',
                                                    )*/
                                            ),
                                    ),
                            );
                        }

			$this->info_setBodyOnLoad('initApplicationTabs(' . $selected . ')');

			if (array_key_exists($this->getName(), $this->config['briefcase']['modules'])){
			    $template->data['briefcase_select_folder'] = $this->briefcaseSelectFolder(1);
			    $this->info_setBodyOnLoad('initSelectFolderForm()');
			}

			$this->setMultiAjax();

			return $template->transform();
		}

		/**
		* Render the module's page (will be embedded in general layout)
		* @return string
		*/
		public abstract function getPageContent();

		/**
		 * Returns the short name of the module (used by menus)
		 * @return string
		 */
		public abstract function getName();
		/**
		 * Returns the title of the module (used in html/head/title)
		 * @return string
		 */
		public abstract function getTitle();
		/**
		 * Returns the description of the module (used in html/head/description)
		 * @return string
		 */
		public abstract function getDescription();
		/**
		 * Returns the url to the current module (used in menus)
		 * @return string
		 */
		public abstract function getLink();
		/**
		 * Return the items of the current breadcrumb path
		 * @return tariqa3ModuleDescriptor[]
		 */
		public abstract function getBreadCrumb();

		/**
		 * Indicates if the module should be displayed in the application's menu
		 * @return bool
		 */
		public final function isMenuable() {
			return $this->_isMenuable;
		}

		/**
		 * Indicates if the module should be displayed in the application's menu
		 *
		 * @var bool
		 */
		protected $_isMenuable = true;

		/**
		 * Sets the default layout
		 * @param string $layout The new default layout
		 * @access public 
		 * @final
		 * @return void
		 */
		public final function setDefaultLayout($layout) {
			$this->layout = $layout;
		}
	}
}
?>