<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3{

/**
 * Helper class extending the ECAS user class in order to also include the Tariqa user preferences
 * @author Cosmin Popescu, Pascal Havelange
 * @copyright © EUROPEAN COMMISSION, 2010
 * @package tariqa3
 * @license http://ec.europa.eu/idabc/eupl
 */
class tariqaAuthentication extends \MetaNull\Commission\EC_Authentication {
    /**
     * Constructor
     *
     * @param string $session_name HTTP Session Name
     * @param string $ssl_certificate Full Path to the SSL Certificate
     * @param string $application_url Base URL of your application (where ECAS has to redirect the user in case of successful authentication)
     * @access public
     */
    public function __construct( $session_name, $application_url, $ssl_certificate ) {
	parent::__construct($session_name, $application_url, $ssl_certificate);
    }

    /**
     * Establish a session (and proceed with authentication if needed)
     * @param bool $login If set to True also login to the system, otherwise just create an HTTP session (this parameter should always be set to true, but at logoff time)
     * @return tariqaUser|bool An iUser object in case of success, false otherwise
     */
    public function tariqaStartSession( $login = true ) {
	if( headers_sent() ) {
	    throw new \MetaNull\Authentication\authenticationException( 'HTTP Headers already sent!' );
	}
	if (session_name() != $this->session_name) {
	    session_name( $this->session_name );
	    session_start();
	}

	if( true === $login ) {
	    if( !$this->sessionEstablished() ) {
		if( !isset( $_GET['ticket']) ) {

		    // Allow to redirect after login -----------------------
		    $_SESSION['SCRIPT_URL'] = $_SERVER['SCRIPT_URL'];
		    if( count($_GET) > 0) {
			$_SESSION['QUERY_STRING'] = $_SERVER['QUERY_STRING'];
		    }

		    $this->call_ecas_login_page();
		    return false;
		} else {
		    $user_id = $this->checkECASTicket( $_GET['ticket'] );
		    if( false === $user_id ) {
			throw new \MetaNull\Authentication\authenticationException( 'Authentication failed!' );
		    }

		    // Redirect after login if requested -------------------
		    if( array_key_exists( 'QUERY_STRING', $_SESSION )) {
			$redirect = $_SESSION['QUERY_STRING'];
			unset( $_SESSION['QUERY_STRING'] );
			header( "Location: {$_SESSION['SCRIPT_URL']}?{$redirect}" );
		    }

		    $_SESSION['ecasuserid'] = $user_id;
		    return $this->tariqaGetUser($user_id);
		}
	    } else {
		return $this->tariqaGetUser($_SESSION['ecasuserid']);
	    }
	}
	return false;
    }

    /**
     * Retrieves the user object
     * @param string $user_id The LDAP user identifier
     * @access private
     * @return tariqaUser
     */
    private function tariqaGetUser($user_id) {
	$user = \MetaNull\Tools\mCache::loadVariable("users/" . $user_id, null, true);
	if ($user != null) {
	    return $user;
	}
	$user = new tariqaUser( $_SESSION['ecasuserid'], true );
	\MetaNull\Tools\mCache::saveVariable($user, "users/" . $user_id, true);
	return $user;
    }


}
}
?>
