<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

/**
 * Tarîqa 3.0 - Core components
 * @author Pascal Havelange, Cosmin Popescu
 * @copyright © EUROPEAN COMMISSION, 2009-2010
 *
 * @license http://ec.europa.eu/idabc/eupl
 */
namespace tariqa3{
	/**
	 * Helper class to deal with a time range in the range(date1, date2) or previous(n) format
	 */
	class timeRange{
		/**
		 * The start date (UNIX timestamp)
		 * @var int
		 * @access private
		 */
		private $start_date;

		/**
		 * The end date (UNIX timestamp)
		 * @var int
		 * @access private
		 */
		private $end_date;

		/**
		 * The number of days
		 * @var int
		 * @access private
		 */
		private $days;

		/**
		 * Constructs the object
		 * @param string $range The time range
		 * @access public
		 * @return void
		 */
		public function __construct($range) {
			$d = \MetaNull\News\unifiedQuerySyntax::getDatesCondition($range);
			$t = new \DateTime();
			$time = $t->getTimestamp() + $t->getOffset();
			//\MetaNull\Tools\mDump::dumpVariable($time);
			if ($d['function'] == 'range'){
				$this->start_date = \MetaNull\News\unifiedQuerySyntax::timstamp($d['params'][0]);
				$this->end_date = \MetaNull\News\unifiedQuerySyntax::timstamp($d['params'][1]);
				$this->days = floor($time - $this->start_date * 60 * 60 * 24);
			}
			else if ($d['function'] == 'previous'){
				$this->start_date = $time - $d['params'][0] * 60 * 60 * 24;
				$this->end_date = $time;
				$this->days = $d['params'][0];
			}
		}

		/**
		 * Gets the start date
		 * @access public
		 * @return int
		 */
		public function getStartDate() {
			return $this->start_date;
		}

		/**
		* Gets the end date
		* @access public
		* @return int
		*/
		public function getEndDate(){
			return $this->end_date;
		}

		/**
		 * Gets the number of days
		 * @access public
		 * @return int
		 */
		public function getDays() {
			return $this->days;
		}
	}
}
?>
