CREATE DATABASE  IF NOT EXISTS `hotspots` /*!40100 DEFAULT CHARACTER SET utf8 */;
USE `hotspots`;
-- MySQL dump 10.13  Distrib 5.1.41, for debian-linux-gnu (i486)
--
-- Host: d02di0827377    Database: hotspots
-- ------------------------------------------------------
-- Server version	5.0.67-community-nt

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Not dumping tablespaces as no INFORMATION_SCHEMA.FILES table on this server
--

--
-- Table structure for table `hotspots`
--

DROP TABLE IF EXISTS `hotspots`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hotspots` (
  `country_id` varchar(2) NOT NULL,
  `date` date NOT NULL,
  `forced` enum('y','n') NOT NULL default 'n',
  PRIMARY KEY  USING BTREE (`country_id`,`date`),
  KEY `ixhotspotscountryisd` (`country_id`),
  KEY `ixhotspotsdate` (`date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Table structure for table `articles`
--

DROP TABLE IF EXISTS `articles`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `articles` (
  `article_id` int(11) unsigned NOT NULL auto_increment COMMENT 'Unique identifier of the article (url is wrong as it can appear in several feeds)',
  `feed_id` int(11) unsigned NOT NULL COMMENT 'ID of the feed this article belongs to',
  `date` datetime default NULL COMMENT 'Date of publication of the article',
  `title` varchar(255) NOT NULL COMMENT 'Title of the article (truncated to 255 chars)',
  `headline` text COMMENT 'Title of the article (full length)',
  `summary` text COMMENT 'Summary of the article',
  `content` text COMMENT 'Body of the article',
  `language` varchar(12) default NULL COMMENT 'Language of the article',
  `agency` text COMMENT 'Name of the Press Agency',
  `latestnews_id` int(11) unsigned default NULL COMMENT 'Internal ID of the article in the LatestNews database',
  `ts_article` timestamp NOT NULL default CURRENT_TIMESTAMP COMMENT 'Load date of the article',
  PRIMARY KEY  (`article_id`),
  KEY `idx_articles_feed_id_date` (`feed_id`,`date`),
  KEY `idx_articles_feed_id_date_title` (`feed_id`,`date`,`title`),
  KEY `ix_articles_ts_article` (`ts_article`),
  KEY `idx_articles_title` (`title`),
  KEY `idx_articles_date` (`date`),
  CONSTRAINT `fk_articles` FOREIGN KEY (`feed_id`) REFERENCES `feeds` (`feed_id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=442845 DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='Stores the list of articles of each feed';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Table structure for table `feeds`
--

DROP TABLE IF EXISTS `feeds`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `feeds` (
  `feed_id` int(11) unsigned NOT NULL auto_increment COMMENT 'Unique identifier for the feed',
  `query` text NOT NULL COMMENT 'SQL WHERE statement',
  `time_range` int(11) NOT NULL default '1' COMMENT 'Number of hours to go backwards in the archive',
  `title` varchar(255) default NULL COMMENT 'Title of the feed',
  `description` text COMMENT 'Description of the feed',
  `picture` varchar(255) default NULL COMMENT 'URL to the embeded Logo',
  `link` varchar(255) default NULL COMMENT 'URL of the site corresponding to the current feed',
  `language` varchar(20) default NULL COMMENT 'Language of the feed (if avialable)',
  `copyright` text COMMENT 'Copyright information',
  `refresh_rate` int(10) unsigned NOT NULL default '15' COMMENT 'Refresh rate of the feed (in seconds). 0 means unrestricted',
  `last_refresh` datetime default NULL COMMENT 'Date/time at which the feed was last refreshed',
  PRIMARY KEY  (`feed_id`)
) ENGINE=InnoDB AUTO_INCREMENT=172 DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='Stores the list of RSS feeds';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Table structure for table `statistics`
--

DROP TABLE IF EXISTS `statistics`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `statistics` (
  `country_id` varchar(2) NOT NULL COMMENT 'Country ISO2 code',
  `w_average` float default NULL COMMENT 'Average of articles per day (including weekends)',
  `w_stddev` float default NULL COMMENT 'Standard deviation of articles per day (including weekends)',
  `w_average_before` float default NULL COMMENT 'Average of articles per days older than an week (including weekends)',
  `w_stddev_before` float default NULL COMMENT 'Standard deviation of articles per days older than an week (including weekends)',
  `average` float default NULL COMMENT 'Average of articles per day (excluding weekends)',
  `stddev` float default NULL COMMENT 'Standard deviation of articles per day (excluding weekends)',
  `average_before` float default NULL COMMENT 'Average of articles per days older than an week (excluding weekends)',
  `stddev_before` float default NULL COMMENT 'Standard deviation of articles per days older than an week (excluding weekends)',
  `ow_average` float default NULL COMMENT 'Average of articles per day (only weekends)',
  `ow_stddev` float default NULL COMMENT 'Standard deviation of articles per day (only weekends)',
  `ow_average_before` float default NULL COMMENT 'Average of articles per days older than an week (only weekends)',
  `ow_stddev_before` float default NULL COMMENT 'Standard deviation of articles per days older than an week (only weekends)',
  `w_variance` float default NULL COMMENT 'Variance of articles per day (including weekends)',
  `variance` float default NULL COMMENT 'Variance of articles per day (excluding weekends)',
  `ow_variance` float default NULL COMMENT 'Variance of articles per day (only weekends)',
  PRIMARY KEY  (`country_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Table structure for table `countries`
--

DROP TABLE IF EXISTS `countries`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `countries` (
  `country_id` varchar(2) NOT NULL COMMENT 'ISO 3166-1',
  `name_en` varchar(255) NOT NULL COMMENT 'ISO 3166-2',
  `name_fr` varchar(255) NOT NULL COMMENT 'ISO 3166-2',
  `parent_country_id` varchar(2) default NULL COMMENT '"Parent" country or NULL',
  `eu_member` enum('0','1') NOT NULL default '0' COMMENT '1 if the Country belongs to the European Union',
  `continent_id` int(11) unsigned default NULL COMMENT 'Ref to the continent',
  `official` enum('0','1') NOT NULL default '1' COMMENT '0 If the country is not officialy recognised',
  `cluster_id` int(11) unsigned default NULL,
  `capital_city` varchar(255) default NULL,
  `capital_adm` varchar(255) default NULL,
  `region_id` int(11) unsigned default NULL,
  `other_country` enum('0','1') default '0' COMMENT 'If set to true, it means that there is another country with a similar name. ',
  PRIMARY KEY  (`country_id`),
  KEY `fk_countries_parents` (`parent_country_id`),
  KEY `idx_countries_name_en` (`name_en`),
  KEY `idx_countries_name_fr` (`name_fr`),
  KEY `fk_countries_continents` (`continent_id`),
  KEY `fk_countries_clusters` (`cluster_id`),
  KEY `FK_countries_official_regions` (`region_id`)
) ENGINE=FEDERATED DEFAULT CHARSET=utf8 CONNECTION='mysql://popesad:popesad@s-relex-crisis/meta_common/countries';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Table structure for table `countries_feeds`
--

DROP TABLE IF EXISTS `countries_feeds`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `countries_feeds` (
  `feed_id` int(11) NOT NULL,
  `country_id` varchar(16) NOT NULL,
  `type_id` int(11) NOT NULL,
  PRIMARY KEY  (`feed_id`,`country_id`,`type_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Table structure for table `articles_per_hour`
--

DROP TABLE IF EXISTS `articles_per_hour`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `articles_per_hour` (
  `article_per_hour_id` int(10) unsigned NOT NULL auto_increment,
  `no` int(10) unsigned NOT NULL,
  `hour` int(10) unsigned NOT NULL,
  `date` date NOT NULL,
  `country_id` varchar(2) NOT NULL,
  PRIMARY KEY  (`article_per_hour_id`)
) ENGINE=InnoDB AUTO_INCREMENT=569462 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Table structure for table `pivot_data`
--

DROP TABLE IF EXISTS `pivot_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `pivot_data` (
  `country_id` varchar(2) NOT NULL default '',
  `2009_02_01` mediumint(5) default '0',
  `2009_02_02` mediumint(5) default '0',
  `2009_02_03` mediumint(5) default '0',
  `2009_02_04` mediumint(5) default '0',
  `2009_02_05` mediumint(5) default '0',
  `2009_02_06` mediumint(5) default '0',
  `2009_02_07` mediumint(5) default '0',
  `2009_02_08` mediumint(5) default '0',
  `2009_02_09` mediumint(5) default '0',
  `2009_02_10` mediumint(5) default '0',
  PRIMARY KEY  (`country_id`)
) ENGINE=MEMORY DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Table structure for table `articles_per_day`
--

DROP TABLE IF EXISTS `articles_per_day`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `articles_per_day` (
  `article_per_day_id` int(10) unsigned NOT NULL auto_increment,
  `date` date NOT NULL,
  `no` int(10) unsigned NOT NULL,
  `country_id` varchar(2) NOT NULL,
  PRIMARY KEY  USING BTREE (`article_per_day_id`)
) ENGINE=InnoDB AUTO_INCREMENT=50558 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Table structure for table `statsmobiles`
--

DROP TABLE IF EXISTS `statsmobiles`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `statsmobiles` (
  `countryId` varchar(2) NOT NULL default '',
  `curDate` date NOT NULL default '0000-00-00',
  `mobileRange` int(11) default NULL,
  `sMinDate` date default NULL,
  `sMaxDate` date default NULL,
  `sAverage` float default NULL,
  `sStdDev` float default NULL,
  `sVariance` float default NULL,
  `sSize` mediumtext,
  `sMinVal` mediumtext,
  `sMaxVal` mediumtext,
  PRIMARY KEY  (`countryId`,`curDate`),
  KEY `ixhotspotscountryisd` (`countryId`),
  KEY `ixhotspotsdate` (`curDate`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Temporary table structure for view `stats_global`
--

DROP TABLE IF EXISTS `stats_global`;
/*!50001 DROP VIEW IF EXISTS `stats_global`*/;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
/*!50001 CREATE TABLE `stats_global` (
  `perCountry` varchar(10),
  `minSample` bigint(20),
  `maxSample` bigint(20),
  `avgSample` decimal(23,4),
  `stdDevSample` double,
  `sampleSize` decimal(41,0),
  `sampleCount` bigint(21)
) ENGINE=MyISAM */;
SET character_set_client = @saved_cs_client;

--
-- Temporary table structure for view `stats_per_country`
--

DROP TABLE IF EXISTS `stats_per_country`;
/*!50001 DROP VIEW IF EXISTS `stats_per_country`*/;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
/*!50001 CREATE TABLE `stats_per_country` (
  `country_id` varchar(2),
  `no` decimal(33,0),
  `average` decimal(15,4),
  `standardDeviation` double(28,4),
  `sample` bigint(21)
) ENGINE=MyISAM */;
SET character_set_client = @saved_cs_client;

--
-- Temporary table structure for view `stats_per_day`
--

DROP TABLE IF EXISTS `stats_per_day`;
/*!50001 DROP VIEW IF EXISTS `stats_per_day`*/;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
/*!50001 CREATE TABLE `stats_per_day` (
  `date` date,
  `no` decimal(33,0),
  `average` decimal(15,4),
  `standardDeviation` double(28,4),
  `sample` bigint(21)
) ENGINE=MyISAM */;
SET character_set_client = @saved_cs_client;

--
-- Temporary table structure for view `statsmobiles_coldspots`
--

DROP TABLE IF EXISTS `statsmobiles_coldspots`;
/*!50001 DROP VIEW IF EXISTS `statsmobiles_coldspots`*/;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
/*!50001 CREATE TABLE `statsmobiles_coldspots` (
  `country_id` varchar(2),
  `date` date,
  `hotspot` int(1),
  `coldspot` int(1),
  `hotpc` double(23,2),
  `coldpc` double(23,2),
  `articles` int(10) unsigned,
  `mobile_average` float,
  `mobile_stddev` float
) ENGINE=MyISAM */;
SET character_set_client = @saved_cs_client;

--
-- Temporary table structure for view `statsmobiles_hotspots`
--

DROP TABLE IF EXISTS `statsmobiles_hotspots`;
/*!50001 DROP VIEW IF EXISTS `statsmobiles_hotspots`*/;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
/*!50001 CREATE TABLE `statsmobiles_hotspots` (
  `country_id` varchar(2),
  `date` date,
  `hotspot` int(1),
  `coldspot` int(1),
  `hotpc` double(23,2),
  `coldpc` double(23,2),
  `articles` int(10) unsigned,
  `mobile_average` float,
  `mobile_stddev` float
) ENGINE=MyISAM */;
SET character_set_client = @saved_cs_client;

--
-- Temporary table structure for view `statsmobiles_month_spots`
--

DROP TABLE IF EXISTS `statsmobiles_month_spots`;
/*!50001 DROP VIEW IF EXISTS `statsmobiles_month_spots`*/;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
/*!50001 CREATE TABLE `statsmobiles_month_spots` (
  `country_id` varchar(2),
  `date` date,
  `hotspot` int(1),
  `coldspot` int(1),
  `hotpc` double(23,2),
  `coldpc` double(23,2),
  `articles` int(10) unsigned,
  `mobile_average` float,
  `mobile_stddev` float
) ENGINE=MyISAM */;
SET character_set_client = @saved_cs_client;

--
-- Temporary table structure for view `statsmobiles_spots`
--

DROP TABLE IF EXISTS `statsmobiles_spots`;
/*!50001 DROP VIEW IF EXISTS `statsmobiles_spots`*/;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
/*!50001 CREATE TABLE `statsmobiles_spots` (
  `country_id` varchar(2),
  `date` date,
  `hotspot` int(1),
  `coldspot` int(1),
  `hotpc` double(23,2),
  `coldpc` double(23,2),
  `articles` int(10) unsigned,
  `mobile_average` float,
  `mobile_stddev` float
) ENGINE=MyISAM */;
SET character_set_client = @saved_cs_client;

--
-- Temporary table structure for view `statsmobiles_today_spots`
--

DROP TABLE IF EXISTS `statsmobiles_today_spots`;
/*!50001 DROP VIEW IF EXISTS `statsmobiles_today_spots`*/;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
/*!50001 CREATE TABLE `statsmobiles_today_spots` (
  `country_id` varchar(2),
  `date` date,
  `hotspot` int(1),
  `coldspot` int(1),
  `hotpc` double(23,2),
  `coldpc` double(23,2),
  `articles` int(10) unsigned,
  `mobile_average` float,
  `mobile_stddev` float
) ENGINE=MyISAM */;
SET character_set_client = @saved_cs_client;

--
-- Temporary table structure for view `statsmobiles_week_spots`
--

DROP TABLE IF EXISTS `statsmobiles_week_spots`;
/*!50001 DROP VIEW IF EXISTS `statsmobiles_week_spots`*/;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
/*!50001 CREATE TABLE `statsmobiles_week_spots` (
  `country_id` varchar(2),
  `date` date,
  `hotspot` int(1),
  `coldspot` int(1),
  `hotpc` double(23,2),
  `coldpc` double(23,2),
  `articles` int(10) unsigned,
  `mobile_average` float,
  `mobile_stddev` float
) ENGINE=MyISAM */;
SET character_set_client = @saved_cs_client;

--
-- Temporary table structure for view `today`
--

DROP TABLE IF EXISTS `today`;
/*!50001 DROP VIEW IF EXISTS `today`*/;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
/*!50001 CREATE TABLE `today` (
  `country_id` varchar(2),
  `date` date,
  `forced` varchar(1),
  `hot` bigint(20),
  `cold` bigint(20)
) ENGINE=MyISAM */;
SET character_set_client = @saved_cs_client;

--
-- Temporary table structure for view `today_spots`
--

DROP TABLE IF EXISTS `today_spots`;
/*!50001 DROP VIEW IF EXISTS `today_spots`*/;
SET @saved_cs_client     = @@character_set_client;
SET character_set_client = utf8;
/*!50001 CREATE TABLE `today_spots` (
  `country_id` varchar(2),
  `date` date,
  `forced` varchar(1),
  `hot` bigint(20),
  `cold` bigint(20)
) ENGINE=MyISAM */;
SET character_set_client = @saved_cs_client;

--
-- Final view structure for view `stats_global`
--

/*!50001 DROP TABLE IF EXISTS `stats_global`*/;
/*!50001 DROP VIEW IF EXISTS `stats_global`*/;
/*!50001 CREATE ALGORITHM=UNDEFINED DEFINER=`metanull`@`%` SQL SECURITY DEFINER VIEW `stats_global` AS select _utf8'perCountry' AS `perCountry`,min(`stats_per_country`.`sample`) AS `minSample`,max(`stats_per_country`.`sample`) AS `maxSample`,avg(`stats_per_country`.`sample`) AS `avgSample`,std(`stats_per_country`.`sample`) AS `stdDevSample`,sum(`stats_per_country`.`sample`) AS `sampleSize`,count(`stats_per_country`.`sample`) AS `sampleCount` from `stats_per_country` union select _utf8'perDay' AS `perDay`,min(`stats_per_day`.`sample`) AS `minSample`,max(`stats_per_day`.`sample`) AS `maxSample`,avg(`stats_per_day`.`sample`) AS `avgSample`,std(`stats_per_day`.`sample`) AS `stdDevSample`,sum(`stats_per_day`.`sample`) AS `sampleSize`,count(`stats_per_day`.`sample`) AS `sampleCount` from `stats_per_day` */;

--
-- Final view structure for view `stats_per_country`
--

/*!50001 DROP TABLE IF EXISTS `stats_per_country`*/;
/*!50001 DROP VIEW IF EXISTS `stats_per_country`*/;
/*!50001 CREATE ALGORITHM=UNDEFINED DEFINER=`metanull`@`%` SQL SECURITY DEFINER VIEW `stats_per_country` AS select `articles_per_day`.`country_id` AS `country_id`,sum(`articles_per_day`.`no`) AS `no`,avg(`articles_per_day`.`no`) AS `average`,std(`articles_per_day`.`no`) AS `standardDeviation`,count(`articles_per_day`.`no`) AS `sample` from `articles_per_day` group by `articles_per_day`.`country_id` */;

--
-- Final view structure for view `stats_per_day`
--

/*!50001 DROP TABLE IF EXISTS `stats_per_day`*/;
/*!50001 DROP VIEW IF EXISTS `stats_per_day`*/;
/*!50001 CREATE ALGORITHM=UNDEFINED DEFINER=`metanull`@`%` SQL SECURITY DEFINER VIEW `stats_per_day` AS select `articles_per_day`.`date` AS `date`,sum(`articles_per_day`.`no`) AS `no`,avg(`articles_per_day`.`no`) AS `average`,std(`articles_per_day`.`no`) AS `standardDeviation`,count(`articles_per_day`.`no`) AS `sample` from `articles_per_day` group by `articles_per_day`.`date` */;

--
-- Final view structure for view `statsmobiles_coldspots`
--

/*!50001 DROP TABLE IF EXISTS `statsmobiles_coldspots`*/;
/*!50001 DROP VIEW IF EXISTS `statsmobiles_coldspots`*/;
/*!50001 CREATE ALGORITHM=UNDEFINED DEFINER=`metanull`@`%` SQL SECURITY INVOKER VIEW `statsmobiles_coldspots` AS select `statsmobiles_spots`.`country_id` AS `country_id`,`statsmobiles_spots`.`date` AS `date`,`statsmobiles_spots`.`hotspot` AS `hotspot`,`statsmobiles_spots`.`coldspot` AS `coldspot`,`statsmobiles_spots`.`hotpc` AS `hotpc`,`statsmobiles_spots`.`coldpc` AS `coldpc`,`statsmobiles_spots`.`articles` AS `articles`,`statsmobiles_spots`.`mobile_average` AS `mobile_average`,`statsmobiles_spots`.`mobile_stddev` AS `mobile_stddev` from `statsmobiles_spots` where (`statsmobiles_spots`.`coldspot` = 1) */;

--
-- Final view structure for view `statsmobiles_hotspots`
--

/*!50001 DROP TABLE IF EXISTS `statsmobiles_hotspots`*/;
/*!50001 DROP VIEW IF EXISTS `statsmobiles_hotspots`*/;
/*!50001 CREATE ALGORITHM=UNDEFINED DEFINER=`metanull`@`%` SQL SECURITY INVOKER VIEW `statsmobiles_hotspots` AS select `statsmobiles_spots`.`country_id` AS `country_id`,`statsmobiles_spots`.`date` AS `date`,`statsmobiles_spots`.`hotspot` AS `hotspot`,`statsmobiles_spots`.`coldspot` AS `coldspot`,`statsmobiles_spots`.`hotpc` AS `hotpc`,`statsmobiles_spots`.`coldpc` AS `coldpc`,`statsmobiles_spots`.`articles` AS `articles`,`statsmobiles_spots`.`mobile_average` AS `mobile_average`,`statsmobiles_spots`.`mobile_stddev` AS `mobile_stddev` from `statsmobiles_spots` where (`statsmobiles_spots`.`hotspot` = 1) */;

--
-- Final view structure for view `statsmobiles_month_spots`
--

/*!50001 DROP TABLE IF EXISTS `statsmobiles_month_spots`*/;
/*!50001 DROP VIEW IF EXISTS `statsmobiles_month_spots`*/;
/*!50001 CREATE ALGORITHM=UNDEFINED DEFINER=`metanull`@`%` SQL SECURITY INVOKER VIEW `statsmobiles_month_spots` AS select `apd`.`country_id` AS `country_id`,`apd`.`date` AS `date`,if((`apd`.`no` > (`sm`.`sAverage` + `sm`.`sStdDev`)),1,0) AS `hotspot`,if((`apd`.`no` < (`sm`.`sAverage` - `sm`.`sStdDev`)),1,0) AS `coldspot`,round(((100 * `apd`.`no`) / (`sm`.`sAverage` + `sm`.`sStdDev`)),2) AS `hotpc`,round(((100 * (`sm`.`sAverage` - `sm`.`sStdDev`)) / `apd`.`no`),2) AS `coldpc`,`apd`.`no` AS `articles`,`sm`.`sAverage` AS `mobile_average`,`sm`.`sStdDev` AS `mobile_stddev` from (`articles_per_day` `apd` join `statsmobiles` `sm` on(((`apd`.`country_id` = `sm`.`countryId`) and (`apd`.`date` = `sm`.`curDate`)))) where ((to_days(now()) - to_days(`apd`.`date`)) between 1 and 30) order by `apd`.`country_id`,`apd`.`date` */;

--
-- Final view structure for view `statsmobiles_spots`
--

/*!50001 DROP TABLE IF EXISTS `statsmobiles_spots`*/;
/*!50001 DROP VIEW IF EXISTS `statsmobiles_spots`*/;
/*!50001 CREATE ALGORITHM=UNDEFINED DEFINER=`metanull`@`%` SQL SECURITY INVOKER VIEW `statsmobiles_spots` AS select `apd`.`country_id` AS `country_id`,`apd`.`date` AS `date`,if((`apd`.`no` > (`sm`.`sAverage` + `sm`.`sStdDev`)),1,0) AS `hotspot`,if((`apd`.`no` < (`sm`.`sAverage` - `sm`.`sStdDev`)),1,0) AS `coldspot`,round(((100 * `apd`.`no`) / (`sm`.`sAverage` + `sm`.`sStdDev`)),2) AS `hotpc`,round(((100 * (`sm`.`sAverage` - `sm`.`sStdDev`)) / `apd`.`no`),2) AS `coldpc`,`apd`.`no` AS `articles`,`sm`.`sAverage` AS `mobile_average`,`sm`.`sStdDev` AS `mobile_stddev` from (`articles_per_day` `apd` join `statsmobiles` `sm` on(((`apd`.`country_id` = `sm`.`countryId`) and (`apd`.`date` = `sm`.`curDate`)))) order by `apd`.`country_id`,`apd`.`date` */;

--
-- Final view structure for view `statsmobiles_today_spots`
--

/*!50001 DROP TABLE IF EXISTS `statsmobiles_today_spots`*/;
/*!50001 DROP VIEW IF EXISTS `statsmobiles_today_spots`*/;
/*!50001 CREATE ALGORITHM=UNDEFINED DEFINER=`metanull`@`%` SQL SECURITY INVOKER VIEW `statsmobiles_today_spots` AS select `apd`.`country_id` AS `country_id`,`apd`.`date` AS `date`,if((`apd`.`no` > (`sm`.`sAverage` + `sm`.`sStdDev`)),1,0) AS `hotspot`,if((`apd`.`no` < (`sm`.`sAverage` - `sm`.`sStdDev`)),1,0) AS `coldspot`,round(((100 * `apd`.`no`) / (`sm`.`sAverage` + `sm`.`sStdDev`)),2) AS `hotpc`,round(((100 * (`sm`.`sAverage` - `sm`.`sStdDev`)) / `apd`.`no`),2) AS `coldpc`,`apd`.`no` AS `articles`,`sm`.`sAverage` AS `mobile_average`,`sm`.`sStdDev` AS `mobile_stddev` from (`articles_per_day` `apd` join `statsmobiles` `sm` on(((`apd`.`country_id` = `sm`.`countryId`) and (`apd`.`date` = `sm`.`curDate`)))) where ((to_days(now()) - to_days(`apd`.`date`)) = 1) order by `apd`.`country_id`,`apd`.`date` */;

--
-- Final view structure for view `statsmobiles_week_spots`
--

/*!50001 DROP TABLE IF EXISTS `statsmobiles_week_spots`*/;
/*!50001 DROP VIEW IF EXISTS `statsmobiles_week_spots`*/;
/*!50001 CREATE ALGORITHM=UNDEFINED DEFINER=`metanull`@`%` SQL SECURITY INVOKER VIEW `statsmobiles_week_spots` AS select `apd`.`country_id` AS `country_id`,`apd`.`date` AS `date`,if((`apd`.`no` > (`sm`.`sAverage` + `sm`.`sStdDev`)),1,0) AS `hotspot`,if((`apd`.`no` < (`sm`.`sAverage` - `sm`.`sStdDev`)),1,0) AS `coldspot`,round(((100 * `apd`.`no`) / (`sm`.`sAverage` + `sm`.`sStdDev`)),2) AS `hotpc`,round(((100 * (`sm`.`sAverage` - `sm`.`sStdDev`)) / `apd`.`no`),2) AS `coldpc`,`apd`.`no` AS `articles`,`sm`.`sAverage` AS `mobile_average`,`sm`.`sStdDev` AS `mobile_stddev` from (`articles_per_day` `apd` join `statsmobiles` `sm` on(((`apd`.`country_id` = `sm`.`countryId`) and (`apd`.`date` = `sm`.`curDate`)))) where ((to_days(now()) - to_days(`apd`.`date`)) between 1 and 7) order by `apd`.`country_id`,`apd`.`date` */;

--
-- Final view structure for view `today`
--

/*!50001 DROP TABLE IF EXISTS `today`*/;
/*!50001 DROP VIEW IF EXISTS `today`*/;
/*!50001 CREATE ALGORITHM=UNDEFINED DEFINER=`metanull`@`%` SQL SECURITY INVOKER VIEW `today` AS select `today_spots`.`country_id` AS `country_id`,`today_spots`.`date` AS `date`,`today_spots`.`forced` AS `forced`,`today_spots`.`hot` AS `hot`,`today_spots`.`cold` AS `cold` from `today_spots` group by `today_spots`.`country_id`,`today_spots`.`date` */;

--
-- Final view structure for view `today_spots`
--

/*!50001 DROP TABLE IF EXISTS `today_spots`*/;
/*!50001 DROP VIEW IF EXISTS `today_spots`*/;
/*!50001 CREATE ALGORITHM=UNDEFINED DEFINER=`metanull`@`%` SQL SECURITY INVOKER VIEW `today_spots` AS select `hotspots`.`country_id` AS `country_id`,`hotspots`.`date` AS `date`,`hotspots`.`forced` AS `forced`,1 AS `hot`,0 AS `cold` from `hotspots` where ((`hotspots`.`forced` = _utf8'y') and ((to_days(now()) - to_days(`hotspots`.`date`)) = 0)) union select `statsmobiles_hotspots`.`country_id` AS `country_id`,(`statsmobiles_hotspots`.`date` + interval 1 day) AS `date`,_latin1'n' AS `forced`,1 AS `hot`,0 AS `cold` from `statsmobiles_hotspots` where ((to_days(now()) - to_days(`statsmobiles_hotspots`.`date`)) = 1) union select `statsmobiles_coldspots`.`country_id` AS `country_id`,(`statsmobiles_coldspots`.`date` + interval 1 day) AS `date`,_latin1'n' AS `forced`,0 AS `hot`,1 AS `cold` from `statsmobiles_coldspots` where ((to_days(now()) - to_days(`statsmobiles_coldspots`.`date`)) = 1) */;

--
-- Dumping routines for database 'hotspots'
--
/*!50003 DROP PROCEDURE IF EXISTS `CalculerStatsMobiles` */;
--
-- WARNING: old server version. The following dump may be incomplete.
--
/*!50003 SET @saved_sql_mode       = @@sql_mode */ ;
/*!50003 SET sql_mode              = 'STRICT_TRANS_TABLES,NO_AUTO_CREATE_USER' */ ;
DELIMITER ;;
/*!50003 CREATE*/ /*!50020 DEFINER=`metanull`@`%`*/ /*!50003 PROCEDURE `CalculerStatsMobiles`(
    IN mobileRange INT
)
    SQL SECURITY INVOKER
    COMMENT 'Computes all mobile statistics'
BEGIN
    DECLARE curDate DATE;
    DECLARE curCountry VARCHAR(2);
    
    DECLARE sMinDate DATE;
    DECLARE sMaxDate DATE;
    DECLARE sAverage FLOAT;
    DECLARE sStdDev FLOAT;
    DECLARE sVariance FLOAT;
    DECLARE sSize LONG;
    DECLARE sMinVal LONG;
    DECLARE sMaxVal LONG;
    
    DECLARE cData CURSOR FOR SELECT `country_id`, `date` FROM `articles_per_day`;
    
    
    
    OPEN cData;
    cDataLoop: LOOP
        FETCH cData INTO curCountry, curDate;
        CALL StatsMobile(curCountry, curDate, mobileRange, sMinDate, sMaxDate, sAverage, sStdDev, sVariance, sSize, sMinVal, sMaxVal );
        
        IF sSize > (mobileRange * 1 / 4 ) AND curDate <> sMaxDate THEN
            REPLACE INTO `StatsMobiles` VALUES(curCountry, curDate, mobileRange, sMinDate, sMaxDate, sAverage, sStdDev, sVariance, sSize, sMinVal, sMaxVal);
        END IF;
    END LOOP;
    CLOSE cData;
    
END */;;
DELIMITER ;
/*!50003 SET sql_mode              = @saved_sql_mode */ ;
/*!50003 DROP PROCEDURE IF EXISTS `CleanHotSpotsDatabase` */;
--
-- WARNING: old server version. The following dump may be incomplete.
--
/*!50003 SET @saved_sql_mode       = @@sql_mode */ ;
/*!50003 SET sql_mode              = 'STRICT_TRANS_TABLES,NO_AUTO_CREATE_USER' */ ;
DELIMITER ;;
/*!50003 CREATE*/ /*!50020 DEFINER=`metanull`@`%`*/ /*!50003 PROCEDURE `CleanHotSpotsDatabase`(
    IN daysToKeep INT
)
    SQL SECURITY INVOKER
    COMMENT 'Clean hotspots database from old data'
BEGIN
    DECLARE days INT DEFAULT 365;
    IF daysToKeep IS NOT NULL THEN
        SET days = daysToKeep;
    END IF;
    IF days < 90 THEN
        SET days = 90;
    END IF;
    DELETE FROM statsmobiles WHERE DATEDIFF(now(),curDate) > days;
    DELETE FROM hotspots WHERE DATEDIFF(now(),date) > days;
    DELETE FROM articles WHERE DATEDIFF(now(),date) > days;
END */;;
DELIMITER ;
/*!50003 SET sql_mode              = @saved_sql_mode */ ;
/*!50003 DROP PROCEDURE IF EXISTS `fillPivotData` */;
--
-- WARNING: old server version. The following dump may be incomplete.
--
/*!50003 SET @saved_sql_mode       = @@sql_mode */ ;
/*!50003 SET sql_mode              = 'STRICT_TRANS_TABLES,NO_AUTO_CREATE_USER' */ ;
DELIMITER ;;
/*!50003 CREATE*/ /*!50020 DEFINER=`cosmin`@`%`*/ /*!50003 PROCEDURE `fillPivotData`()
begin
  declare _no, done mediumint(5) default 0;
  declare _date date default '0000-00-00';
  declare _country_id varchar(2) default '';
  declare _sql text default '';
  declare rec cursor for select date(`date`) from articles_per_day group by date(`date`) order by date(`date`);
  declare rec2 cursor for select `no`, date(`date`) from articles_per_day where country_id = _country_id order by country_id;
  declare rec3 cursor for select country_id from articles_per_day a where not exists (select country_id from articles_per_day b where `no` > 5 and a.country_id = b.country_id group by country_id);
  declare continue handler for sqlstate '02000' set done = 1;

  open rec;
  fetch rec into _date;

  while done <> 1 do
    set _sql = concat(_sql, if(_sql = "", "", ", "), replace(_date, "-", "_"), " mediumint(5) default 0");
    set done = 0;
    fetch rec into _date;
  end while;
  close rec;

  set _sql = concat("create table pivot_data(country_id varchar(2), ", _sql, ", primary key(country_id)) engine = memory");

  drop table if exists pivot_data;

  set @sql = _sql;
  prepare stm from @sql;
  execute stm;

  set done = 0;
  open rec3;
  fetch rec3 into _country_id;

  while done <> 1 do
  set done = 0;
    open rec2;
    fetch rec2 into _no, _date;

    while done <> 1 do
      if (select count(*) from pivot_data where country_id = _country_id) = 0 then
        insert into pivot_data(country_id) values(_country_id);
      end if;
      set _sql = concat("update pivot_data set ", replace(_date, "-", "_"), " = ", _no, " where country_id = '", _country_id , "'");
      set @sql = _sql;
      prepare stm from @sql;
      execute stm;

      set done = 0;
      fetch rec2 into _no, _date;
    end while;
    close rec2;

    set done = 0;
    fetch rec3 into _country_id;
  end while;

  close rec3;

end */;;
DELIMITER ;
/*!50003 SET sql_mode              = @saved_sql_mode */ ;
/*!50003 DROP PROCEDURE IF EXISTS `StatsMobile` */;
--
-- WARNING: old server version. The following dump may be incomplete.
--
/*!50003 SET @saved_sql_mode       = @@sql_mode */ ;
/*!50003 SET sql_mode              = 'STRICT_TRANS_TABLES,NO_AUTO_CREATE_USER' */ ;
DELIMITER ;;
/*!50003 CREATE*/ /*!50020 DEFINER=`metanull`@`%`*/ /*!50003 PROCEDURE `StatsMobile`(
    IN countryId VARCHAR(2),
    IN curDate DATE,
    IN mobileRange INT,
    OUT sMinDate DATE,
    OUT sMaxDate DATE,
    OUT sAverage FLOAT,
    OUT sStdDev FLOAT,
    OUT sVariance FLOAT,
    OUT sSize LONG,
    OUT sMinVal LONG,
    OUT sMaxVal LONG
)
    SQL SECURITY INVOKER
    COMMENT 'Computes mobile statistics of a given date and country'
BEGIN
    DECLARE tmpCountryId varchar(2);
    
    select `country_id`, min(`date`), max(`date`), avg(`no`), std(`no`), count(`no`), min(`no`), max(`no`), variance(`no`)
    
    into tmpCountryId, sMinDate, sMaxDate, sAverage, sStdDev, sSize, sMinVal, sMaxVal, sVariance
    from `articles_per_day`
    where `country_id`= countryId
    and date < curDate
    and date >= date_sub(curDate, interval mobileRange day)
    group by `country_id`;
END */;;
DELIMITER ;
/*!50003 SET sql_mode              = @saved_sql_mode */ ;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2011-04-07 15:24:20
