CREATE DATABASE  IF NOT EXISTS `rss_aggregator` /*!40100 DEFAULT CHARACTER SET utf8 */;
USE `rss_aggregator`;
-- MySQL dump 10.13  Distrib 5.1.41, for debian-linux-gnu (i486)
--
-- Host: s-relex-crisis    Database: rss_aggregator
-- ------------------------------------------------------
-- Server version	5.0.67-community

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Not dumping tablespaces as no INFORMATION_SCHEMA.FILES table on this server
--

--
-- Table structure for table `articles`
--

DROP TABLE IF EXISTS `articles`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `articles` (
  `article_id` int(11) unsigned NOT NULL auto_increment COMMENT 'Unique identifier of the article (url is wrong as it can appear in several feeds)',
  `feed_id` int(11) unsigned NOT NULL COMMENT 'ID of the feed this article belongs to',
  `date` datetime default NULL COMMENT 'Date of publication of the article',
  `title` text COMMENT 'Title of the article',
  `headline` text COMMENT 'Title of the article (full length)',
  `description` longtext COMMENT 'Summary of the article if available',
  `link` text COMMENT 'Link to the article',
  `comments` text COMMENT 'Comment about the article (if available)',
  `author` text COMMENT 'Author of the article (if available)',
  `ts_article` timestamp NOT NULL default CURRENT_TIMESTAMP COMMENT 'Load date of the article',
  PRIMARY KEY  (`article_id`),
  KEY `idx_articles_feed_id_date` (`feed_id`,`date`),
  KEY `ix_articles_ts_article` (`ts_article`),
  KEY `idx_articles_feed_id` (`feed_id`),
  KEY `idx_articles_date` (`date`),
  KEY `idx_articles_title` (`title`(255)),
  KEY `idx_articles_link` (`link`(255)),
  KEY `idx_articles_headline` (`headline`(255)),
  KEY `idx_articles_description` (`description`(255)),
  CONSTRAINT `fk_articles` FOREIGN KEY (`feed_id`) REFERENCES `feeds` (`feed_id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=17361768 DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC COMMENT='Stores the list of articles of each feed';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Table structure for table `feeds`
--

DROP TABLE IF EXISTS `feeds`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `feeds` (
  `feed_id` int(11) unsigned NOT NULL auto_increment COMMENT 'Unique identifier for the feed',
  `url` varchar(512) NOT NULL COMMENT 'Full URL of the feed. UNIQUE CONSTRAINT.',
  `title` varchar(255) default NULL COMMENT 'Title of the feed',
  `description` text COMMENT 'Description of the feed',
  `picture` varchar(255) default NULL COMMENT 'URL to the embeded Logo',
  `link` varchar(255) default NULL COMMENT 'URL of the site corresponding to the current feed',
  `language` varchar(20) default NULL COMMENT 'Language of the feed (if avialable)',
  `copyright` text COMMENT 'Copyright information',
  `refresh_rate` int(10) unsigned NOT NULL default '15' COMMENT 'Refresh rate of the feed (in seconds). 0 means unrestricted',
  `last_refresh` datetime default NULL COMMENT 'Date/time at which the feed was last refreshed',
  `use_proxy` tinyint(1) NOT NULL default '1' COMMENT 'If set to 1, the feed will be downloaded through the proxy, otherwise direct connection will be used',
  `has_pictures` enum('y','n') NOT NULL default 'n',
  `manual_picture` varchar(255) default NULL,
  `has_video` enum('y','n') NOT NULL default 'n',
  `has_audio` enum('y','n') NOT NULL default 'n',
  PRIMARY KEY  (`feed_id`)
) ENGINE=InnoDB AUTO_INCREMENT=3273 DEFAULT CHARSET=utf8 COMMENT='Stores the list of RSS feeds';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Table structure for table `newsticker_feeds`
--

DROP TABLE IF EXISTS `newsticker_feeds`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `newsticker_feeds` (
  `feed_id` int(10) unsigned NOT NULL COMMENT 'The feed identifier',
  `name` varchar(255) NOT NULL COMMENT 'The feed name',
  PRIMARY KEY  (`feed_id`),
  CONSTRAINT `new_fk_constraint` FOREIGN KEY (`feed_id`) REFERENCES `feeds` (`feed_id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='The list of feeds for newstickers';
/*!40101 SET character_set_client = @saved_cs_client */;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2011-04-07 15:38:27
