<?php
	/**
	 * Encloses the documentView, documentMarkup, and WSKDocumentRange elements which define a series of retrieval options.
	 * */
	class WSKRetrievalOptions  {
		
		/**
		 * Identifies the display format in which the documents will be delivered. The default display format is source-specific.
		 * Note: Please refer to the Glossary for descriptions of these display formats (http://www.lexisnexis.com/webserviceskit/developers/v1_12/text/WSK-Glossary.aspx).
		 * @see dvCite
		 * @see dvExpandedCite
		 * @see dvSearchHitsInContext
		 * @see dvFullText
		 * @see dvFullTextWithTerms
		 * @var string
		 * */
		public $documentView;
		
		/**
		 * Displays the name of the document plus some relevant information about it so that users can select the one or more documents they want to review in more detail. By default, initial search results are returned in this display format.
		 * @see $documentView
		 * */
		const dvCite = "Cite";
		
		/**
		 * This format lists documents in the Cite format. In addition, it lists up to the first 25 search term matches in each document along with a few words on both sides of them to show their use in the context of the document.
		 * @see $documentView
		 * */
		const dvExpandedCite = "ExpandedCite";
		
		/**
		 * SearchHitsInContext
		 * @see $documentView
		 * */
		const dvSearchHitsInContext = "SearchHitsInContext";
		
		/**
		 * Displays all the document's text so you can read it in its entirety.
		 * @see $documentView
		 * */
		const dvFullText = "FullText";
		
		/**
		 * This format displays the full text a single retrieved document. In addition it lists all LexisNexis index terms that have been assigned to that document. This helps users see how that document was categorized when it was analyzed and indexed.
		 * @see $documentView
		 * */
		const dvFullTextWithTerms= "FullTextWithTerms";
		
		/**
		 * Identifies the desired XML markup type for document formatting. The default markup is the most appropriate markup for the content type.
		 * "Markup": A set of tags assigned with text that describes either what the text is or how the text is to be formatted.
		 * @see dmDisplay
		 * @see dmSemantic
		 * @var string
		 **/
		public $documentMarkup;
		
		/**
		 *
		 * @see $documentMarkup
		 * */
		const dmDisplay = "Display";
		
		/**
		 *
		 * @see $documentMarkup
		 * */
		const dmSemantic = "Semantic";
		
		/**
		 * Contains the begin and end  elements which identify the range of documents to be retrieved.
		 * Note: The identities of the documents are unknown at this point. Therefore, they are identified by their position in the sorted list (the first document is document 1, the second is document 2, etc.).
		 * @var WSKDocumentRange
		 **/
		public $documentRange;
		
		/**
		 * Include Extended Output
		 * @var boolean
		 * */
		public $includeExtendedOutput;
		
		/**
		 * Allows the retrieval of Shepard's Signals.
		 * @var boolean
		 * */
		public $includeShepardsSignals;
		
		/**
		 * This is an identifier to continue to a previously attempted search that was too general for normal processing.
		 * This feature is not available for all customers.
		 * @var string
		 * */
		public $continueId;
		
		/**
		 * Constructs a WSKRetrievalOptions Object
		 * @param string $documentView
		 * @param string $documentMarkup
		 * @param WSKDocumentRange $documentRange
		 * @param boolean $includeExtendedOutput
		 * @param boolean $includeShepardsSignals
		 * @param string $continueId
		 * @see $documentView
		 * @see $documentMarkup
		 * @see $WSKDocumentRange
		 * @see $includeExtendedOutput
		 * @see $includeShepardsSignals
		 * @see $continueId
		 **/
		public function __construct( $documentView = null, $documentMarkup = null, $documentRange = null, $includeExtendedOutput = null, $includeShepardsSignals = null, $continueId = null ) {
			$this->documentView = $documentView;
			$this->documentMarkup = $documentMarkup;
			$this->documentRange = $documentRange;
			$this->includeExtendedOutput = $includeExtendedOutput;
			$this->includeShepardsSignals = $includeShepardsSignals;
			$this->continueId = $continueId;
		}
	}
?>