<?php
	/**
	 * Encloses the securedSourceId, expiration, permissibleUseMessage, and informationalMessage elements which identify the secured source information to be displayed to your user.
	 * @see WSKGetSourceDetailsResponse
	 * */
	class WSKSecuredSource {
		
		/**
		 * Identifies an encrypted source identifier that must be used in the Search request message to access this secured source.
		 * @var string
		 * */
		public $securedSourceId;
		
		/**
		 * Indicates when the securedSourceId will expire. The date format is:
		 * CCYY-MM-DDThh:mm:ss-hh:mm
		 * (GMT with a time zone offset - CCYY = year, MM= month [1-12], DD = day [01-31], T= required separator, hh= hour [0-23], mm= minute [0-59], and ss= second [0-59] -The time offset may be expressed as a + or - value.)
		 * @var string
		 * */
		public $expiration;
		
		/**
		 * Contains the secured source information that must be displayed to your user.
		 * @var string
		 * */
		public $permissibleUseMessage;
		
		/**
		 * Contains the secured source information that should be displayed to your user.
		 * @var string
		 * */
		public $informationalMessage;
		
		/**
		 * Constructs a securedSource object
		 * @param string $securedSourceId
		 * @param string $expiration
		 * @param string $permissibleUseMessage
		 * @param string $informationalMessage
		 * */
		public function __construct( $securedSourceId = null, $expiration = null, $permissibleUseMessage = null, $informationalMessage = null ) {
			$this->securedSourceId = $securedSourceId;
			$this->expiration = $expiration;
			$this->permissibleUseMessage = $permissibleUseMessage;
			$this->informationalMessage = $informationalMessage;
		}
	}
?>